@@ -1,6 +1,6 @@
 /*
      This file is part of Advanced Strategic Command; http://www.asc-hq.de
-     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+     Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
  
      This program is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -700,7 +700,7 @@ void ServiceChecker :: check( ContainerBase* dest )
 
 void ServiceTargetSearcher::fieldChecker( const MapCoordinate& pos )
 {
-   tfield* fld = gamemap->getField( pos );
+   MapField* fld = gamemap->getField( pos );
    if ( fld && fld->getContainer() )
       check( fld->getContainer() );
 }
