@@ -4,7 +4,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -342,7 +342,7 @@
             MapCoordinate getDestination ( Vehicle* veh );
             AiResult moveToSavePlace ( Vehicle* veh, int preferredHeight = -1 );
             int  getBestHeight (  Vehicle* veh );
-            float getAttackValue ( const tfight& battle, const Vehicle* attackingUnit, const Vehicle* attackedUnit, float factor = 1 );
+            float getAttackValue ( const tfight& battle, Vehicle* attackingUnit, Vehicle* attackedUnit, float factor = 1 );
 
             /** chenges a vehicles height
                 \returns 1 = height change successful ;
@@ -352,12 +352,14 @@
             */
             int changeVehicleHeight ( Vehicle* veh, int preferredDirection = -1 );
 
-            void  calculateThreat ( const Vehicletype* vt);
+            void  calculateThreat ( const VehicleType* vt);
             void  calculateThreat ( Vehicle* eht );
             void  calculateThreat ( Building* bld );
             void  calculateThreat ( Building* bld, int player );
+            int getValue( Vehicle* v );
+            
 
-            static AiParameter::JobList chooseJob ( const Vehicletype* typ );
+            static AiParameter::JobList chooseJob ( const VehicleType* typ );
             friend class CalculateThreat_Vehicle;
 
             /** This structure helps identifying units which don't reach any
@@ -387,11 +389,11 @@
             };
             UnitDistribution originalUnitDistribution;
             UnitDistribution::Group getUnitDistributionGroup ( Vehicle* veh );
-            UnitDistribution::Group getUnitDistributionGroup ( Vehicletype* veh );
+            UnitDistribution::Group getUnitDistributionGroup ( VehicleType* veh );
 
             UnitDistribution calcUnitDistribution();
             struct ProductionRating {
-               const Vehicletype* vt;
+               const VehicleType* vt;
                Building*    bld;
                float        rating;
                bool operator< ( const ProductionRating& pr ) { return rating < pr.rating; };
