@@ -94,7 +94,7 @@ void AI :: searchTargets ( Vehicle* veh, const MapCoordinate3D& pos, TargetVecto
 
          for ( int nf = 0; nf < sidenum; nf++ ) {
             MapCoordinate mc = getNeighbouringFieldCoordinate ( MapCoordinate ( mv->attackx, mv->attacky), nf );
-            tfield* fld = getMap()->getField(mc);
+            MapField* fld = getMap()->getField(mc);
             if ( fld && !veh->typ->wait)
                mv->neighbouringFieldsReachable[nf] = (vm.fieldVisited( MapCoordinate3D(mc.x, mc.y, pos.getBitmappedHeight()) ) || ( veh->xpos == mc.x && veh->ypos == mc.y )) && !fld->building && (!fld->vehicle || fld->unitHere(veh));
             else
@@ -117,7 +117,7 @@ void AI :: searchTargets ( Vehicle* veh, const MapCoordinate3D& pos, TargetVecto
             }
 
             MapCoordinate mc = getNeighbouringFieldCoordinate ( MapCoordinate ( mv->attackx, mv->attacky), checkDir%sidenum );
-            tfield* fld = getMap()->getField(mc);
+            MapField* fld = getMap()->getField(mc);
             if ( fld && !fld->building && !fld->vehicle )
                hemmingFactor += AttackFormula::getHemmingFactor ( nf );
          }
@@ -212,7 +212,7 @@ void AI::getAttacks ( AStar3D& vm, Vehicle* veh, TargetVector& tv, int hemmingBo
    int enemycount = 0;
    for ( int y = y1; y <= y2 && !enemycount; ++y)
       for ( int x = x1; x <= x2; ++x) {
-         tfield* fld = getMap()->getField(x,y);
+         MapField* fld = getMap()->getField(x,y);
          if ( fld && fld->vehicle)
             if ( getPlayer(fld->vehicle->getOwner()).diplomacy.isHostile( getPlayerNum() )  )
                enemycount++;
@@ -242,7 +242,7 @@ void AI::getAttacks ( AStar3D& vm, Vehicle* veh, TargetVector& tv, int hemmingBo
       int fuelLacking = 0;
       for ( AStar3D::Container::iterator ff = vm.visited.begin(); ff != vm.visited.end(); ++ff )
          if ( !ff->hasAttacked ) {
-            tfield* fld = getMap()->getField (ff->h);
+            MapField* fld = getMap()->getField (ff->h);
             if ( !fld->vehicle && !fld->building ) {
                 if ( !apl || apl->returnFromPositionPossible ( ff->h )) {
                    searchTargets ( veh, ff->h, tv, beeline ( ff->h.x, ff->h.y, orgxpos, orgypos ), vm, hemmingBonus );
@@ -406,7 +406,7 @@ AI::AiResult AI::moveToSavePlace ( Vehicle* veh, int preferredHeight )
    }
 
    for ( set<MapCoordinate3D>::const_iterator i = fields.begin(); i != fields.end(); ++i ) {
-      tfield* fld = getMap()->getField( *i );
+      MapField* fld = getMap()->getField( *i );
       if ( !fld->vehicle && !fld->building ) {
          AiThreat& ait = getFieldThreat ( i->x, i->y );
          int _dist = beeline ( i->x, i->y, veh->xpos, veh->ypos);
@@ -563,6 +563,9 @@ AI::AiResult AI::tactics( void )
    for ( Player::VehicleList::iterator vi = getPlayer().vehicleList.begin(); vi != getPlayer().vehicleList.end(); vi++ ) {
       Vehicle* veh = *vi;
 
+      if ( !veh->aiparam[ getPlayerNum() ] )
+          calculateThreat( veh );
+      
       bool unitUsable = false;
       if ( veh->aiparam[ getPlayerNum() ]->getJob() == AiParameter::job_fight
         || veh->aiparam[ getPlayerNum() ]->getJob() == AiParameter::job_undefined
@@ -597,7 +600,7 @@ AI::AiResult AI::tactics( void )
          int xdist = ydist / 4;
          for ( int x = veh->xpos - xdist; x <= veh->xpos + xdist; x++ )
             for ( int y = veh->ypos - ydist; y <= veh->ypos + ydist; y++ ) {
-               tfield* fld = getMap()->getField(x,y );
+               MapField* fld = getMap()->getField(x,y );
                if ( fld ) {
                   if ( fld->vehicle && getPlayer(veh->getOwner()).diplomacy.isHostile( fld->vehicle->getOwner() )  )
                      enemiesNear = true;
@@ -662,7 +665,7 @@ AI::AiResult AI::tactics( void )
    
                      int freeNeighbouringFields = 0;
                      for ( int j = 0; j < sidenum; j++ ) {
-                        tfield* fld = getMap()->getField ( getNeighbouringFieldCoordinate ( MapCoordinate(mv->attackx, mv->attacky), j));
+                        MapField* fld = getMap()->getField ( getNeighbouringFieldCoordinate ( MapCoordinate(mv->attackx, mv->attacky), j));
                         if ( fld )
                            if ( !fld->building && !fld->vehicle )
                               freeNeighbouringFields++;
@@ -813,7 +816,7 @@ AI::AiResult AI::tactics( void )
 
                      vector<Vehicle*> unitsToMoveAwayAfterAttacking;
 
-                     tfield* enemyField = getMap()->getField(enemy->xpos, enemy->ypos);
+                     MapField* enemyField = getMap()->getField(enemy->xpos, enemy->ypos);
                      for ( int i = 0; i < finalAttackNum && enemyField->vehicle == enemy && finalAttackNum < maxint; i++ ) {
                         checkKeys();
                         if ( finalOrder[i] < 0 )
@@ -942,9 +945,20 @@ void AI :: tactics_findBestAttackOrder ( Vehicle** units, int* attackOrder, Vehi
 
 }
 
-float AI :: getAttackValue ( const tfight& battle, const Vehicle* attackingUnit, const Vehicle* attackedUnit, float factor )
+
+int AI :: getValue( Vehicle* v ) 
 {
-   float result = (battle.dv.damage - attackedUnit->damage) * attackedUnit->aiparam[getPlayerNum()]->getValue() * factor - 1/config.aggressiveness * (battle.av.damage - attackingUnit->damage) * attackedUnit->aiparam[getPlayerNum()]->getValue() ;
+   if ( v->aiparam[getPlayerNum()] == NULL ) {
+      calculateThreat(v);  
+   }
+   return v->aiparam[getPlayerNum()]->getValue();
+}
+
+float AI :: getAttackValue ( const tfight& battle, Vehicle* attackingUnit, Vehicle* attackedUnit, float factor )
+{
+   calculateThreat( attackedUnit );
+   float result =                     (battle.dv.damage - attackedUnit->damage) * getValue(attackedUnit) * factor 
+          - 1/config.aggressiveness * (battle.av.damage - attackingUnit->damage) * getValue(attackingUnit) ;
    if ( battle.dv.damage >= 100 )
       result += attackedUnit->aiparam[getPlayerNum()]->getValue() * attack_unitdestroyed_bonus;
    return result;
@@ -962,7 +976,7 @@ class UnitAttacksUnit_FakeHemming : public tunitattacksunit {
           UnitAttacksUnit_FakeHemming ( AI* ai, Vehicle* attacker, Vehicle* defender, Vehicle** _neighbours ) : tunitattacksunit ( attacker , defender )
           {
              for ( int i = 0; i < sidenum; i++ ) {
-                tfield* fld = ai->getMap()->getField ( getNeighbouringFieldCoordinate ( attacker->getPosition(), i ));
+                MapField* fld = ai->getMap()->getField ( getNeighbouringFieldCoordinate ( attacker->getPosition(), i ));
 
                 Vehicle* v = NULL;
                 if ( fld )
