@@ -45,6 +45,7 @@
 #include "widgets/textrenderer-addons.h"
 #include "spfst-legacy.h"
 
+#include "weaponrangelayer.h"
 #include "dialogs/fileselector.h"
 
 #include "actions/moveunitcommand.h"
@@ -85,7 +86,7 @@ class Menu : public PG_MenuBar {
 
 bool Menu::execAction  (PG_PopupMenu::MenuItem* menuItem )
 {
-   execUserAction_ev( tuseractions( menuItem->getId() ) );
+   executeUserAction( tuseractions( menuItem->getId() ) );
 
    return true;
 }
@@ -127,6 +128,7 @@ void Menu::addbutton( const char* name, int id )
 
 void Menu::setup()
 {
+  
    addfield ( "Glo~b~al" );
    addbutton ( "~O~ptions", ua_gamepreferences );
    addbutton ( "~S~ound options", ua_soundDialog );
@@ -162,7 +164,9 @@ void Menu::setup()
    addfield ( "~A~ction" );
    addbutton ( "~U~ndo\tctrl-z", ua_undo );
    addbutton ( "~R~edo\tctrl-shift-z", ua_redo );
-   addbutton ( "~M~anage", ua_actionManager );
+   addbutton ( "~M~anage Actions", ua_actionManager );
+   addbutton ( "Manage ~P~ending Tasks", ua_taskManager );
+   addbutton ( "Run all pending tasks\tctrl-t", ua_runOpenTasks );
    currentMenu->addSeparator();
    addbutton ( "Save Script", ua_writeLuaCommands );
    addbutton ( "Run Script", ua_runLuaCommands );
@@ -185,17 +189,17 @@ void Menu::setup()
    currentMenu->addSeparator();
    addbutton ( "Unit Production Analysis", ua_unitproductionanalysis );
    addbutton ( "Mining Station Analysis", ua_showMiningPower );
-   
-   // addbutton ( "~R~esearch status", ua_showResearchStatus );
-
-   // addbutton ( "vehicle ~I~mprovement\tF7", ua_dispvehicleimprovement);
-
-
-   // addfield ( "~S~tatistics" );
-   
-//   addbutton ( "~R~esources ", ua_statisticdialog );
-   // addbutton ( "seperator");
-   // addbutton ( "~H~istory");
+	
+	// addbutton ( "~R~esearch status", ua_showResearchStatus );
+	
+	// addbutton ( "vehicle ~I~mprovement\tF7", ua_dispvehicleimprovement);
+	
+	
+	// addfield ( "~S~tatistics" );
+	
+	//   addbutton ( "~R~esources ", ua_statisticdialog );
+	// addbutton ( "seperator");
+   	// addbutton ( "~H~istory");
 
    addfield ( "~M~essage");
    addbutton ( "~n~ew message", ua_newmessage );
@@ -219,7 +223,10 @@ void Menu::setup()
    addbutton ( "toggle unit shading\t2", ua_toggleunitshading );
    addbutton ( "show ~P~ipeline net\t9", ua_viewPipeNet );
    addbutton ( "show ~V~isibility Range\t0", ua_visibilityInfo );
-   addbutton ( "show reaction~f~ire", ua_viewReactionfireOverlay );
+   currentMenu->addSeparator();
+   addbutton ( "show reaction~f~ire", ua_viewReactionfireOverlay );	
+   addbutton ( "show unit info\tctrl-1", ua_viewUnitinfoOverlay );
+   addbutton ( "show unit experience\tctrl-2", ua_viewUnitexperienceOverlay );
    currentMenu->addSeparator();
    addbutton ( "Button Panel", ua_viewButtonPanel );
    addbutton ( "Wind Panel", ua_viewWindPanel );
@@ -250,6 +257,7 @@ void Menu::setup()
    addbutton ( "calc airplane endurance", ua_showUnitEndurance );
    addbutton ( "show game ~P~arameters", ua_GameParameterInfo );
    addbutton ( "Recompute View", ua_recompteview );
+   addbutton ( "Create unit cost list ", ua_createUnitCostList );
    currentMenu->addSeparator();
    addbutton ( "benchmark without view calc", ua_benchgamewov );
    addbutton ( "benchmark with view calc", ua_benchgamewv);
@@ -267,7 +275,7 @@ void Menu::setup()
    addbutton ( "~K~eys", ua_help );
    addbutton ( "~M~ap Layer", ua_viewlayerhelp );
    currentMenu->addSeparator();
-
+	
    addbutton ( "~A~bout", ua_viewaboutmessage );
 }
 
@@ -282,96 +290,6 @@ Menu::Menu ( PG_Widget *parent, const PG_Rect &rect)
 
 
 
-class UnitWeaponRangeLayer : public MapLayer {
-   Surface& icon1;
-   Surface& icon2;
-   GameMap* gamemap;
-
-   map<MapCoordinate,int> fields;
-
-   void markField( const MapCoordinate& pos )
-   {
-      fields[pos] |= 1;
-   }
-
-      bool addUnit( Vehicle* veh )
-      {
-         if ( fieldvisiblenow ( getfield ( veh->xpos, veh->ypos ))) {
-            int found = 0;
-            for ( int i = 0; i < veh->typ->weapons.count; i++ ) {
-               if ( veh->typ->weapons.weapon[i].shootable() ) {
-                  circularFieldIterator( gamemap,veh->getPosition(), veh->typ->weapons.weapon[i].maxdistance/minmalq, (veh->typ->weapons.weapon[i].mindistance+maxmalq-1)/maxmalq, FieldIterationFunctor( this, &UnitWeaponRangeLayer::markField )  );
-                  found++;
-               }
-            }
-            if ( found )
-               fields[veh->getPosition()] |= 2;
-            
-            return found;
-         } else
-            return false;
-      };
-
-      void reset()
-      {
-         fields.clear();
-      }
-   public:
-
-      void operateField( GameMap* actmap, const MapCoordinate& pos )
-      {
-         if ( !pos.valid() )
-            return;
-         
-         if ( gamemap && gamemap != actmap ) 
-            reset();
-
-         gamemap = actmap;
-         
-         if ( fields.find( pos ) != fields.end() ) {
-            if ( fields[pos] & 2 ) {
-               reset();
-               setActive(false);
-               statusMessage("Weapon range layer disabled");
-               repaintMap();
-               return;
-            }
-         }
-         
-         if ( actmap->getField( pos )->vehicle ) {
-            if ( addUnit( actmap->getField( pos )->vehicle ) ) {
-               setActive(true);
-               statusMessage("Weapon range layer enabled");
-               repaintMap();
-            }
-         }
-      }
-      
-      UnitWeaponRangeLayer() : icon1 ( IconRepository::getIcon( "markedfield-red.png")), icon2 ( IconRepository::getIcon( "markedfield-red2.png")), gamemap(NULL) {
-         // cursorMoved.connect( SigC::slot( *this, UnitWeaponRangeLayer::cursorMoved ));
-      }
-
-      bool onLayer( int layer ) { return layer == 17; };
-      
-      void paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,  int layer, const SPoint& pos )
-      {
-         if ( fieldInfo.gamemap != gamemap && gamemap) {
-            reset();
-            gamemap = NULL;
-            return;
-         }
-         
-         if ( fieldInfo.visibility >= visible_ago) {
-            if ( fields.find( fieldInfo.pos ) != fields.end() ) {
-               int p = fields[fieldInfo.pos];
-               if ( p & 1 )
-                  fieldInfo.surface.Blit( icon1, pos );
-               if ( p & 2 )
-                  fieldInfo.surface.Blit( icon2, pos );
-            }
-         }
-      }
-};
 
 
 
@@ -573,8 +491,8 @@ ASC_MainScreenWidget::ASC_MainScreenWidget( PG_Application& application )
    int counter = 0;
    for ( CGameOptions::PanelDataContainer::iterator i = CGameOptions::Instance()->panelData.begin(); i != CGameOptions::Instance()->panelData.end(); ++i ) {
       if ( i->second.visible ) {
-         ++counter;
-         spawnPanel( i->first );
+         if ( spawnPanel( i->first ))
+            ++counter;
       }
    }
 
@@ -641,25 +559,39 @@ void displaymessage2( const char* formatstring, ... )
 
 
 
-void ASC_MainScreenWidget::spawnPanel ( const ASCString& panelName )
+bool ASC_MainScreenWidget::spawnPanel ( const ASCString& panelName )
 {
-   if ( panelName == "WindInfo" )
+   if ( panelName == "WindInfo" ) {
       spawnPanel ( WindInfo );
+      return true;
+   }
 
-   if ( panelName == "UnitInfo" )
+   if ( panelName == "UnitInfo" ) {
       spawnPanel ( UnitInfo );
+      return true;
+   }
    
-   if ( panelName == "GuiIcons" )
+   if ( panelName == "GuiIcons" ) {
       spawnPanel ( ButtonPanel );
+      return true;
+   }
 
-   if ( panelName == "OverviewMap" )
+   if ( panelName == "OverviewMap" ) {
       spawnPanel ( OverviewMap );
+      return true;
+   }
 
-   if ( panelName == "MapInfo" )
+   if ( panelName == "MapInfo" ) {
       spawnPanel ( MapControl );
+      return true;
+   }
 
-   if ( panelName == "ActionInfo" )
+   if ( panelName == "ActionInfo" ) {
       spawnPanel ( ActionInfo );
+      return true;
+   }
+   
+   return false;
 }
 
 void ASC_MainScreenWidget::spawnPanel ( Panels panel )
@@ -693,7 +625,7 @@ void ASC_MainScreenWidget::spawnPanel ( Panels panel )
    if ( panel == MapControl ) {
       if ( !mapInfoPanel || !CGameOptions::Instance()->cacheASCGUI ) {
          delete mapInfoPanel;
-         mapInfoPanel = new MapInfoPanel( this, PG_Rect(Width()-170, 0, 170, 160), mapDisplay );
+         mapInfoPanel = new MapInfoPanel( this, PG_Rect(Width()-170, 0, 170, 135), mapDisplay );
       }
       mapInfoPanel->Show();
    }
@@ -732,19 +664,19 @@ bool ASC_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
    if ( !mod  ) {
       switch ( key->keysym.sym ) {
             case SDLK_ESCAPE:
-               execUserAction_ev( ua_mainmenu );
+               executeUserAction( ua_mainmenu );
                return true;
                
             case SDLK_F1:
-               execUserAction_ev ( ua_help );
+               executeUserAction ( ua_help );
                return true;
 
             case SDLK_F3:
-               execUserAction_ev ( ua_continuenetworkgame );
+               executeUserAction ( ua_continuenetworkgame );
                return true;
 
             case SDLK_F4:
-               execUserAction_ev ( ua_networksupervisor );
+               executeUserAction ( ua_networksupervisor );
                return true;
 
             case SDLK_F8:
@@ -762,62 +694,62 @@ bool ASC_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
                return true;
 
             case SDLK_1:
-               execUserAction_ev ( ua_changeresourceview );
+               executeUserAction ( ua_changeresourceview );
                return true;
 
             case SDLK_2:
-               execUserAction_ev ( ua_toggleunitshading );
+               executeUserAction ( ua_toggleunitshading );
                return true;
 
             case SDLK_3:
-               execUserAction_ev( ua_viewunitweaponrange );
+               executeUserAction( ua_viewunitweaponrange );
                return true;
 
             case SDLK_4:
-               execUserAction_ev( ua_viewunitmovementrange );
+               executeUserAction( ua_viewunitmovementrange );
                return true;
 
                /*
             case SDLK_5:
-               execUserAction_ev ( ua_GameStatus );
+               execuseraction ( ua_GameStatus );
                return true;
                */
 
-            case SDLK_5: execUserAction_ev ( ua_showCargoLayer );
+            case SDLK_5: executeUserAction ( ua_showCargoLayer );
                return true;
 
                /*
             case SDLK_6:
-               execUserAction_ev ( ua_UnitSetInfo );
+               execuseraction ( ua_UnitSetInfo );
                return true;
                */
 
             case SDLK_7:
-               execUserAction_ev ( ua_viewterraininfo );
+               executeUserAction ( ua_viewterraininfo );
                return true;
 
             case SDLK_8:
-               execUserAction_ev ( ua_unitweightinfo );
+               executeUserAction ( ua_unitweightinfo );
                return true;
 
             case SDLK_9:
-               execUserAction_ev ( ua_viewPipeNet );
+               executeUserAction ( ua_viewPipeNet );
                return true;
 
-            case SDLK_0: execUserAction_ev( ua_visibilityInfo );
+            case SDLK_0: executeUserAction( ua_visibilityInfo );
                return true;
 
             case SDLK_BACKSPACE:               
-               execUserAction_ev( ua_undo );
+               executeUserAction( ua_undo );
                return true;
 
 
             case SDLK_PLUS:   
-            case SDLK_KP_PLUS: execUserAction_ev( ua_increase_zoom );
+            case SDLK_KP_PLUS: executeUserAction( ua_increase_zoom );
                return true;
 
             case SDLK_MINUS:   
-            case SDLK_KP_MINUS: execUserAction_ev( ua_decrease_zoom );
+            case SDLK_KP_MINUS: executeUserAction( ua_decrease_zoom );
                return true;
                
                case SDLK_F10: {
@@ -844,22 +776,22 @@ bool ASC_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
                return true;
             }
          case SDLK_l:
-               execUserAction_ev ( ua_loadrecentgame );
+               executeUserAction ( ua_loadrecentgame );
                return true;
 
             case SDLK_LEFT:
-               execUserAction_ev( ua_turnUnitLeft );
+               executeUserAction( ua_turnUnitLeft );
                return true;
 
             case SDLK_RIGHT:
-               execUserAction_ev( ua_turnUnitRight );
+               executeUserAction( ua_turnUnitRight );
                return true;
 
             default:;
       }
       switch ( key->keysym.unicode ) {
             case 26:
-               execUserAction_ev( ua_redo );
+               executeUserAction( ua_redo );
                return true;
                
             default:;
@@ -869,9 +801,15 @@ bool ASC_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
    if ( mod & KMOD_CTRL ) {
       switch ( key->keysym.sym ) {
 
-            case SDLK_0: execUserAction_ev( ua_writescreentopcx );
+            case SDLK_0: executeUserAction( ua_writescreentopcx );
                return true;
 
+            case SDLK_1: executeUserAction( ua_viewUnitinfoOverlay );
+              return true;
+
+            case SDLK_2: executeUserAction( ua_viewUnitexperienceOverlay );
+              return true;
+
             case SDLK_F10: {
                SDL_Surface* s = PG_Application::GetScreen();
                SDL_LockSurface( s );
@@ -888,39 +826,43 @@ bool ASC_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
       }
       switch ( key->keysym.unicode ) {
             case 3: // C
-               execUserAction_ev ( ua_cargosummary );
+               executeUserAction ( ua_cargosummary );
                return true;
 
             case 6: // F
-               execUserAction_ev ( ua_unitsummary );
+               executeUserAction ( ua_unitsummary );
                return true;
 
             case 7: // G
-               execUserAction_ev( ua_gotoPosition );
+               executeUserAction( ua_gotoPosition );
                return true;
 
             case 12: // L
-               execUserAction_ev ( ua_loadgame );
+               executeUserAction ( ua_loadgame );
                return true;
 
             case 14: // N
-               execUserAction_ev ( ua_newGame );
+               executeUserAction ( ua_newGame );
                return true;
 
             case 17: // Q
-               execUserAction_ev ( ua_exitgame );
+               executeUserAction ( ua_exitgame );
                return true;
 
             case 18: // R
-               execUserAction_ev( ua_createReminder );
+               executeUserAction( ua_createReminder );
                return true;
                
             case 19: // S
-               execUserAction_ev ( ua_savegame );
+               executeUserAction ( ua_savegame );
                return true;
 
+            case 20: // T
+               executeUserAction ( ua_runOpenTasks );
+               return true;
+               
             case 26: // Z
-               execUserAction_ev( ua_undo );
+               executeUserAction( ua_undo );
                return true;
 
       }
@@ -939,7 +881,7 @@ bool ASC_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
    if ( mod & KMOD_SHIFT ) {
       switch ( key->keysym.sym ) {
             case SDLK_F3:
-               execUserAction_ev ( ua_continuerecentnetworkgame );
+               executeUserAction ( ua_continuerecentnetworkgame );
                return true;
 
             default:;
