@@ -4,7 +4,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -60,7 +60,9 @@ class ASC_MainScreenWidget : public MainScreenWidget {
       ASC_MainScreenWidget( PG_Application& application );
       enum Panels { ButtonPanel, WindInfo, UnitInfo, OverviewMap, MapControl, ActionInfo };
       void spawnPanel ( Panels panel );
-      void spawnPanel ( const ASCString& panelName );
+      
+      //! spawns the panel with the given name. Returns true if such a panel exists, false otherwise
+      bool spawnPanel ( const ASCString& panelName );
    
       NewGuiHost* getGuiHost() { return guiHost; };
       DashboardPanel* getUnitInfoPanel() { return unitInfoPanel; };
