@@ -29,7 +29,7 @@
        GameMap* tempsMarked;
        Path *_path;
        Vehicle* _veh;
-       GameMap* _actmap;
+       GameMap* gamemap;
 
 
        //! returns the movement cost for the unit to travel from x1/y1 to x2/y2
@@ -50,13 +50,14 @@
            int gval;        // g in A* represents how far we've already gone
            int hval;        // h in A* represents an estimate of how far is left
            Node(): h(0,0), gval(0), hval(0) {}
-           bool operator< ( const Node& a );
+           bool operator< ( const Node& a ) const;
+           bool operator> ( const Node& a ) const;
        };
 
        int dist( HexCoord a, HexCoord b );
 
        typedef std::vector<Node> Container;
-       greater<Node> comp;
+	   std::greater<Node> comp;
 
        inline void get_first( Container& v, Node& n );
 
@@ -109,6 +110,7 @@ class AStar3D {
 
 
        class PathPoint: public MapCoordinate3D {
+             PathPoint() {};
           public:
              PathPoint ( const MapCoordinate3D& mc, int dist_, int enterHeight_, bool hasAttacked_ ) : MapCoordinate3D(mc), dist(dist_), enterHeight(enterHeight_), hasAttacked(hasAttacked_) {};
              // PathPoint ( const MapCoordinate3D& mc ) : MapCoordinate3D(mc), dist(-1), enterHeight(-1), hasAttacked(false) {};
@@ -117,6 +119,9 @@ class AStar3D {
              int dist;
              int enterHeight;
              bool hasAttacked;
+             void write( tnstream& stream ) const;
+             void read( tnstream& stream );
+             static PathPoint newFromStream( tnstream& stream );
        };
 
        typedef vector<PathPoint> Path;
@@ -140,6 +145,7 @@ class AStar3D {
        Vehicle* veh;
        GameMap* actmap;
        float vehicleSpeedFactor[8];
+       float maxVehicleSpeedFactor;
        bool markTemps;
        WindMovement* wind;
 
@@ -206,8 +212,9 @@ class AStar3D {
        /** searches for all fields that are within the range of maxDist and marks them.
            On each field one bit for each level of height will be set.
            The Destructor removes all marks.
+           \param path if non-null, all fields will be stored there
        */
-       void findAllAccessibleFields (  );
+       void findAllAccessibleFields ( vector<MapCoordinate3D>* path = NULL );
 
        //! returns the distance of the last found path, or -1 on any error
        int getDistance( );
