@@ -5,7 +5,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,12 +27,14 @@
 
 #include <stdio.h>
 #include <math.h>
+#include <iostream>
 
 #include "typen.h"
 #include "buildingtype.h"
 #include "vehicletype.h"
 #include "attack.h"
 #include "spfst.h"
+#include "gameoptions.h"
 
 #include "actions/changeunitproperty.h"
 #include "actions/consumeammo.h"
@@ -55,7 +57,7 @@ bool  AttackFormula :: checkHemming ( Vehicle*     d_eht,  int     direc )
    int x = d_eht->xpos;
    int y = d_eht->ypos; 
    getnextfield(x, y, direc);
-   tfield* fld = d_eht->getMap()->getField(x,y);
+   MapField* fld = d_eht->getMap()->getField(x,y);
 
    if ( fld )
       s_eht = fld->vehicle;
@@ -291,7 +293,7 @@ void tunitattacksunit :: setup ( Vehicle* &attackingunit, Vehicle* &attackedunit
    av.height = attackingunit->height;
    av.weapontype = attackingunit->typ->weapons.weapon[ _weapon ].getScalarWeaponType();
 
-   tfield* field = attackingunit->getMap()->getField ( attackingunit->xpos, attackingunit->ypos );
+   MapField* field = attackingunit->getMap()->getField ( attackingunit->xpos, attackingunit->ypos );
 
    if ( attackingunit->height <= chfahrend ) {
       // if ( dist <= maxmalq )
@@ -373,36 +375,11 @@ void tunitattacksunit :: setup ( Vehicle* &attackingunit, Vehicle* &attackedunit
 
 
 
-void tunitattacksunit :: setresult ( void )
+void log( const Vehicle* attacker, const Vehicle* attackee )
 {
-   _attackingunit->experience = av.experience;
-   _attackingunit->ammo[ av.weapnum ] = av.weapcount;
-
-   _attackingunit->postAttack( reactionfire );
-
-   _attackingunit->reactionfire.weaponShots[ av.weapnum]--;
-   _attackingunit->reactionfire.nonattackableUnits.push_back ( _attackedunit->networkid );
-
-   _attackedunit->damage    = dv.damage;
-   _attackingunit->damage    = av.damage;
-
-   if ( _respond ) {
-      _attackedunit->experience = dv.experience;
-      _attackedunit->ammo[ dv.weapnum ] = dv.weapcount;
-   }
-
-   /* If the attacking vehicle was destroyed, remove it */
-   if ( _attackingunit->damage >= 100 ) {
-     delete *_pattackingunit;
-     *_pattackingunit = NULL;
-   }
-
-   /* If the attacked vehicle was destroyed, remove it */
-   if ( _attackedunit->damage >= 100 ) {
-     delete *_pattackedunit;
-     *_pattackedunit = NULL;
-   }
-   gamemap->time.set ( gamemap->time.turn(), gamemap->time.move()+1);
+   if( CGameOptions::Instance()->logKillsToConsole ) 
+      std::cout << attackee->getOwner() << ";" << attacker->getOwner() << ";" << attackee->typ->id  << ";"
+            << attackee->typ->name  << ";" << attackee->experience << ";" << attacker->getMap()->time.turn() <<  "\n" ;
 }
 
 void tunitattacksunit :: setresult( const Context& context )
@@ -431,11 +408,17 @@ void tunitattacksunit :: setresult( const Context& context )
    
    GameAction* f = new InflictDamage( _attackingunit, av.damage - _attackingunit->damage );
    f->execute ( context );
+   
+   if( av.damage >= 100 )
+      log ( _attackedunit, _attackingunit );
 
+   if( dv.damage >= 100 )
+      log ( _attackingunit, _attackedunit );
+   
    GameAction* g = new InflictDamage( _attackedunit, dv.damage - _attackedunit->damage  );
    g->execute ( context );
    
-   
+
    /* If the attacking vehicle was destroyed, remove it */
    if ( av.damage >= 100 ) {
      *_pattackingunit = NULL;
@@ -506,7 +489,7 @@ void tunitattacksbuilding :: setup ( Vehicle* attackingunit, int x, int y, int w
    av.kamikaze   = attackingunit->typ->hasFunction( ContainerBaseType::KamikazeOnly  );
    av.height = attackingunit->height;
 
-   tfield* field = attackingunit->getMap()->getField ( attackingunit->xpos, attackingunit->ypos );
+   MapField* field = attackingunit->getMap()->getField ( attackingunit->xpos, attackingunit->ypos );
 
    if ( attackingunit->height <= chfahrend ) {
       av.defensebonus = field->getdefensebonus();
@@ -538,32 +521,6 @@ void tunitattacksbuilding :: setup ( Vehicle* attackingunit, int x, int y, int w
 }
 
 
-void tunitattacksbuilding :: setresult ( void )
-{
-   // _attackingunit->experience = av.experience;
-   _attackingunit->ammo[ av.weapnum ] = av.weapcount;
-
-   _attackingunit->postAttack( false );
-
-   _attackingunit->damage    = av.damage;
-   _attackedbuilding->damage    = dv.damage;
-
-   /* Remove the attacking unit if it was destroyed */
-   if ( _attackingunit->damage >= 100 ) {
-      delete _attackingunit;
-      _attackingunit = NULL;
-   }
-
-
-   /* Remove attacked building if it was destroyed */
-   if ( _attackedbuilding->damage >= 100 ) {
-     delete _attackedbuilding ;
-     _attackedbuilding = NULL;
-   }
-
-   gamemap->time.set ( gamemap->time.turn(), gamemap->time.move()+1);
-}
-
 void tunitattacksbuilding :: setresult( const Context& context )
 {
    MapCoordinate target = _attackedbuilding->getPosition();
@@ -592,7 +549,7 @@ void tmineattacksunit :: setup ( const MapCoordinate& position, int minenum, Veh
 {
    this->position = position;
    
-   tfield* mineposition = attackedunit->getMap()->getField( position );
+   MapField* mineposition = attackedunit->getMap()->getField( position );
    
    if ( mineposition->mines.empty() )
       errorMessage(" tmineattacksunit :: setup \n no mine to attack !\n" );
@@ -612,7 +569,7 @@ void tmineattacksunit :: setup ( const MapCoordinate& position, int minenum, Veh
    if ( minenum == -1 ) {
       int cnt = 1;
       av.strength = 0;
-      for ( tfield::MineContainer::iterator m = mineposition->mines.begin(); m != mineposition->mines.end(); m++ )
+      for ( MapField::MineContainer::iterator m = mineposition->mines.begin(); m != mineposition->mines.end(); m++ )
          if ( m->attacksunit ( attackedunit )) {
             int strength = m->strength;
             if ( m->type == cmantipersonnelmine   &&  (attackedunit->typ->movemalustyp ==  cmm_trooper ) )
@@ -661,35 +618,16 @@ void tmineattacksunit :: setup ( const MapCoordinate& position, int minenum, Veh
 }
 
 
-void tmineattacksunit :: setresult ( void )
-{
-   if ( _minenum == -1 ) {
-      for ( tfield::MineContainer::iterator m = _mineposition->mines.begin(); m != _mineposition->mines.end(); )
-         if ( m->attacksunit ( _attackedunit ))
-            m = _mineposition->mines.erase ( m );
-         else
-            m++;
-   } else
-      _mineposition->removemine ( _minenum );
-
-   _attackedunit->damage = dv.damage;
-
-   /* Remove the mined vehicle if it was destroyed */
-   if ( dv.damage >= 100 ) 
-     *_pattackedunit = NULL;
-
-}
-
 void tmineattacksunit :: setresult( const Context& context )
 {
    vector<GameAction*> actions;
    if ( _minenum == -1 ) {
-      for ( tfield::MineContainer::iterator m = _mineposition->mines.begin(); m != _mineposition->mines.end(); ++m)
+      for ( MapField::MineContainer::iterator m = _mineposition->mines.begin(); m != _mineposition->mines.end(); ++m)
          if ( m->attacksunit ( _attackedunit ))
             actions.push_back ( new RemoveMine(_attackedunit->getMap(), position, m->identifier));
    } else {
       int counter = 0;
-      for ( tfield::MineContainer::iterator m = _mineposition->mines.begin(); m != _mineposition->mines.end(); ++m, ++counter)
+      for ( MapField::MineContainer::iterator m = _mineposition->mines.begin(); m != _mineposition->mines.end(); ++m, ++counter)
          if ( counter == _minenum )
             actions.push_back ( new RemoveMine(_attackedunit->getMap(), position, m->identifier));
    }
@@ -731,7 +669,7 @@ void tunitattacksobject :: setup ( Vehicle* attackingunit, int obj_x, int obj_y,
 
    dist = beeline ( attackingunit->xpos, attackingunit->ypos, obj_x, obj_y );
 
-   for ( tfield::ObjectContainer::reverse_iterator o = targetField->objects.rbegin(); o != targetField->objects.rend(); o++ )
+   for ( MapField::ObjectContainer::reverse_iterator o = targetField->objects.rbegin(); o != targetField->objects.rend(); o++ )
       if ( o->typ->armor > 0 ) {
          _obji = &(*o);
          break;
@@ -757,8 +695,8 @@ void tunitattacksobject :: setup ( Vehicle* attackingunit, int obj_x, int obj_y,
    } else
       _weapon  = weapon;
 
-   const SingleWeapon *weap = &attackingunit->typ->weapons.weapon[weapon];
-   av.strength  = int ( ceil( attackingunit->weapstrength[weapon]
+   const SingleWeapon *weap = &attackingunit->typ->weapons.weapon[_weapon];
+   av.strength  = int ( ceil( attackingunit->weapstrength[_weapon]
                         * WeapDist::getWeaponStrength(weap, targetField->getWeather(), dist, attackingunit->height, _obji->typ->getEffectiveHeight() )
                         * attackingunit->typ->weapons.weapon[_weapon].targetingAccuracy[cmm_building] / 100 ));
 
@@ -771,7 +709,7 @@ void tunitattacksobject :: setup ( Vehicle* attackingunit, int obj_x, int obj_y,
    av.height = attackingunit->height;
    av.weapontype = attackingunit->typ->weapons.weapon[ _weapon ].getScalarWeaponType();
 
-   tfield* field2 = attackingunit->getMap()->getField ( attackingunit->xpos, attackingunit->ypos );
+   MapField* field2 = attackingunit->getMap()->getField ( attackingunit->xpos, attackingunit->ypos );
 
    if ( attackingunit->height <= chfahrend ) {
       av.defensebonus = field2->getdefensebonus();
@@ -800,31 +738,6 @@ void tunitattacksobject :: setup ( Vehicle* attackingunit, int obj_x, int obj_y,
 }
 
 
-void tunitattacksobject :: setresult ( void )
-{
-   // _attackingunit->experience = av.experience;
-   _attackingunit->ammo[ av.weapnum ] = av.weapcount;
-
-   _attackingunit->postAttack( false );
-
-   _obji->damage    = dv.damage;
-   _attackingunit->damage    = av.damage;
-
-   /* Remove the object if it was destroyed */
-   if ( _obji->damage >= 100 ) {
-      _attackingunit->getMap()->getField ( _x, _y )-> removeObject ( _obji->typ );
-   }
-
-   /* Remove the attacking unit if it was destroyed */
-   if ( _attackingunit->damage >= 100 ) {
-      delete _attackingunit;
-      _attackingunit = NULL;
-   }
-
-
-   gamemap->time.set ( gamemap->time.turn(), gamemap->time.move()+1);
-
-}
 
 void tunitattacksobject :: setresult( const Context& context )
 {
@@ -867,7 +780,7 @@ AttackWeap*  attackpossible( const Vehicle*     attacker, int x, int y)
    if (attacker->typ->weapons.count == 0)
       return atw;
 
-   tfield* efield = attacker->getMap()->getField(x,y);
+   MapField* efield = attacker->getMap()->getField(x,y);
 
    if ( efield->getVehicle() ) {
       if (fieldvisiblenow(efield, attacker->color/8))
@@ -886,7 +799,7 @@ AttackWeap*  attackpossible( const Vehicle*     attacker, int x, int y)
                               if (d <= attacker->typ->weapons.weapon[i].maxdistance)
                                  if (d >= attacker->typ->weapons.weapon[i].mindistance) {
                                     if (attacker->height & attacker->typ->weapons.weapon[i].sourceheight)
-                                       if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( log2( attacker->height), log2(tm))] )
+                                       if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( getFirstBit( attacker->height), getFirstBit(tm))] )
                                           if (attacker->ammo[i] > 0) {
                                              atw->strength[atw->count ] = attacker->weapstrength[i];
                                              atw->typ[atw->count ] = 1 << attacker->typ->weapons.weapon[i].getScalarWeaponType() ;
@@ -901,14 +814,14 @@ AttackWeap*  attackpossible( const Vehicle*     attacker, int x, int y)
                      }
    } else if ( efield->objects.size() ) {
       int n = 0;
-      for ( tfield::ObjectContainer::iterator j = efield->objects.begin(); j != efield->objects.end(); j++ )
+      for ( MapField::ObjectContainer::iterator j = efield->objects.begin(); j != efield->objects.end(); j++ )
          if ( j->typ->armor > 0 )
             n++;
 
       if ( n > 0 )
          if ((efield->vehicle == NULL) && ( efield->building == NULL)) {
             bool found = false;
-            for ( tfield::ObjectContainer::reverse_iterator j = efield->objects.rbegin(); j != efield->objects.rend(); ++j ) {
+            for ( MapField::ObjectContainer::reverse_iterator j = efield->objects.rbegin(); j != efield->objects.rend(); ++j ) {
                for ( int i = 0; i <= attacker->typ->weapons.count - 1; i++)
                   if (attacker->typ->weapons.weapon[i].shootable() )
                      if ( attacker->typ->weapons.weapon[i].getScalarWeaponType() == cwcannonn ||
@@ -925,7 +838,7 @@ AttackWeap*  attackpossible( const Vehicle*     attacker, int x, int y)
                                     if (d >= attacker->typ->weapons.weapon[i].mindistance) {
                                        if (attacker->height & attacker->typ->weapons.weapon[i].sourceheight )
                                           if ( attacker->typ->weapons.weapon[i].targ & j->typ->getEffectiveHeight() )
-                                             if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( log2( attacker->height), log2(j->typ->getEffectiveHeight()))] )
+                                             if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( getFirstBit( attacker->height), getFirstBit(j->typ->getEffectiveHeight()))] )
                                                 if (attacker->ammo[i] > 0) {
                                                    atw->strength[atw->count ] = attacker->weapstrength[i];
                                                    atw->num[atw->count ] = i;
@@ -977,7 +890,7 @@ bool attackpossible2u( const Vehicle* attacker, const Vehicle* target, AttackWea
                      if ( (1<<h) & attacker->typ->weapons.weapon[i].targ )
                         if (attacker->height & attacker->typ->weapons.weapon[i].sourceheight )
                            if ( attacker->typ->weapons.weapon[i].targetingAccuracy[ target->typ->movemalustyp] > 0 )
-                              if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( log2( attacker->height), h)] )
+                              if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( getFirstBit( attacker->height), h)] )
                                  if (attacker->ammo[i] > 0) {
                                     result = true;
                                     if ( atw ) {
@@ -1021,7 +934,7 @@ bool attackpossible28( const Vehicle* attacker, const Vehicle* target, AttackWea
                      if (minmalq >= attacker->typ->weapons.weapon[i].mindistance)
                         if (attacker->height & attacker->typ->weapons.weapon[i].sourceheight )
                            if ( attacker->typ->weapons.weapon[i].targetingAccuracy[ target->typ->movemalustyp ] > 0)
-                              if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( log2( attacker->height), log2(targetHeight))] )
+                              if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( getFirstBit( attacker->height), getFirstBit(targetHeight))] )
                                  if (attacker->ammo[i] > 0) {
                                     result =  true;
                                     if ( atw ) {
@@ -1063,7 +976,7 @@ bool attackpossible2n( const Vehicle* attacker, const Vehicle* target, AttackWea
                         if (dist <= attacker->typ->weapons.weapon[i].maxdistance)
                            if (dist >= attacker->typ->weapons.weapon[i].mindistance)
                               if (attacker->height & attacker->typ->weapons.weapon[i].sourceheight )
-                                 if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( log2( attacker->height), log2(target->height))] )
+                                 if ( attacker->typ->weapons.weapon[i].efficiency[6 + getheightdelta ( getFirstBit( attacker->height), getFirstBit(target->height))] )
                                     if ( attacker->typ->weapons.weapon[i].targetingAccuracy[ target->typ->movemalustyp ] > 0)
                                        if (attacker->ammo[i] > 0) {
                                           result = true;
@@ -1081,7 +994,7 @@ bool attackpossible2n( const Vehicle* attacker, const Vehicle* target, AttackWea
 }
 
 bool vehicleplattfahrbar( const Vehicle*     vehicle,
-                           const tfield*        field)
+                           const MapField*        field)
 {
    return false;
 /*
@@ -1164,11 +1077,11 @@ float WeapDist::getWeaponStrength ( const SingleWeapon* weap, int weather, int d
    float weatherFactor = 1;
    int heightEff = 100;
    if ( attacker_height != -1 && defender_height != -1 ) {
-      int hd = getheightdelta ( log2 ( attacker_height ), log2 ( defender_height ));
+      int hd = getheightdelta ( getFirstBit ( attacker_height ), getFirstBit ( defender_height ));
       heightEff = weap->efficiency[6+hd];
 
       if ( attacker_height >= chtieffliegend && weather != 0 && defender_height != -1) {
-         int weatherRelevantHeightDelta = min( abs( getheightdelta ( log2 ( attacker_height ), log2 ( defender_height ))), 3);
+         int weatherRelevantHeightDelta = min( abs( getheightdelta ( getFirstBit ( attacker_height ), getFirstBit ( defender_height ))), 3);
          if ( weather == 1 || weather == 3  )
             weatherFactor = 1 - 0.07*weatherRelevantHeightDelta;
          else
@@ -1184,7 +1097,7 @@ float WeapDist::getWeaponStrength ( const SingleWeapon* weap, int weather, int d
    return relstrength * heightEff * weatherFactor / float(weap->maxstrength * 100) ;
 
 /*   if ( attacker_height != -1 && defender_height!= -1 ) {
-      int hd = getheightdelta ( log2 ( attacker_height ), log2 ( defender_height ));
+      int hd = getheightdelta ( getFirstBit ( attacker_height ), getFirstBit ( defender_height ));
       return relstrength * weap->efficiency[6+hd] / 100 ;
    } else
       return relstrength ;
