@@ -5,7 +5,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -111,7 +111,6 @@ class tfight : public AttackFormula
       void calc ( void ) ;
 
       //! Writes the result of the attack calculation to the actual units.
-      virtual void setresult () = 0;
       virtual void setresult( const Context& context ) = 0;
 
       virtual void visit ( FightVisitor& visitor ) = 0;
@@ -157,7 +156,6 @@ class tunitattacksunit : public UnitAttacksSomething
       */
       tunitattacksunit ( Vehicle* &attackingunit, Vehicle* &attackedunit, bool respond = true, int weapon = -1, bool reactionfire = false );
       void setup ( Vehicle* &attackingunit, Vehicle* &attackedunit, bool respond, int weapon );
-      void setresult();
       void setresult( const Context& context );
 
       void visit ( FightVisitor& visitor )
@@ -195,7 +193,6 @@ class tunitattacksbuilding : public UnitAttacksSomething
       */
       tunitattacksbuilding ( Vehicle* attackingunit, int x, int y, int weapon = -1);
       void setup ( Vehicle* attackingunit, int x, int y, int weapon );
-      void setresult();
       void setresult( const Context& context );
 
       void visit ( FightVisitor& visitor )
@@ -211,7 +208,7 @@ class tunitattacksbuilding : public UnitAttacksSomething
 
 class tmineattacksunit : public tfight
 {
-      tfield* _mineposition;
+      MapField* _mineposition;
       Vehicle* _attackedunit;
       int _minenum;
       Vehicle** _pattackedunit;
@@ -236,7 +233,6 @@ class tmineattacksunit : public tfight
       */
       tmineattacksunit ( const MapCoordinate& mineposition, int minenum, Vehicle* &attackedunit );
       void setup ( const MapCoordinate& position, int minenum, Vehicle* &attackedunit );
-      void setresult();
       void setresult( const Context& context );
 
       Mine* getFirstMine();
@@ -254,7 +250,7 @@ class tmineattacksunit : public tfight
 
 class tunitattacksobject : public UnitAttacksSomething
 {
-      tfield*       targetField;
+      MapField*       targetField;
       Object*      _obji;
       int _x, _y;
 
@@ -276,7 +272,6 @@ class tunitattacksobject : public UnitAttacksSomething
       */
       tunitattacksobject ( Vehicle* attackingunit, int obj_x, int obj_y, int weapon = -1 );
       void setup ( Vehicle* attackingunit, int obj_x, int obj_y, int weapon );
-      void setresult();
       void setresult( const Context& context );
       
       Object* getTarget()
@@ -349,7 +344,7 @@ extern bool attackpossible28( const Vehicle* attacker, const Vehicle* target, At
 extern bool attackpossible2n( const Vehicle* attacker, const Vehicle* target, AttackWeap* attackweap = NULL );
 
 //! Can the vehicle drive across the field and destroy any unit there by moving over them?
-extern bool vehicleplattfahrbar( const Vehicle* vehicle, const tfield* field );
+extern bool vehicleplattfahrbar( const Vehicle* vehicle, const MapField* field );
 
 
 //! Some very old system to calculate the weapon efficiency over a given distance.
