@@ -14,7 +14,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -419,8 +419,8 @@ class collategraphicoperations {
 
 #pragma pack()
 
-//! this variable determines whether the next call to initgraphics will open a window or a fullscreen session
-extern int fullscreen;
+// this variable determines whether the next call to initgraphics will open a window or a fullscreen session
+// extern int fullscreen;
 
 //! sets the caption of the main window
 extern void setWindowCaption ( const char* s );
