@@ -5,7 +5,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@
 
 
 
-extern SDL_RWops *SDL_RWFromStream( pnstream stream );
+extern SDL_RWops *SDL_RWFromStream( tnstream* stream );
 
 class RWOPS_Handler {
       SDL_RWops *rwo;
@@ -81,19 +81,19 @@ class CharBuf {
 
 
 
-class tcompressionerror : public ASCmsgException {
+class StreamCompressionError : public ASCmsgException {
    public:
-     tcompressionerror ( const ASCString& msg, int returncode ) : ASCmsgException ( msg )
+     StreamCompressionError ( const ASCString& msg, int returncode ) : ASCmsgException ( msg )
      {
         message += "\n the returncode is ";
         message += strrr ( returncode );
      };
 };
 
-class toutofmem : public ASCexception {
+class OutOfMemoryError : public ASCexception {
   public:
    int required;
-   toutofmem ( int m ) ;
+   OutOfMemoryError ( int m ) ;
 };
 
 class tbufferoverflow : public ASCexception {
@@ -140,7 +140,11 @@ class dynamic_array {
 ////////////        Streams
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
+/**
+ * Buffers the complete contents of a stream in memory.
+ * May be useful when the original stream doesn't support seeking, but the
+ * consumer needs it.
+ */
 class MemoryStreamCopy : public tnstream {
                void* buf;
                int size;
@@ -148,7 +152,7 @@ class MemoryStreamCopy : public tnstream {
 
 
              public:
-               MemoryStreamCopy ( pnstream stream );
+               MemoryStreamCopy ( tnstream* stream );
                ~MemoryStreamCopy ( );
                void writedata ( const void* buf, int size );
                int  readdata  ( void* buf, int size, bool excpt = true );
@@ -161,8 +165,12 @@ class MemoryStreamCopy : public tnstream {
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-class tmemorystreambuf {
-           friend class tmemorystream;
+/**
+ * An in-memory storage of streamed data.
+ * A MemoryStream can be used to read or write to it
+ */
+class MemoryStreamStorage {
+           friend class MemoryStream;
 
            bool initialized;
 
@@ -171,29 +179,38 @@ class tmemorystreambuf {
            int dummy[10];
            char* buf;
         public:
-           tmemorystreambuf ( void );
-           void writetostream ( pnstream stream );
-           void readfromstream ( pnstream stram );
+           MemoryStreamStorage();
+
+           //! persist the contents in another stream
+           void writetostream ( tnstream* stream );
+
+           //! read persisted contents from another stream
+           void readfromstream ( tnstream* stream );
+
            void clear() { used= 0; };
+
            int getMemoryFootprint() const { return allocated; };
            
            const char* getBuffer() const { return buf; };
            int getSize() const { return used; };
            
-           ~tmemorystreambuf ( );
+           ~MemoryStreamStorage ( );
       };
 
-
-class tmemorystream : public tnstream {
+/**
+ * Reads data from or writes data to a MemoryStreamStorage
+ * This allows a completely volatile storage of data.
+ */
+class MemoryStream : public tnstream {
        protected:
            int   blocksize;
-           char* zeiger;
+           char* pointer;
            IOMode _mode;
            int   actmempos;
-           tmemorystreambuf* buf;
+           MemoryStreamStorage* buf;
 
         public:
-           tmemorystream ( tmemorystreambuf* lbuf, IOMode mode );
+           MemoryStream ( MemoryStreamStorage* lbuf, IOMode mode );
            virtual void writedata ( const void* nbuf, int size );
            virtual int  readdata  ( void* nbuf, int size, bool excpt = true );
            int dataavail ( void );
@@ -296,37 +313,32 @@ class tlzwstreamcompression {
 };
 
 
-class t_compressor_stream_interface {
+class CompressionStreamInterface {
            public:
              virtual void writecmpdata ( const void* buf, int size ) = 0;
              virtual int readcmpdata ( void* buf, int size, bool excpt = true ) = 0;
-             virtual ~t_compressor_stream_interface() {};
+             virtual ~CompressionStreamInterface() {};
       };
-/*
-class t_compressor_2ndbuf_filter : public t_compressor_stream_interface {
-             t_compressor_stream_interface *stream;
-             typedef deque<char> CDQ;
-             queue<char, CDQ> _queue;
-           public:
-             t_compressor_2ndbuf_filter ( t_compressor_stream_interface* strm );
-             virtual void writecmpdata ( const void* buf, int size );
-             virtual int readcmpdata ( void* buf, int size, bool excpt = true );
-             void insert_data_into_queue ( const void* buf, int size );
-             virtual ~t_compressor_2ndbuf_filter() {};
-};
-*/
 
-typedef t_compressor_stream_interface *p_compressor_stream_interface;
+
+class CompressionStreamAdapter : public CompressionStreamInterface {
+   private:
+      tnstream* stream;
+   public:
+      CompressionStreamAdapter( tnstream* compressedStream );
+      virtual void writecmpdata ( const void* buf, int size );
+      virtual int readcmpdata ( void* buf, int size, bool excpt = true );
+};
 
 class PrivateCompressionData;
 
 class libbzip_compression {
-            p_compressor_stream_interface stream;
+            CompressionStreamInterface* stream;
             PrivateCompressionData* data;
          public:
              void close_compression ( void );
              void writedata ( const void* buf, int size );
-             libbzip_compression ( p_compressor_stream_interface strm );
+             libbzip_compression ( CompressionStreamInterface* strm );
              virtual ~libbzip_compression ( );
 
 };
@@ -334,11 +346,11 @@ class libbzip_compression {
 class PrivateDecompressionData;
 
 class libbzip_decompression {
-            p_compressor_stream_interface stream;
+            CompressionStreamInterface* stream;
             PrivateDecompressionData* data;
          public:
              int  readdata  ( void* buf, int size, bool excpt = true  );
-             libbzip_decompression ( p_compressor_stream_interface strm );
+             libbzip_decompression ( CompressionStreamInterface* strm );
              virtual ~libbzip_decompression ( );
 
 };
@@ -348,7 +360,7 @@ class libbzip_decompression {
 
 
 
-class tanycompression : public t_compressor_stream_interface, public tlzwstreamcompression {
+class tanycompression : public CompressionStreamInterface, public tlzwstreamcompression {
 
                             typedef deque<char> CDQ;
                             queue<char, CDQ> _queue;
@@ -372,18 +384,6 @@ class tanycompression : public t_compressor_stream_interface, public tlzwstreamc
                              ~tanycompression ( );
 };
 
-///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
-/*
-class tn_lzw_bufstream : public tnbufstream, protected tlzwstreamcompression {
-                            public:
-                              void writedata ( const void* buf, int size );
-                              int  readdata  ( void* buf, int size, bool excpt = true  );
-                              int readlzwdata ( void* buf, int size, bool excpt = true );
-                              void writelzwdata ( const void* buf, int size );
-                              ~tn_lzw_bufstream();
-                        };
-*/
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -530,7 +530,7 @@ class tfindfile {
         /** Searches for files matching the wildcard name in all search paths specified for ASC and inside the ASC archive files.
 
             If name contains a relative directory entry ( like music / *.mp3 ), searchPosition specifies, which directories
-            will be searched for the file. Note that "Current" may be problemativ in unix environments, because the program may be
+            will be searched for the file. Note that "Current" may be problematic in Unix environments, because the program may be
             started from any directory.
         */
         tfindfile ( ASCString name, SearchPosition searchPosition = DefaultDir, SearchTypes searchTypes = All);
@@ -551,6 +551,80 @@ class tfindfile {
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+/** Data written to this stream will be encoded similar to base64 and can be retrieved as a string
+ *  \see ASCIIDecodingStream
+ */
+class ASCIIEncodingStream : public tnstream {
+   private:
+      int shift;
+      unsigned char buf;
+
+      ASCString result;
+   public:
+      ASCIIEncodingStream();
+
+      virtual void writedata ( const void* buf, int size );
+      virtual int  readdata  ( void* buf, int size, bool excpt = true );
+
+       void put( char c );
+       void flush();
+       ASCString getResult();
+};
+
+/** Reading data from an ASCII encoded String
+ *  \see  ASCIIEncodingStream
+ */
+class ASCIIDecodingStream : public tnstream {
+   private:
+      int shift;
+      unsigned char buf;
+
+      int length;
+      ASCString data;
+
+      int reverse[256];
+
+      void generateTable();
+
+      int get();
+   public:
+      ASCIIDecodingStream( const ASCString& data);
+      virtual void writedata ( const void* buf, int size );
+      virtual int  readdata  ( void* buffer, int size, bool excpt = true );
+};
+
+/**
+ * Compresses data transparently into another stream (using bzip2 compression)
+ * \see StreamDecompressionFilter
+ */
+class StreamCompressionFilter : public tnstream {
+      CompressionStreamAdapter adapter;
+      libbzip_compression compressor;
+      bool closed;
+   public:
+      StreamCompressionFilter( tnstream* outputstream );
+      virtual void writedata ( const void* buf, int size );
+      virtual int  readdata  ( void* buf, int size, bool excpt = true );
+      void close();
+      ~StreamCompressionFilter();
+};
+
+/**
+ * Deompresses data from a compressed stream (using bzip2 compression)
+ * \see StreamCompressionFilter
+ */
+class StreamDecompressionFilter : public tnstream {
+      CompressionStreamAdapter adapter;
+      libbzip_decompression decompressor;
+
+   public:
+      StreamDecompressionFilter( tnstream* inputstream );
+      virtual void writedata ( const void* buf, int size ) ;
+      virtual int  readdata  ( void* buf, int size, bool excpt = true );
+};
+
+
+/////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include "basetemp.h"
 
