@@ -46,6 +46,9 @@ const float repairEfficiencyBuilding[resourceTypeNum*resourceTypeNum] = { 1./3.,
 Building :: Building ( GameMap* actmap, const MapCoordinate& _entryPosition, const BuildingType* type, int player, bool setupImages, bool chainToField )
            : ContainerBase ( type, actmap, player ), typ ( type ), repairEfficiency ( repairEfficiencyBuilding )
 {
+   
+   viewOnMap = false;
+         
    int i;
    for ( i = 0; i < 8; i++ )
       aiparam[i] = NULL;
@@ -69,7 +72,6 @@ Building :: Building ( GameMap* actmap, const MapCoordinate& _entryPosition, con
 
    if ( chainToField )
       chainbuildingtofield ( entryPosition, setupImages );
-   plus = typ->defaultProduction;
 }
 
 
@@ -132,7 +134,8 @@ void Building :: convert ( int player, bool recursive )
          }
 
    #endif
-   if ( color < 8*8 )
+   bool hadViewOnMap = viewOnMap;
+   if ( color < 8*8  && hadViewOnMap)
       removeview();
 
    Player::BuildingList::iterator i = find ( gamemap->player[oldcol].buildingList.begin(), gamemap->player[oldcol].buildingList.end(), this );
@@ -143,7 +146,7 @@ void Building :: convert ( int player, bool recursive )
 
    color = player * 8;
 
-   if ( player < 8 )
+   if ( hadViewOnMap && player < 8 )
       addview();
 
    if ( recursive )
@@ -185,7 +188,7 @@ void Building :: registerForNewOwner( int player )
 const Surface& Building :: getPicture ( const BuildingType::LocalCoordinate& localCoordinate ) const
 {
    static Surface emptySurface;
-   tfield* fld = getField ( localCoordinate );
+   MapField* fld = getField ( localCoordinate );
    if ( fld ) {
       return typ->getPicture(localCoordinate, fld->getWeather(), _completion);
    } else
@@ -270,7 +273,7 @@ int  Building :: chainbuildingtofield ( const MapCoordinate& entryPos, bool setu
    for ( int a = 0; a < 4; a++)
       for ( int b = 0; b < 6; b++)
          if ( typ->fieldExists ( BuildingType::LocalCoordinate( a, b) )) {
-            tfield* f = getField( BuildingType::LocalCoordinate( a, b) );
+            MapField* f = getField( BuildingType::LocalCoordinate( a, b) );
             if ( !f || f->building ) {
                entryPosition = oldpos;
                return 1;
@@ -280,10 +283,10 @@ int  Building :: chainbuildingtofield ( const MapCoordinate& entryPos, bool setu
    for ( int a = 0; a < 4; a++)
       for ( int b = 0; b < 6; b++)
          if ( typ->fieldExists ( BuildingType::LocalCoordinate( a , b ) )) {
-            tfield* field = getField( BuildingType::LocalCoordinate( a, b) );
+            MapField* field = getField( BuildingType::LocalCoordinate( a, b) );
 
             if ( visible ) {
-               tfield::ObjectContainer::iterator i = field->objects.begin();
+               MapField::ObjectContainer::iterator i = field->objects.begin();
                while ( i != field->objects.end()) {
                   if ( !i->typ->canExistBeneathBuildings )
                      i = field->objects.erase ( i );
@@ -304,7 +307,7 @@ int  Building :: chainbuildingtofield ( const MapCoordinate& entryPos, bool setu
       if ( *i ) 
          (*i)->setnewposition ( entryPos.x, entryPos.y );
 
-   tfield* field = getField( typ->entry );
+   MapField* field = getField( typ->entry );
    if ( field )
       field->bdt |= getTerrainBitType(cbbuildingentry) ;
 
@@ -332,7 +335,7 @@ int  Building :: unchainbuildingfromfield ( void )
    for (int i = 0; i <= 3; i++)
       for (int j = 0; j <= 5; j++)
          if ( typ->fieldExists ( BuildingType::LocalCoordinate(i,j) ) ) {
-            tfield* fld = getField( BuildingType::LocalCoordinate(i,j) );
+            MapField* fld = getField( BuildingType::LocalCoordinate(i,j) );
             if ( fld && fld->building == this ) {
                set = 1;
                fld->building = NULL;
@@ -349,17 +352,33 @@ int  Building :: unchainbuildingfromfield ( void )
 
 void Building :: addview ( void )
 {
+   if ( viewOnMap )
+      fatalError ("void Building :: addview - the building is already viewing the map");
+
+   viewOnMap = true;
+   
    tcomputebuildingview bes ( gamemap );
    bes.init( this, +1 );
    bes.startsearch();
 }
 
+void Building :: resetview()
+{
+   viewOnMap = false;  
+}
+
+
 void Building :: removeview ( void )
 {
    if ( color != 64 ) {
+      if ( !viewOnMap )
+         fatalError ("void Building :: removeview - the building is not viewing the map");
+      
       tcomputebuildingview bes ( gamemap );
       bes.init( this, -1 );
       bes.startsearch();
+      
+      viewOnMap = false;
    }
 }
 
@@ -377,13 +396,13 @@ int Building :: getArmor ( ) const
 }
 
 
-tfield*        Building :: getField( const BuildingType::LocalCoordinate& lc ) const
+MapField*        Building :: getField( const BuildingType::LocalCoordinate& lc ) const
 {
   return gamemap->getField ( getFieldCoordinates ( lc ));
 }
 
 
-tfield*        Building :: getEntryField( ) const
+MapField*        Building :: getEntryField( ) const
 {
   return getField ( typ->entry );
 }
@@ -426,7 +445,7 @@ Building :: ~Building ()
 }
 
 
-const int buildingstreamversion = -6;
+const int buildingstreamversion = -7;
 
 
 void Building :: write ( tnstream& stream, bool includeLoadedUnits ) const
@@ -497,6 +516,7 @@ void Building :: write ( tnstream& stream, bool includeLoadedUnits ) const
        stream.writeChar(0);
 
     stream.writeInt( view );
+    stream.writeString( privateName );
 }
 
 
@@ -681,6 +701,11 @@ void Building :: readData ( tnstream& stream, int version )
        view = stream.readInt();
     else
        view = typ->view;
+    
+    if ( version <= -7 )
+       privateName = stream.readString();
+    else
+       privateName = "";
 }
 
 ASCString Building::getName ( ) const
