@@ -2,7 +2,7 @@
                           buildingtype.cpp  -  description
                              -------------------
     begin                : Fri Sep 29 2000
-    copyright            : (C) 1994-2003 by Martin Bickel
+    copyright            : (C) 1994-2010 by Martin Bickel
     email                : bickel@asc-hq.org
  ***************************************************************************/
 
@@ -302,7 +302,7 @@ void BuildingType :: read ( tnstream& stream )
       }
 
 
-      height = 1 << log2 ( stream.readInt() );
+      height = 1 << getFirstBit ( stream.readInt() );
       stream.readInt( ); // was: unitheight_forbidden =
       externalloadheight = stream.readInt( );
 
@@ -533,7 +533,7 @@ void BuildingType :: runTextIO ( PropertyContainer& pc )
       ASCString fieldNames;
       for ( int a = 0; a < 4; a++ )
          for ( int b = 0; b < 6; b++ )
-            if ( w_picture[0][0][a][b].valid() ) {
+            if ( w_picture[0][0][a][b].valid() || bi_picture[0][0][a][b] > 0 ) {
                fieldNames += LocalCoordinate( a, b).toString();
                fieldNames += " ";
             }
@@ -669,6 +669,8 @@ void BuildingType :: runTextIO ( PropertyContainer& pc )
          StringTokenizer st ( entryString );
          entry = LocalCoordinate ( st.getNextToken() );
       }
+      if ( !fieldExists( entry ))
+         pc.error( "Building " + name + " has invalid entrance position!" );
 
       pc.addInteger( "Armor", _armor );
 
