@@ -43,8 +43,10 @@ ContainerBase ::  ContainerBase ( const ContainerBaseType* bt, GameMap* map, int
    maxplus = baseType->maxplus;
    repairedThisTurn = 0;
   
+   plus = baseType->defaultProduction;
+   
    for ( int i = 0; i < map->getVehicleTypeNum(); ++i ) {
-      const Vehicletype* vt = map->getvehicletype_bypos(i);
+      const VehicleType* vt = map->getvehicletype_bypos(i);
       if ( vt ) 
          for ( int j = 0; j < bt->vehiclesInternallyProduceable.size(); ++j ) 
             if ( vt->id >= bt->vehiclesInternallyProduceable[j].from  && vt->id <= bt->vehiclesInternallyProduceable[j].to )
@@ -52,6 +54,16 @@ ContainerBase ::  ContainerBase ( const ContainerBaseType* bt, GameMap* map, int
    }
 }
 
+
+ASCString ContainerBase::getPrivateName() const
+{
+   if ( privateName.empty())
+      return getName();
+   else
+      return privateName;  
+}
+
+
 SigC::Signal1<void,ContainerBase*> ContainerBase :: anyContainerDestroyed;
 SigC::Signal1<void,ContainerBase*> ContainerBase :: anyContainerConquered;
 
@@ -114,26 +126,29 @@ int ContainerBase :: getMaxRepair ( const ContainerBase* item, int newDamage, Re
    if ( !canRepair( item ) )
       return item->damage;
 
-   int i;
-   if ( newDamage > item->damage )
-      newDamage = item->damage;
-
-   if ( item == this )
+   if ( item == this ) {
       if ( damage - repairableDamage() > newDamage )
          newDamage = damage - repairableDamage();
+   } else if ( item->getCarrier() != this ) {
+      if ( newDamage < item->baseType->minFieldRepairDamage )
+         newDamage = item->baseType->minFieldRepairDamage;
+   }
 
+   if ( newDamage > item->damage )
+      newDamage = item->damage;
+   
    int toRepair = item->damage - newDamage;
 
    Resources maxNeeded = getRepairEfficiency() * item->baseType->productionCost;
 
    Resources needed;
-   for ( i = 0; i < resourceTypeNum; i++ )
+   for ( int i = 0; i < resourceTypeNum; i++ )
       needed.resource(i) = maxNeeded.resource(i) * (item->damage-newDamage) / 100;
 
    if ( !ignoreCost ) {
       Resources avail = getResource ( needed );
    
-      for ( i = 0; i < resourceTypeNum; i++ )
+      for ( int i = 0; i < resourceTypeNum; i++ )
          if ( needed.resource(i) ) {
             int repairable = toRepair * avail.resource(i) / needed.resource(i);
             if ( item->damage - repairable > newDamage )
@@ -141,7 +156,7 @@ int ContainerBase :: getMaxRepair ( const ContainerBase* item, int newDamage, Re
          }
    }
 
-   for ( i = 0; i < resourceTypeNum; i++ )
+   for ( int i = 0; i < resourceTypeNum; i++ )
       cost.resource(i) = maxNeeded.resource(i) * (item->damage-newDamage) / 100;
 
    return newDamage;
@@ -258,7 +273,7 @@ int ContainerBase::calcShadowDist( int binaryHeight )
    if ( binaryHeight <= 3 )
       return 1;
 
-   return 6 * ( binaryHeight - log2 ( chfahrend ));
+   return 6 * ( binaryHeight - getFirstBit ( chfahrend ));
 }
 
 
@@ -300,7 +315,7 @@ void ContainerBase::paintField ( const Surface& img, Surface& dest, SPoint pos,
    } else {
       if ( height >= chfahrend && shadowDist ) {
          if ( shadowDist == -1 )
-            shadowDist = calcShadowDist( log2( height ));
+            shadowDist = calcShadowDist( getFirstBit( height ));
 
          megaBlitter< ColorTransform_None,
          ColorMerger_AlphaShadow,
@@ -449,7 +464,7 @@ bool  ContainerBase :: vehicleLoadable ( const Vehicle* vehicle, int uheight, co
       for ( ContainerBaseType::EntranceSystems::const_iterator i = baseType->entranceSystems.begin(); i != baseType->entranceSystems.end(); i++ )
          if ( (i->height_abs & uheight) || (i->height_abs == 0 ))
             if ( i->mode & ContainerBaseType::TransportationIO::In )
-               if ( i->height_rel == -100 || i->height_rel == getheightdelta ( getPosition().getNumericalHeight(), log2(uheight)  ) )
+               if ( i->height_rel == -100 || i->height_rel == getheightdelta ( getPosition().getNumericalHeight(), getFirstBit(uheight)  ) )
                   if ( (i->container_height & getPosition().getBitmappedHeight()) || (i->container_height == 0))
                      if ( vehicle->typ->hasAnyFunction(i->requiresUnitFeature) || i->requiresUnitFeature.none() )
                         if ( i->vehicleCategoriesLoadable & (1<<vehicle->typ->movemalustyp)) {
@@ -469,37 +484,16 @@ bool  ContainerBase :: vehicleLoadable ( const Vehicle* vehicle, int uheight, co
    return false;
 }
 
-int  ContainerBase :: vehicleUnloadable ( const Vehicletype* vehicleType, int carrierHeight ) const
+int  ContainerBase :: vehicleUnloadable ( const VehicleType* vehicleType, int carrierHeight ) const
 {
-   int height = 0;
-
-   if ( carrierHeight == -1 )
-      carrierHeight = getPosition().getBitmappedHeight();
+   if (carrierHeight == -1 )
+      return baseType->vehicleUnloadable( vehicleType, getPosition().getNumericalHeight());
    else
-      carrierHeight = 1 << carrierHeight;
-   
-   if ( baseType->vehicleFit ( vehicleType ))
-      for ( ContainerBaseType::EntranceSystems::const_iterator i = baseType->entranceSystems.begin(); i != baseType->entranceSystems.end(); i++ )
-         if ( i->mode & ContainerBaseType::TransportationIO::Out )
-            if ( (i->container_height & carrierHeight) || (i->container_height == 0))
-               if ( i->vehicleCategoriesLoadable & (1<<vehicleType->movemalustyp))
-                  if ( vehicleType->hasAnyFunction(i->requiresUnitFeature) || i->requiresUnitFeature.none() ) {
-                     if ( i->height_abs != 0 && i->height_rel != -100 ) {
-                        int h = 0;
-                        for ( int hh = 0; hh < 8; ++hh)
-                           if ( getheightdelta(getPosition().getNumericalHeight(), hh) == i->height_rel )
-                              h += 1 << hh;
-                        height |= i->height_abs & h;
-                     } else
-                        if ( i->height_rel != -100 )
-                           height |= 1 << (getPosition().getNumericalHeight() + i->height_rel) ;
-                        else
-                           height |= i->height_abs ;
-                  }
-   return height & vehicleType->height;
+      return baseType->vehicleUnloadable( vehicleType, carrierHeight );
+
 }
 
-const ContainerBaseType::TransportationIO* ContainerBase::vehicleUnloadSystem ( const Vehicletype* vehicleType, int height )
+const ContainerBaseType::TransportationIO* ContainerBase::vehicleUnloadSystem ( const VehicleType* vehicleType, int height )
 {
    if ( baseType->vehicleFit ( vehicleType ))
       for ( ContainerBaseType::EntranceSystems::const_iterator i = baseType->entranceSystems.begin(); i != baseType->entranceSystems.end(); i++ )
@@ -559,13 +553,13 @@ const ContainerBase::Production& ContainerBase::getProduction() const
    return productionCache;
 }
 
-Resources ContainerBase::getProductionCost( const Vehicletype* unit ) const
+Resources ContainerBase::getProductionCost( const VehicleType* unit ) const
 {
    return baseType->productionEfficiency * unit->productionCost;
 }
 
 
-void ContainerBase ::deleteProductionLine( const Vehicletype* type )
+void ContainerBase ::deleteProductionLine( const VehicleType* type )
 {
    internalUnitProduction.erase( remove( internalUnitProduction.begin(), internalUnitProduction.end(), type ), internalUnitProduction.end());
    productionCache.clear();
@@ -577,13 +571,19 @@ void ContainerBase ::deleteAllProductionLines()
    productionCache.clear();
 }
 
-void ContainerBase :: addProductionLine( const Vehicletype* type )
+void ContainerBase :: addProductionLine( const VehicleType* type )
 {
    if ( find ( internalUnitProduction.begin(), internalUnitProduction.end(), type ) == internalUnitProduction.end() )
       internalUnitProduction.push_back( type );
    productionCache.clear();
 }
 
+bool ContainerBase :: hasProductionLine( const VehicleType* type )
+{
+   return find ( internalUnitProduction.begin(), internalUnitProduction.end(), type ) != internalUnitProduction.end();
+}
+
+
 void ContainerBase :: setProductionLines( const Production& production  )
 {
    internalUnitProduction = production;
@@ -621,7 +621,7 @@ ContainerBase :: ~ContainerBase ( )
 TemporaryContainerStorage :: TemporaryContainerStorage ( ContainerBase* _cb, bool storeCargo )
 {
    cb = _cb;
-   tmemorystream stream ( &buf, tnstream::writing );
+   MemoryStream stream ( &buf, tnstream::writing );
    cb->write ( stream, storeCargo );
    _storeCargo = storeCargo;
 }
@@ -632,7 +632,7 @@ void TemporaryContainerStorage :: restore (  )
       cb->clearCargo();
    }
 
-   tmemorystream stream ( &buf, tnstream::reading );
+   MemoryStream stream ( &buf, tnstream::reading );
    cb->read ( stream );
 }
 
@@ -673,6 +673,27 @@ Player& ContainerBase :: getOwningPlayer() const
    return getMap()->getPlayer(this); 
 }
 
+void ContainerBase :: setInternalResourcePlus( const Resources& res )
+{
+   for ( int r = 0; r < Resources::count; ++r ) 
+      plus.resource(r) = min ( res.resource(r), min( maxplus.resource(r), baseType->maxplus.resource(r)));
+}
+
+void ContainerBase :: setInternalResourceMaxPlus( const Resources& res )
+{
+   for ( int r = 0; r < Resources::count; ++r ) 
+      maxplus.resource(r) = min ( res.resource(r), baseType->maxplus.resource(r));
+}
+
+Resources ContainerBase :: getInternalResourcePlus() const
+{
+   return plus;
+}
+
+Resources ContainerBase :: getInternalResourceMaxPlus() const
+{
+   return maxplus;
+}
 
 
 Resources ContainerBase :: getResourcePlus( )
