@@ -4,7 +4,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -197,6 +197,6 @@ extern int editInt( const ASCString& title, int defaultValue, int minValue = 0,
 
 
 class ActionResult;
-extern void displayActionError( const ActionResult& result );
+extern void displayActionError( const ActionResult& result, const ASCString& additionalInfo = "" );
 
 #endif
