@@ -59,7 +59,7 @@
 #include "../sg.h"
 #include "../spfst.h"
 
-const Vehicletype* selectVehicletype( ContainerBase* plant, const vector<Vehicletype*>& items );
+const VehicleType* selectVehicletype( ContainerBase* plant, const vector<VehicleType*>& items );
 
 
 class CargoDialog;
@@ -146,6 +146,14 @@ class CancelMovement : public GuiFunctions::Cancel
    public:
       CancelMovement ( PG_Widget& masterParent ) : parent( masterParent)  {};
 
+      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
+      {
+         if ( !NewGuiHost::pendingCommand )
+            parent.QuitModal();
+         
+         return true;
+      }
+
       void execute( const MapCoordinate& pos, ContainerBase* subject, int num ) {
          GuiFunctions::Cancel::execute( pos, subject, num );
          parent.QuitModal();
@@ -326,8 +334,6 @@ class CargoInfoWindow;
 class CargoDialog : public Panel
 {
 
-      ContainerControls containerControls;
-
       GuiIconHandler guiIconHandler;
 
       ContainerBase* container;
@@ -522,7 +528,7 @@ class CargoDialog : public Panel
                if ( res.successful() )
                   cargomove.release();
             } else {
-               if ( container->getCarrier() ) {
+               if ( container->getCarrier() && !targetUnit ) {
                   auto_ptr<CargoMoveCommand> cargomove ( new CargoMoveCommand( draggedUnit ));
                   cargomove->setMode( CargoMoveCommand::moveOutwards );
                   ActionResult res = cargomove->execute ( createContext( getContainer()->getMap() ));
@@ -661,10 +667,6 @@ class CargoDialog : public Panel
          else return NULL;
       };
 
-      ContainerControls& getControls() {
-         return containerControls;
-      };
-
       SigC::Signal0<void>  sigCargoChanged;
 
       void setUnitInfoWidgets( const ContainerBase* container, const ASCString& prefix ) {
@@ -1767,7 +1769,7 @@ class DamageBarWidget : public PG_ThemeWidget
 
 
 CargoDialog ::CargoDialog (PG_Widget *parent, ContainerBase* cb )
-      : Panel( parent, PG_Rect::null, "cargodialog", false ), containerControls( cb ), container(cb), setupOK(false), cargoWidget(NULL), researchWindow( NULL ), matterWindow(NULL)
+      : Panel( parent, PG_Rect::null, "cargodialog", false ), container(cb), setupOK(false), cargoWidget(NULL), researchWindow( NULL ), matterWindow(NULL)
 {
    shutdownImmediately = false;
 
@@ -2136,7 +2138,7 @@ void UnitProduction::execute( const MapCoordinate& pos, ContainerBase* subject,
    auto_ptr<ConstructUnitCommand> production ( new ConstructUnitCommand( parent.getContainer() ));
    constructUnitCommand = production.get();
 
-   const Vehicletype* v;
+   const VehicleType* v;
    {
       production->setMode( ConstructUnitCommand::internal );
       producables = production->getProduceableVehicles();
@@ -2606,13 +2608,13 @@ ASCString MoveUnitIntoInnerContainer::getName( const MapCoordinate& pos, Contain
 
 
 
-class VehicleWidget: public VehicleTypeBaseWidget
+class VehicleWidget: public VehicleBaseWidget
 {
    private:
       Vehicle* veh;
    public:
       VehicleWidget( PG_Widget* parent, const PG_Point& pos, int width, Vehicle* unit )
-            : VehicleTypeBaseWidget( parent, pos, width, unit->typ, unit->getMap()->getPlayer(unit) ) {
+            : VehicleBaseWidget( parent, pos, width, unit, unit->getMap()->getPlayer(unit) ) {
          veh = unit;
       };
 
@@ -2725,7 +2727,7 @@ void RefuelUnitDialogCommand :: execute( const MapCoordinate& pos, ContainerBase
    ser->setDestination( subject );
    ammoTransferWindow( parent.getContainer(), subject, ser.get() );
    parent.cargoChanged();
-   if ( ser->getState() == Command::Completed )
+   if ( ser->getState() == Command::Finished )
       ser.release();
 }
 
@@ -2863,8 +2865,6 @@ ASCString RecycleUnitCommandButton :: getName( const MapCoordinate& pos, Contain
    if ( !veh )
       return "";
 
-   ContainerControls cc ( parent.getContainer() );
-
    ASCString s = getCommandName( parent.getContainer() ) + " unit - ";
 
    Resources res = RecycleUnitCommand::getOutput( parent.getContainer(), veh );
