@@ -1,6 +1,6 @@
 /*
      This file is part of Advanced Strategic Command; http://www.asc-hq.de
-     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+     Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
  
      This program is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -65,8 +65,11 @@ SelectFromMap::SelectFromMap( CoordinateList& list, GameMap* map, bool justOne,
    
 
    showFieldMarking( coordinateList );
-   if ( !list.empty() )
+   if ( !list.empty() ) {
       md->cursor.goTo( *list.begin() );
+      actmap->getCursor() =  *list.begin();
+      cursorMoved();
+   }
 
    updateList();
 };
@@ -91,7 +94,7 @@ void SelectFromMap::showFieldMarking( const CoordinateList& coordinateList )
 {
    actmap->cleartemps( 7 );
    for ( CoordinateList::const_iterator i = coordinateList.begin(); i != coordinateList.end(); ++i ) {
-      tfield* fld = actmap->getField( *i );
+      MapField* fld = actmap->getField( *i );
       if ( fld )
          fld->a.temp = 1;
    }
@@ -165,7 +168,8 @@ bool SelectFromMap::listItemClicked( PG_ListBoxBaseItem* item )
       CoordinateItem* i = dynamic_cast<CoordinateItem*>(item);
       if ( i ) {
          md->cursor.goTo( i->getPos() );
-         updateFieldInfo();
+         actmap->getCursor() =  i->getPos();
+         cursorMoved();
       }
    }
    return true;
