@@ -1,6 +1,6 @@
 /*
      This file is part of Advanced Strategic Command; http://www.asc-hq.de
-     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+     Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
  
      This program is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -159,6 +159,12 @@ void MessageDialog::Init(const std::string& windowtext, int textalign, const std
    LoadThemeStyle(style);
 }
 
+void MessageDialog::SetText( const std::string& text ) 
+{
+   if ( my_textbox && my_textbox->GetText() != text )
+      my_textbox->SetText( text );
+}
+
 void MessageDialog::LoadThemeStyle(const std::string& widgettype) {
    PG_Window::LoadThemeStyle(widgettype);
 
