@@ -4,7 +4,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 #include "widgets/textrenderer-addons.h"
 #include "spfst-legacy.h"
 #include "dataversioncheck.h"
+#include "tasks/taskhibernatingcontainer.h"
 
 #ifdef WIN32
 # include "win32/win32-errormsg.h"
@@ -65,7 +66,7 @@ pfont load_font(const char* name)
 }
 
 
-void loaddata( void ) 
+void loadEditordata( void ) 
 {
    loadmessages();
 
@@ -111,7 +112,7 @@ int mapeditorMainThread ( void* _mapname )
       StartupScreen sus( "title_mapeditor.jpg", dataLoaderTicker );
       
       GraphicSetManager::Instance().loadData();
-      loaddata();
+      loadEditordata();
 
       if ( mapname && mapname[0] ) {
          /*
@@ -145,13 +146,13 @@ int mapeditorMainThread ( void* _mapname )
 
    } /* end try */
    catch ( ParsingError err ) {
-      displaymessage ( "Error parsing text file " + err.getMessage(), 2 );
+      fatalError ( "Error parsing text file " + err.getMessage() );
    }
    catch ( tfileerror err ) {
-      displaymessage ( " error loading file %s ",2, err.getFileName().c_str() );
+      fatalError ( "Error loading file " + err.getFileName() );
    } /* end catch */
    catch ( ASCmsgException err ) {
-      displaymessage ( "Error loading file %s ",2, err.getMessage().c_str() );
+      fatalError( "Error loading file " + err.getMessage() );
    }
 
    activefontsettings.font = schriften.arial8;
@@ -234,11 +235,11 @@ int main(int argc, char *argv[] )
 
    signal ( SIGINT, SIG_IGN );
 
-   fullscreen = !CGameOptions::Instance()->mapeditWindowedMode;
+   bool fullscreen = !CGameOptions::Instance()->mapeditWindowedMode;
    if ( cl->f() )
-      fullscreen = 1;
+      fullscreen = true;
    if (  cl->w() )
-      fullscreen = 0;
+      fullscreen = false;
 
    checkDataVersion();
 
@@ -278,6 +279,9 @@ int main(int argc, char *argv[] )
    mapChanged.connect( SigC::hide<GameMap*>( updateFieldInfo.slot() ) );
    mapChanged.connect( SigC::hide<GameMap*>( SigC::slot( setSaveNotification) ));
    
+   TaskHibernatingContainer::registerHooks();
+
+   
    char* buf = new char[cl->l().length()+10];
    strcpy ( buf, cl->l().c_str() );
    initializeEventHandling ( mapeditorMainThread, buf  );
