@@ -1,6 +1,6 @@
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ extern void 	     playerchange(void);
 extern void         editpolygon (Poly_gon& poly);
 // extern int        getpolygon(ppolygon *poly); //return Fehlerstatus
 
-extern tfield* getactfield();
+extern MapField* getactfield();
 
 
 extern void selectunitsetfilter ( void );
