@@ -39,7 +39,13 @@ extern bool legacyEventSystemActive();
 
 extern int initializeEventHandling ( int (*fn)(void *) , void *data );
 
-extern SDL_mutex* eventHandlingMutex;
+
+class EventHandlingMutex {
+   public:
+      EventHandlingMutex();
+      ~EventHandlingMutex();
+};
+
 
 extern void exit_asc( int returnresult );
 
@@ -115,16 +121,12 @@ extern volatile tmousesettings mouseparams;
  ***************************************************************************/
 
 
- #ifdef _SDL_
   #include "sdl/keysymbols.h"
- #endif
 
  typedef int tkey;
 
  extern char  skeypress( tkey keynr);
  extern char *get_key(tkey keynr);
- extern tkey r_key(void);
- extern int  rp_key(void);
  extern int keypress(void);
  extern void wait(void);
  extern tkey char2key (int ch);
@@ -133,6 +135,8 @@ extern volatile tmousesettings mouseparams;
  extern int exitprogram;
 
 
+ extern bool isKeyPressed(SDLKey key);
+
 /***************************************************************************
  *                                                                         *
  *   Timer routines                                                        *
