@@ -1,6 +1,6 @@
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,10 +35,10 @@ extern void researchinfo ( void );
 extern void choosetechlevel ( void );
 
 
-class tfield;
+class MapField;
 class Context;
 
-extern void giveunitaway ( tfield* fld, const Context& context );
+extern void giveunitaway ( MapField* fld, const Context& context );
 
 extern void showGameParameters ( void );
 
