@@ -39,6 +39,7 @@
 #include "campaignactionrecorder.h"
 
 #include "packagemanager.h"
+#include "tasks/abstracttaskcontainer.h"
 
 
 RandomGenerator::RandomGenerator(int seedValue){
@@ -98,7 +99,7 @@ bool OverviewMapHolder::updateField( const MapCoordinate& pos )
 {
    SPoint imgpos = OverviewMapImage::map2surface( pos );
 
-   tfield* fld = map.getField( pos );
+   MapField* fld = map.getField( pos );
    VisibilityStates visi = fieldVisibility( fld, map.getPlayerView() );
    if ( visi == visible_not ) {
       OverviewMapImage::fill ( overviewMapImage, imgpos, 0xff545454 );
@@ -109,7 +110,7 @@ bool OverviewMapHolder::updateField( const MapCoordinate& pos )
 
          int w = fld->getWeather();
          fld->typ->getQuickView()->blit( overviewMapImage, imgpos );
-         for ( tfield::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); ++i )
+         for ( MapField::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); ++i )
             if ( visi > visible_ago || i->typ->visibleago )
                i->getOverviewMapImage( w )->blit( overviewMapImage, imgpos );
 
@@ -223,6 +224,7 @@ void OverviewMapHolder::clearmap( GameMap* actmap )
 GameMap :: GameMap ( void )
    : actions(this), actionRecorder(NULL), overviewMapHolder( *this ), network(NULL), packageData(NULL)
 {
+   serverMapID = 0;
    randomSeed = rand();
    dialogsHooked = false;
 
@@ -230,8 +232,6 @@ GameMap :: GameMap ( void )
 
    state = Normal;
 
-   int i;
-
    xsize = 0;
    ysize = 0;
    field = NULL;
@@ -241,7 +241,7 @@ GameMap :: GameMap ( void )
 
    _resourcemode = 0;
 
-   for ( i = 0; i < 9; ++i ) {
+   for ( int i = 0; i < 9; ++i ) {
       player[i].setParentMap ( this, i );
       if ( i == 0 )
          player[i].stat = Player::human;
@@ -264,9 +264,6 @@ GameMap :: GameMap ( void )
    game_parameter = NULL;
    mineralResourcesDisplayed = 0;
 
-   // sigPlayerUserInteractionBegins.connect( SigC::bind( SigC::slot( GameMap::setPlayerMode ), NormalManual));
-   // sigPlayerUserInteractionEnds.connect( SigC::bind( SigC::slot( GameMap::setPlayerMode ), NormalAuto));
-
 
 #ifdef WEATHERGENERATOR
    weatherSystem  = new WeatherSystem(this, 1, 0.03);
@@ -275,6 +272,8 @@ GameMap :: GameMap ( void )
    
    
    nativeMessageLanguage = "en_US";
+   
+   sigMapCreation( *this );
 }
 
 GameMap::Campaign::Campaign()
@@ -290,12 +289,11 @@ void GameMap :: guiHooked()
    dialogsHooked = true;
 }
 
-const int tmapversion = 32;
+const int tmapversion = 34;
 
 void GameMap :: read ( tnstream& stream )
 {
    int version;
-   int i;
 
    xsize = stream.readWord();
    ysize = stream.readWord();
@@ -359,19 +357,19 @@ void GameMap :: read ( tnstream& stream )
       
    for ( int j = 0; j < 4; j++ )
       stream.readChar(); // was: different wind in different altitudes
-   for ( i = 0; i< 12; i++ )
+   for ( int i = 0; i< 12; i++ )
       stream.readChar(); // dummy
 
    _resourcemode = stream.readInt();
 
    int alliances[8][8];
    if ( version <= 10 )
-      for ( i = 0; i < 8; i++ )
+      for ( int i = 0; i < 8; i++ )
          for ( int j = 0; j < 8; j++ )
             alliances[j][i] = stream.readChar();
 
    int dummy_playername[9];
-   for ( i = 0; i< 9; i++ ) {
+   for ( int i = 0; i< 9; i++ ) {
       player[i].existanceAtBeginOfTurn = stream.readChar();
       stream.readInt(); // dummy
       stream.readInt(); // dummy
@@ -380,7 +378,9 @@ void GameMap :: read ( tnstream& stream )
       else
          player[i].research.read ( stream );
 
-      player[i].ai = (BaseAI*)stream.readInt() ;
+      // player[i].ai = (BaseAI*)
+      stream.readInt() ;
+      player[i].ai = NULL;
       player[i].stat = Player::PlayerStatus ( stream.readChar() );
       stream.readChar(); // dummy
       dummy_playername[i] = stream.readInt();
@@ -438,16 +438,16 @@ void GameMap :: read ( tnstream& stream )
    bool alliance_names_not_used_any_more[8];
    if ( version <= 9 ) {
       ___loadLegacyNetwork  = stream.readInt();
-      for ( i = 0; i < 8; i++ )
+      for ( int i = 0; i < 8; i++ )
          alliance_names_not_used_any_more[i] = stream.readInt(); // dummy
    } else {
       ___loadLegacyNetwork = false;
-      for ( i = 0; i < 8; i++ )
+      for ( int i = 0; i < 8; i++ )
          alliance_names_not_used_any_more[i] = 0;
    }
 
    if ( version <= 12 ) {
-      for ( i = 0; i< 8; i++ ) {
+      for ( int i = 0; i< 8; i++ ) {
          stream.readWord(); // cursorpos.position[i].cx = 
          stream.readWord(); // cursorpos.position[i].sx = 
          stream.readWord(); // cursorpos.position[i].cy = 
@@ -472,20 +472,20 @@ void GameMap :: read ( tnstream& stream )
    }
 
    int exist_humanplayername[9];
-   for ( i = 0; i < 8; i++ )
+   for ( int i = 0; i < 8; i++ )
       exist_humanplayername[i] = stream.readInt();
    exist_humanplayername[8] = 0;
 
 
    int exist_computerplayername[9];
-   for ( i = 0; i < 8; i++ )
+   for ( int i = 0; i < 8; i++ )
       exist_computerplayername[i] = stream.readInt();
    exist_computerplayername[8] = 0;
 
    supervisorpasswordcrc.read ( stream );
 
    if ( version <= 10 )
-      for ( i = 0; i < 8; i++ )
+      for ( int i = 0; i < 8; i++ )
          stream.readChar(); // alliances_at_beginofturn[i] = 
 
    stream.readInt(); // was objectcrc = (Object*containercrcs)
@@ -498,7 +498,7 @@ void GameMap :: read ( tnstream& stream )
    playerView = stream.readInt();
    lastjournalchange.abstime = stream.readInt();
 
-   for ( i = 0; i< 8; i++ )
+   for ( int i = 0; i< 8; i++ )
       bi_resource[i].read ( stream );
 
    int preferredfilenames = stream.readInt();
@@ -509,14 +509,14 @@ void GameMap :: read ( tnstream& stream )
 
    stream.readInt(); // dummy
    mineralResourcesDisplayed = stream.readInt();
-   for ( i = 0; i< 9; i++ )
+   for ( int i = 0; i< 9; i++ )
        player[i].queuedEvents = stream.readInt();
 
-   for ( i = 0; i < 19; i++ )
+   for ( int i = 0; i < 19; i++ )
        stream.readInt();
 
    int _oldgameparameter[8];
-   for ( i = 0; i < 8; i++ )
+   for ( int i = 0; i < 8; i++ )
        _oldgameparameter[i] = stream.readInt();
 
    if ( version >= 11 ) 
@@ -696,6 +696,12 @@ void GameMap :: read ( tnstream& stream )
     if( version >= 31 )
        properties.read( stream );
     
+    if ( version >= 33 ) 
+       tasks->read( stream );
+    
+    if ( version >= 34 )
+       serverMapID = stream.readInt();
+
 }
 
 
@@ -716,7 +722,6 @@ void GameMap :: write ( tnstream& stream )
    stream.writeString ( codeWord );
 
    
-   
    stream.writeInt( campaign.avail  );
    stream.writeChar( actplayer );
    stream.writeInt( time.abstime );
@@ -904,7 +909,9 @@ void GameMap :: write ( tnstream& stream )
     
     properties.write( stream );
     
-   
+   tasks->write( stream );
+
+   stream.writeInt( serverMapID );
 }
 
 
@@ -975,7 +982,7 @@ void GameMap :: cleartemps( int b, int value )
 
 void GameMap :: allocateFields ( int x, int y, TerrainType::Weather* terrain )
 {
-   field = new tfield[x*y];
+   field = new MapField[x*y];
    for ( int i = 0; i < x*y; i++ ) {
       if ( terrain ) {
          field[i].typ = terrain;
@@ -994,7 +1001,7 @@ void GameMap :: calculateAllObjects ( void )
    calculateallobjects( this );
 }
 
-tfield*  GameMap :: getField(int x, int y)
+MapField*  GameMap :: getField(int x, int y)
 {
    if ((x < 0) || (y < 0) || (x >= xsize) || (y >= ysize))
       return NULL;
@@ -1002,7 +1009,7 @@ tfield*  GameMap :: getField(int x, int y)
       return (   &field[y * xsize + x] );
 }
 
-const tfield*  GameMap :: getField(int x, int y) const
+const MapField*  GameMap :: getField(int x, int y) const
 {
    if ((x < 0) || (y < 0) || (x >= xsize) || (y >= ysize))
       return NULL;
@@ -1011,7 +1018,7 @@ const tfield*  GameMap :: getField(int x, int y) const
 }
 
 
-tfield*  GameMap :: getField(const MapCoordinate& pos )
+MapField*  GameMap :: getField(const MapCoordinate& pos )
 {
    return getField ( pos.x, pos.y );
 }
@@ -1226,7 +1233,7 @@ const Vehicle* GameMap :: getUnit ( int nwid, bool consistencyCheck ) const
 
 Vehicle* GameMap :: getUnit ( int x, int y, int nwid )
 {
-   tfield* fld  = getField ( x, y );
+   MapField* fld  = getField ( x, y );
    if ( !fld )
       return NULL;
 
@@ -1247,7 +1254,7 @@ ContainerBase* GameMap::getContainer ( int nwid )
    else {
       int x = (-nwid) & 0xffff;
       int y = (-nwid) >> 16;
-      tfield* fld = getField(x,y);
+      MapField* fld = getField(x,y);
       if ( !fld )
          return NULL;
 
@@ -1262,7 +1269,7 @@ const ContainerBase* GameMap::getContainer ( int nwid ) const
    else {
       int x = (-nwid) & 0xffff;
       int y = (-nwid) >> 16;
-      const tfield* fld = getField(x,y);
+      const MapField* fld = getField(x,y);
       if ( !fld )
          return NULL;
 
@@ -1418,7 +1425,7 @@ void GameMap::endRound()
     for ( int i = 0; i < getPlayerCount(); ++i )
        if ( !getPlayer(i).exist() )
           playerMask |= 1 << i;
-    tfield::resetView(this,playerMask);
+    MapField::resetView(this,playerMask);
 
     if ( getgameparameter( cgp_objectGrowthMultiplier) > 0 )
        objectGrowth();
@@ -1434,21 +1441,21 @@ int GameMap::random( int max )
 
 void GameMap::objectGrowth()
 {
-   typedef vector< pair<tfield*,int> > NewObjects;
-   map<tfield*,int> remainingGrowthTime;
+   typedef vector< pair<MapField*,int> > NewObjects;
+   map<MapField*,int> remainingGrowthTime;
 
    NewObjects newObjects;
    for ( int y = 0; y < ysize; ++y )
       for ( int x = 0; x < xsize; ++x ) {
-          tfield* fld = getField( x, y );
-          for ( tfield::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); ++i)
+          MapField* fld = getField( x, y );
+          for ( MapField::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); ++i)
              if ( i->typ->growthRate > 0 )
                 for ( int d = 0; d < 6; ++d ) {
-                   tfield* fld2 = getField ( getNeighbouringFieldCoordinate( MapCoordinate(x,y), d ));
+                   MapField* fld2 = getField ( getNeighbouringFieldCoordinate( MapCoordinate(x,y), d ));
                    if ( fld2 ) 
                       if ( i->typ->growOnUnits || ((!fld2->vehicle || fld2->vehicle->height >= chtieffliegend) && !fld2->building ))
                         if ( fld2->objects.empty() || getgameparameter( cgp_objectGrowOnOtherObjects ) > 0 ) 
-                           if ( i->remainingGrowthTime != 0 ) {
+                           if ( i->remainingGrowthTime > 0 || i->typ->growthDuration <= 0 ) {
                               double d = i->typ->growthRate * getgameparameter( cgp_objectGrowthMultiplier) / 100;
                               if ( d > 0 ) {
                                  if ( d > 0.9 )
@@ -1480,6 +1487,7 @@ void GameMap::objectGrowth()
 }
 
 SigC::Signal1<void,GameMap&> GameMap::sigMapDeletion;
+SigC::Signal1<void,GameMap&> GameMap::sigMapCreation;
 SigC::Signal2<void,GameMap*,Player&> GameMap::sigPlayerTurnEndsStatic;
 
 GameMap :: ~GameMap ()
@@ -1537,6 +1545,9 @@ GameMap :: ~GameMap ()
       field = NULL;
    }
 
+   delete tasks;
+   tasks = NULL;
+   
 }
 
 /*
@@ -1677,19 +1688,19 @@ int  GameMap::resize( int top, int bottom, int left, int right )  // positive: l
   int newx = xsize + left + right;
   int newy = ysize + top + bottom;
 
-  tfield* newfield = new tfield [ newx * newy ];
+  MapField* newfield = new MapField [ newx * newy ];
   for ( int i = 0; i < newx * newy; i++ )
      newfield[i].setMap ( this );
 
   int x;
   for ( x = ox1; x < ox2; x++ )
      for ( int y = oy1; y < oy2; y++ ) {
-        tfield* org = getField ( x, y );
-        tfield* dst = &newfield[ (x + left) + ( y + top ) * newx];
+        MapField* org = getField ( x, y );
+        MapField* dst = &newfield[ (x + left) + ( y + top ) * newx];
         *dst = *org;
      }
 
-  tfield defaultfield;
+  MapField defaultfield;
   defaultfield.setMap ( this );
   defaultfield.typ = getterraintype_byid ( 30 )->weather[0];
 
@@ -1746,6 +1757,9 @@ int  GameMap::resize( int top, int bottom, int left, int right )  // positive: l
 
    overviewMapHolder.resetSize();
 
+   if ( left || top ) 
+      sigCoordinateShift( MapCoodinateVector(left,top));
+   
    return 0;
 }
 
@@ -1765,12 +1779,12 @@ const ObjectType* GameMap :: getobjecttype_byid ( int id ) const
 }
 
 
-Vehicletype* GameMap :: getvehicletype_byid ( int id )
+VehicleType* GameMap :: getvehicletype_byid ( int id )
 {
    return vehicleTypeRepository.getObject_byID ( id );
 }
 
-const Vehicletype* GameMap :: getvehicletype_byid ( int id ) const
+const VehicleType* GameMap :: getvehicletype_byid ( int id ) const
 {
    return vehicleTypeRepository.getObject_byID ( id );
 }
@@ -1802,7 +1816,7 @@ ObjectType* GameMap :: getobjecttype_bypos ( int pos )
    return objectTypeRepository.getObject_byPos ( pos );
 }
 
-Vehicletype* GameMap :: getvehicletype_bypos ( int pos )
+VehicleType* GameMap :: getvehicletype_bypos ( int pos )
 {
    return vehicleTypeRepository.getObject_byPos ( pos );
 }
@@ -2063,7 +2077,7 @@ void AiThreat :: reset ( void )
       threat[i] = 0;
 }
 
-AiParameter :: AiParameter ( Vehicle* _unit ) : AiValue ( log2( _unit->height ))
+AiParameter :: AiParameter ( Vehicle* _unit ) : AiValue ( getFirstBit( _unit->height ))
 {
    reset( _unit );
 }
@@ -2109,7 +2123,7 @@ bool AiParameter::hasJob ( AiParameter::Job j )
 
 void AiParameter :: setNewHeight()
 {
-   AiValue::reset ( log2( unit->height ) );
+   AiValue::reset ( getFirstBit( unit->height ) );
 }
 
 
@@ -2117,7 +2131,7 @@ void AiParameter :: reset ( Vehicle* _unit )
 {
    unit = _unit;
    lastDamage = unit->damage;
-   AiValue::reset ( log2( _unit->height ) );
+   AiValue::reset ( getFirstBit( _unit->height ) );
    data = 0;
 
    clearJobs();
@@ -2169,13 +2183,13 @@ void GameMap :: ReplayInfo :: read ( tnstream& stream )
 
    for ( int i = 0; i < 8; i++ ) {
       if ( loadgui[i] ) {
-         guidata[i] = new tmemorystreambuf;
+         guidata[i] = new MemoryStreamStorage;
          guidata[i]->readfromstream ( &stream );
       } else
          guidata[i] = NULL;
 
       if ( loadmap[i] ) {
-         map[i] = new tmemorystreambuf;
+         map[i] = new MemoryStreamStorage;
          map[i]->readfromstream ( &stream );
       } else
          map[i] = NULL;
