@@ -44,6 +44,8 @@
  
  #include "actions/actioncontainer.h"
  
+ class AbstractTaskContainer;
+ 
  class RandomGenerator{
    public:
 
@@ -177,7 +179,14 @@ class PackageData;
 class GameMap {
       void operator= ( const GameMap& map );
       bool dialogsHooked;
+      int serverMapID;
    public:
+
+      void setServerMapID( int id ) { serverMapID = id; };
+      int  getServerMapID() const { return serverMapID; };
+
+      static const int maxTotalPlayers = 8;
+      
       //! the size of the map
       int          xsize, ysize;
 
@@ -185,7 +194,7 @@ class GameMap {
       int height() const { return ysize; };
 
       //! the array of fields
-      tfield*       field;
+      MapField*       field;
 
       //! the codeword for accessing a map in a campaign
       ASCString    codeWord;
@@ -193,6 +202,9 @@ class GameMap {
       //! the title of the map
       ASCString    maptitle;
 
+      void setTitle( const ASCString& title ) { maptitle = title; };
+      ASCString  getTitle() const { return maptitle; };
+      
 
       struct Campaign {
           //! is this a campaign map?
@@ -279,6 +291,7 @@ class GameMap {
             VehicleLookupCache vehicleLookupCache; 
             
             friend class SpawnUnit;
+            friend class SpawnMine;
             friend class GameMap;
                         
             
@@ -348,9 +361,9 @@ class GameMap {
       public:
           ReplayInfo ( void );
 
-          tmemorystreambuf* guidata[8];
-          tmemorystreambuf* map[8];
-          tmemorystream*    actmemstream;
+          MemoryStreamStorage* guidata[8];
+          MemoryStreamStorage* map[8];
+          MemoryStream*    actmemstream;
 
           //! if stopRecordingActions > 0 then no actions will be recorded. \see LockReplayRecording
           int stopRecordingActions;
@@ -368,6 +381,8 @@ class GameMap {
       ActionRecorder* actionRecorder;
 
       
+      AbstractTaskContainer* tasks;
+      
       ReplayInfo*  replayinfo;
 
       //! a helper variable to store some information during the loading process. No usage outside.
@@ -437,9 +452,9 @@ class GameMap {
       void setgameparameter ( GameParameter num, int value );
       void cleartemps( int b = -1, int value = 0 );
       bool isResourceGlobal ( int resource );
-      tfield* getField ( int x, int y );
-      const tfield* getField ( int x, int y ) const;
-      tfield* getField ( const MapCoordinate& pos );
+      MapField* getField ( int x, int y );
+      const MapField* getField ( int x, int y ) const;
+      MapField* getField ( const MapCoordinate& pos );
       
       
       /** @name Turn Management
@@ -468,9 +483,13 @@ class GameMap {
       SigC::Signal1<void,Player&> sigPlayerTurnHasEnded;
       SigC::Signal1<void,Player&> sigMapWon;
 
+      static SigC::Signal1<void,GameMap&> sigMapCreation;
       static SigC::Signal1<void,GameMap&> sigMapDeletion;
       static SigC::Signal2<void,GameMap*,Player&> sigPlayerTurnEndsStatic;
       
+      //! called when the map is resized and all coordinates have to be adjusted 
+      SigC::Signal1<void,const MapCoodinateVector&> sigCoordinateShift;
+      
       //! called when a new round starts (after switching from player 7 to player 0 )
       SigC::Signal0<void> newRound;
 
@@ -507,15 +526,15 @@ class GameMap {
       pterraintype getterraintype_byid ( int id );
       ObjectType* getobjecttype_byid ( int id );
       const ObjectType* getobjecttype_byid ( int id ) const;
-      Vehicletype* getvehicletype_byid ( int id );
-      const Vehicletype* getvehicletype_byid ( int id ) const;
+      VehicleType* getvehicletype_byid ( int id );
+      const VehicleType* getvehicletype_byid ( int id ) const;
       BuildingType* getbuildingtype_byid ( int id );
       const BuildingType* getbuildingtype_byid ( int id ) const;
       const Technology* gettechnology_byid ( int id );
 
       pterraintype getterraintype_bypos ( int pos );
       ObjectType* getobjecttype_bypos ( int pos );
-      Vehicletype* getvehicletype_bypos ( int pos );
+      VehicleType* getvehicletype_bypos ( int pos );
       BuildingType* getbuildingtype_bypos ( int pos );
       const Technology* gettechnology_bypos ( int pos );
 
