@@ -1,6 +1,6 @@
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2004  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -280,7 +280,7 @@ class ColorConverter<1,4>
          if ( targetSurface.GetPixelFormat().Amask() )
             ashift = targetSurface.GetPixelFormat().Ashift();
          else
-            ashift = firstBit( ~( targetSurface.GetPixelFormat().Rmask() | targetSurface.GetPixelFormat().Gmask() | targetSurface.GetPixelFormat().Bmask()));
+            ashift = getFirstBit( ~( targetSurface.GetPixelFormat().Rmask() | targetSurface.GetPixelFormat().Gmask() | targetSurface.GetPixelFormat().Bmask()));
 
       };
 
@@ -726,7 +726,7 @@ class ColorMerger_AlphaHandler<4>
                ashift = srf.GetPixelFormat().Ashift();
             } else {
                amask = ~( srf.GetPixelFormat().Rmask() | srf.GetPixelFormat().Gmask() | srf.GetPixelFormat().Bmask() );
-               ashift = firstBit(amask);
+               ashift = getFirstBit(amask);
             }
          }
       };
@@ -749,7 +749,7 @@ class ColorMerger_AlphaOverwrite : public ColorMerger_AlphaHandler<pixelsize>
 
       void assign ( PixelType src, PixelType* dest )
       {
-         if ( isOpaque(src ) ) {
+         if ( this->isOpaque(src ) ) {
             *dest = src;
          }
       };
@@ -769,7 +769,7 @@ class ColorMerger_AlphaMerge : public ColorMerger_AlphaHandler<pixelsize>
 
       void assign ( PixelType src, PixelType* dest )
       {
-         if ( isOpaque(src ) ) {
+         if ( this->isOpaque(src ) ) {
             *dest = src;
          }
       };
@@ -846,7 +846,7 @@ class ColorMerger_AlphaShadow<1> : public ColorMerger_AlphaHandler<1>
       void assign ( PixelType src, PixelType* dest )
       {
          // STATIC_CHECK ( pixelsize == 1, wrong_pixel_size );
-         if ( isOpaque(src ) ) {
+         if ( this->isOpaque(src ) ) {
             *dest = table[*dest];
          }
       };
@@ -873,7 +873,7 @@ class ColorMerger_AlphaShadow<4> : public ColorMerger_AlphaHandler<4>
 
       void assign ( PixelType src, PixelType* dest )
       {
-         if ( isOpaque(src ) ) {
+         if ( this->isOpaque(src ) ) {
             *dest = ((*dest >> 1) & 0x7f7f7f7f) | (*dest & 0xff000000 );
          }
       };
@@ -901,7 +901,7 @@ class ColorMerger_AlphaMixer<1> : public ColorMerger_AlphaHandler<1>
    protected:
       void assign ( PixelType src, PixelType* dest )
       {
-         if ( isOpaque(src ) )
+         if ( this->isOpaque(src ) )
             *dest = colormixbufchar[*dest + src*256 ];
       };
    public:
@@ -918,7 +918,7 @@ class ColorMerger_AlphaMixer<4> : public ColorMerger_AlphaHandler<4>
       void assign ( PixelType src, PixelType* dest )
       {
          // STATIC_CHECK ( pixelsize == 1, wrong_pixel_size );
-         if ( isOpaque(src ) ) {
+         if ( this->isOpaque(src ) ) {
             *dest = ((*dest >> 1) & 0x7f7f7f7f) + ((src >> 1) & 0x7f7f7f7f);
          }
       };
@@ -975,7 +975,7 @@ class ColorMerger_Alpha_XLAT_TableShifter<1> : public ColorMerger_AlphaHandler<1
       void assign ( PixelType src, PixelType* dest )
       {
          // STATIC_CHECK ( pixelsize == 1, wrong_pixel_size );
-         if ( isOpaque(src ) ) {
+         if ( this->isOpaque(src ) ) {
             *dest = table[ *dest + src*256 ];
          }
       };
