@@ -1,7 +1,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2003  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -579,7 +579,7 @@ class ColorMerger_MaskApply : public ColorMerger_AlphaHandler<pixelsize>
 
       void assign ( PixelType src, PixelType* dest )
       {
-         if ( !isOpaque(src ) )
+         if ( !this->isOpaque(src ) )
             *dest &= alphamask;
       };
 
