@@ -7,7 +7,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include "ascstring.h"
 #include "sgstream.h"
 #include "messages.h"
+#include "graphics/blitter.h"
 
 
 
@@ -50,7 +51,7 @@ extern const char* tournamentextension;
 extern void  savemap( const ASCString& name, GameMap* gamemap );
 
 //! saves the game located in #actmap to the savegame file name
-extern void  savegame( const ASCString& name, GameMap* gamemap );
+extern void  savegame( const ASCString& name, GameMap* gamemap);
 
 
 typedef Loki::Functor<GameMap*, LOKI_TYPELIST_1(const ASCString&) > MapLoadingFunction;
@@ -58,7 +59,7 @@ extern GameMap* mapLoadingExceptionChecker( const ASCString& filename, MapLoadin
 
 
 
-extern GameMap*  loadreplay( tmemorystreambuf* streambuf );
+extern GameMap*  loadreplay( MemoryStreamStorage* streambuf );
 
 //! writes all replay relevant map information of player num to the replay variable of #actmap
 extern void  savereplay( GameMap* gamemap, int num );
@@ -66,7 +67,7 @@ extern void  savereplay( GameMap* gamemap, int num );
 
 class  tspfldloaders {
        public:
-           pnstream        stream;
+           tnstream*        stream;
            GameMap*     spfld;
 
            static SigC::Signal1<void,GameMap*> mapLoaded; 
@@ -122,18 +123,26 @@ class  tgameloaders : public tspfldloaders {
 
 class tnetworkloaders : public tgameloaders {
         public:
-           GameMap*           loadnwgame ( pnstream strm );
-           int             savenwgame ( pnstream strm, const GameMap* gamemap );
+           GameMap*           loadnwgame ( tnstream* strm );
+           int             savenwgame ( tnstream* strm, const GameMap* gamemap );
+};
+
+class GameFileInformation {
+   public:
+      GameFileInformation() : turn(0) {};
+      ASCString maptitle;
+      ASCString playername;
+      int turn;
+      Surface image;
 };
 
 class tsavegameloaders : public tgameloaders {
         public:
-           GameMap*        loadgame ( pnstream strm );
+           GameMap* loadgame ( tnstream* strm );
            static GameMap*  loadGameFromFile ( const ASCString& name );
-
-           void            savegame ( pnstream strm, GameMap* gamemap, bool writeReplays = true );
-
-           void            savegame ( GameMap* gamemap, const ASCString& name );
+           GameFileInformation  loadMapimageFromFile( const ASCString& filename );
+           void  savegame ( tnstream* strm, GameMap* gamemap, bool writeReplays = true );
+           void  savegame ( GameMap* gamemap, const ASCString& name );
 };
 
 
