@@ -25,6 +25,7 @@
 
 #include <cmath>
 #include <limits>
+#include <sstream>
 
 #include "pgeventsupplier.h"
 
@@ -110,7 +111,6 @@ void ContainerInfoLayer::paintSingleField( const MapRenderer::FieldRenderInfo& f
    }
 }
 
-
  
 class ResourceGraphLayer : public MapLayer {
       void paintBar( const MapRenderer::FieldRenderInfo& fieldInfo, const SPoint& pos, int row, int amount, int color ) {
@@ -222,7 +222,7 @@ void PipeLayer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,
                pipeline->display( fieldInfo.surface, pos, o->dir, 0 );
             else {
                bool objfound = false;
-               for ( tfield::ObjectContainer::iterator i = fieldInfo.fld->objects.begin(); i != fieldInfo.fld->objects.end(); ++i )
+               for ( MapField::ObjectContainer::iterator i = fieldInfo.fld->objects.begin(); i != fieldInfo.fld->objects.end(); ++i )
                   if ( i->typ->fieldModification[0].terrain_or.test( cbpipeline ) ) {
                      pipeline->display( fieldInfo.surface, pos, i->dir, 0 );
                      objfound = true;
@@ -242,6 +242,7 @@ void PipeLayer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,
 
 class ReactionFireLayer : public MapLayer {
       Surface& image;
+
    public: 
       ReactionFireLayer() : image ( IconRepository::getIcon("rf-icon.png")) {} ;
       bool onLayer( int layer ) { return layer == 17; };
@@ -258,7 +259,78 @@ void ReactionFireLayer::paintSingleField( const MapRenderer::FieldRenderInfo& fi
    }
 }
 
+//The Class UnitInfoLayer paint informations about the health and the fuel on the top of the unit
+class UnitInfoLayer : public MapLayer {
 
+   Surface& image;
+   void paintBar( const MapRenderer::FieldRenderInfo& fieldInfo, const SPoint& pos, int position, int max, int FromTop, int color, bool OverrideColor  )
+   {
+	   float FlLength = ((float)29 / (float)max * position);
+	   int length = int(floor(FlLength));
+	   // int maxlength = 29;
+	   int paintcolor;
+	   if (OverrideColor == true) {
+		   if (length > 20)
+			   paintcolor = 0x00FF04;
+		   else if (length > 10)
+			   paintcolor = 0xFBFF00;
+		   else if (length >= 0)
+			   paintcolor = 0xFF0400;
+	   }
+	   else paintcolor = color;
+       paintFilledRectangle<4>( fieldInfo.surface, SPoint( pos.x + 9 , pos.y + FromTop), length, 3,  ColorMerger_ColoredOverwrite<4>( paintcolor ) );
+   };
+
+
+   public: 
+      UnitInfoLayer() : image ( IconRepository::getIcon("unitinfobg.png")) {} ;
+      bool onLayer( int layer ) { return layer == 17; };
+      void paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,  int layer, const SPoint& pos );
+};
+
+void UnitInfoLayer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,  int layer, const SPoint& pos )
+{
+
+
+     if ( fieldInfo.visibility > visible_ago) {
+       if ( fieldInfo.fld->vehicle ) {
+    	   if ( ( fieldInfo.fld->vehicle->getOwner() == fieldInfo.playerView ) || (fieldInfo.visibility == visible_all) || ((fieldInfo.fld->vehicle->height >= chschwimmend) && (fieldInfo.fld->vehicle->height <= chhochfliegend))) {
+    	  MegaBlitter<colorDepth,colorDepth,ColorTransform_None,ColorMerger_AlphaMerge> blitter;
+			//paint the BGimage
+			blitter.blit( image, fieldInfo.surface, pos);
+			//paint the bars
+			//1. damage / health
+			paintBar( fieldInfo, pos, 100-fieldInfo.fld->vehicle->damage, 100, 1,  0, true );
+			//2. fuel
+			paintBar( fieldInfo, pos, fieldInfo.fld->vehicle->getTank().fuel, fieldInfo.fld->vehicle->getStorageCapacity().fuel, 4,  0xFFB700, false );
+    	 }
+      }   
+   }
+}
+
+//The class UnitTraining paints the traininglevel at the bottom of the unit
+class UnitTrainingLayer : public MapLayer {
+
+   public: 
+      bool onLayer( int layer ) { return layer == 17; };
+      void paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,  int layer, const SPoint& pos );
+};
+
+
+void UnitTrainingLayer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInfo,  int layer, const SPoint& pos )
+{
+    if ( fieldInfo.visibility > visible_ago) {
+      if ( fieldInfo.fld->vehicle ) {
+   	   if ( ( fieldInfo.fld->vehicle->getOwner() == fieldInfo.playerView ) || (fieldInfo.visibility == visible_all) || ((fieldInfo.fld->vehicle->height >= chschwimmend) && (fieldInfo.fld->vehicle->height <= chhochfliegend))) {
+
+         MegaBlitter<colorDepth,colorDepth,ColorTransform_None,ColorMerger_AlphaMerge> blitter;
+		ASCString training = "unitlevel-" + ASCString::toString(fieldInfo.fld->vehicle->experience+1) +".png";
+		blitter.blit( IconRepository::getIcon(training), fieldInfo.surface, pos);
+   	   }
+         
+      }   
+   }
+}
 
 class WeaponRange : public SearchFields
 {
@@ -346,7 +418,7 @@ void MapRenderer::readData()
 
 int MapRenderer::bitmappedHeight2pass( int height )
 {
-   return log2(height) * 2 + 2;
+   return getFirstBit(height) * 2 + 2;
 }
 
 
@@ -358,7 +430,7 @@ void MapRenderer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInf
       if ( !(layer & 1 ))
          binaryUnitHeight = 1 << (( layer-2)/2);
    
-   tfield* fld = fieldInfo.fld;
+   MapField* fld = fieldInfo.fld;
 
    if ( layer == 0 && fieldInfo.visibility >= visible_ago )
       fld->typ->paint ( fieldInfo.surface, pos );
@@ -381,7 +453,7 @@ void MapRenderer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInf
 
    // display objects
    if ( layer & 1 )
-      for ( tfield::ObjectContainer::iterator o = fld->objects.begin(); o != fld->objects.end(); o++ ) {
+      for ( MapField::ObjectContainer::iterator o = fld->objects.begin(); o != fld->objects.end(); o++ ) {
          int h = o->typ->imageHeight;
          if ( fieldInfo.visibility > visible_ago || (o->typ->visibleago && fieldInfo.visibility >= visible_ago ))
             if (  h >= ((layer-1)/2)*30 && h < (layer-1)/2*30+30 )
@@ -396,7 +468,7 @@ void MapRenderer::paintSingleField( const MapRenderer::FieldRenderInfo& fieldInf
       
       if ( fieldInfo.visibility == visible_all )
          if ( !fld->mines.empty() && layer == 7 ) {
-            for ( tfield::MineContainer::const_iterator i = fld->mines.begin(); i != fld->mines.end(); ++i )
+            for ( MapField::MineContainer::const_iterator i = fld->mines.begin(); i != fld->mines.end(); ++i )
                i->paint( fieldInfo.surface, pos );
          }
      
@@ -570,7 +642,9 @@ MapDisplayPG::MapDisplayPG ( MainScreenWidget *parent, const PG_Rect r )
    addMapLayer( new ContainerInfoLayer(), "container" );
    addMapLayer( new PipeLayer()         , "pipes" );
    addMapLayer( new ReactionFireLayer() , "reactionfire" );
-   
+   addMapLayer( new UnitInfoLayer()     , "unitinfo" );
+   addMapLayer( new UnitTrainingLayer() , "unittraining" );
+
    parent->lockOptionsChanged.connect( SigC::slot( *this, &MapDisplayPG::lockOptionsChanged ));
    GameMap::sigMapDeletion.connect( SigC::slot( *this, &MapDisplayPG::sigMapDeleted ));
 }
@@ -1410,7 +1484,7 @@ void MapDisplayPG::displayAddons( Surface& surf, int pass)
    if( additionalUnit ) 
       if ( pass == bitmappedHeight2pass( additionalUnit->height ) )  {
          SPoint p = mapViewPos2internalPos( additionalUnit->getPosition() - offset );
-         if ( p.x >= 0 && p.y >= 0 && p.x + fieldsizex + ContainerBase::calcShadowDist(log2(chsatellit)) < surf.w() && p.y + fieldsizey  + ContainerBase::calcShadowDist(log2(chsatellit)) < surf.h() )
+         if ( p.x >= 0 && p.y >= 0 && p.x + fieldsizex + ContainerBase::calcShadowDist(getFirstBit(chsatellit)) < surf.w() && p.y + fieldsizey  + ContainerBase::calcShadowDist(getFirstBit(chsatellit)) < surf.h() )
             additionalUnit->paint( surf, p, false, -1 );
       }
 
