@@ -54,7 +54,7 @@ class MapRenderer {
                Surface& surface;
                VisibilityStates visibility;
                int playerView;
-               tfield* fld;
+               MapField* fld;
                MapCoordinate pos;
                GameMap* gamemap;
       };
@@ -105,7 +105,7 @@ class MapRenderer {
 
 
 class MapLayer {
-      bool active;
+   bool active;
    protected:
       MapLayer() : active(true) {};
    public:
@@ -118,6 +118,7 @@ class MapLayer {
 
 
 
+
 class MainScreenWidget;
 
 
