@@ -43,6 +43,9 @@
 #include "gameoptions.h"
 #include "widgets/dropdownselector.h"
 #include "dialogs/fileselector.h"
+#include "weaponrangelayer.h"
+
+#include "mapdisplay.h"
 
 Maped_MainScreenWidget*  mainScreenWidget = NULL ;
 
@@ -183,6 +186,7 @@ void Menu::setup()
     addbutton ( "edit map ~P~arameters",        act_setmapparameters );
     addbutton ( "setup item ~F~ilters\tctrl+h",  act_setunitfilter );
     addbutton ( "select ~G~raphic set",         act_selectgraphicset );
+    addbutton ( "show weapon range\tctrl+r", act_showweapnrange );
 
    addfield ("~D~evelopment");
     addbutton ( "Dump ~B~uilding",          act_dumpBuilding );
@@ -190,6 +194,8 @@ void Menu::setup()
     addbutton ( "Dump ~V~ehicle",          act_dumpVehicle );
     addbutton ( "Dump all Vehicles",       act_dumpAllVehicleDefinitions );
     addbutton ( "Dump ~O~bject",          act_dumpObject );
+    addbutton ( "Dump all Objects",       act_dumpAllObjects );
+    addbutton ( "Dump all Terrain",       act_dumpAllTerrain );
     addbutton ( "Locate Item by ~I~D",    act_locateItemByID );
    currentMenu->addSeparator();
     addbutton ( "Exchange ~G~raphics",          act_exchangeGraphics );
@@ -498,8 +504,18 @@ Maped_MainScreenWidget::Maped_MainScreenWidget( PG_Application& application )
    addContextAction( new ContextMenu::FieldResources );
    addContextAction( new ContextMenu::DeleteTopObject );
    addContextAction( new ContextMenu::DeleteAllObjects );
+   
+   weaponRangeLayer = new UnitWeaponRangeLayer();
+   mapDisplay->addMapLayer( weaponRangeLayer, "weaprange" );
+   
 }
 
+void Maped_MainScreenWidget::showWeaponRange( GameMap* gamemap, const MapCoordinate& pos )
+{
+   weaponRangeLayer->operateField( gamemap, pos );
+}
+
+
 void Maped_MainScreenWidget::playerChanged( int player )
 {
    static int recursionPreventer = 0;
@@ -841,7 +857,7 @@ bool Maped_MainScreenWidget::eventKeyDown(const SDL_KeyboardEvent* key)
             return true;
                         
          case 18: // R
-            execaction_ev(act_repaintdisplay);
+            execaction_ev(act_showweapnrange);
             return true;
    
          case 19 :  // S
