@@ -4,7 +4,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 class Menu;
 class NewGuiHost;
 class MapDisplayPG;
+class UnitWeaponRangeLayer;
 
 class SelectionItemWidget : public PG_Widget {
       const Placeable* it;
@@ -102,6 +103,9 @@ public:
 
     void addContextAction( ContextAction* contextAction );
    
+    
+    void showWeaponRange( GameMap* gamemap, const MapCoordinate& pos );
+    
 protected:
 
     bool clickOnMap( const MapCoordinate& field, const SPoint& pos, bool changed, int button, int prio);
@@ -124,6 +128,8 @@ protected:
     ~Maped_MainScreenWidget() { };
    private:
       bool runContextAction  (PG_PopupMenu::MenuItem* menuItem );
+      UnitWeaponRangeLayer* weaponRangeLayer;
+      
 };
 
 //! displays a message in the status line of ASC
