@@ -23,21 +23,29 @@
 class Context;
 
 //! a single field of the map
-class  tfield {
+class  MapField {
     GameMap* gamemap;
     void init();
   protected:
-    tfield (  );
+    MapField (  );
     friend class GameMap;
   public:
-    tfield ( GameMap* gamemap_ );
-    void operator= ( const tfield& f );
+    MapField ( GameMap* gamemap_ );
+    void operator= ( const MapField& f );
 
     void setMap ( GameMap* gamemap_ ) { gamemap = gamemap_; };
     GameMap* getMap() const { return gamemap; };
 
     //! the terraintype of the field
     TerrainType::Weather* typ;
+    
+    //! returns the terrain of the field
+    const TerrainType* getTerrainType() const;
+    
+    
+    //! changes the terrain type to a new one; weather is not changed
+    void changeTerrainType( const TerrainType* terrain );
+    
 
     /** mineral resources on this field. 
         \note that mineral resources are different from #Resources , there is a factor of #resource_fuel_factor and #resource_material_factor in between
@@ -110,7 +118,7 @@ class  tfield {
     //! Interface for removing objects from a field when it turns out that they can no longer exist
     class ObjectRemovalStrategy {
        public:
-          virtual void removeObject( tfield* fld, const ObjectType* obj ) = 0;
+          virtual void removeObject( MapField* fld, const ObjectType* obj ) = 0;
           virtual ~ObjectRemovalStrategy() {};
     };
     
@@ -128,7 +136,7 @@ class  tfield {
         \param force remove the object even if there are obstacles on the field (like a building standing on the object)
         \returns if the removal was successful
     */
-    bool removeObject ( const ObjectType* obj, bool force = false );
+    bool removeObject ( const ObjectType* obj, bool force = false, ObjectRemovalStrategy* objectRemovalStrategy = NULL );
 
     //! sorts the objects. Since objects can be on different levels of height, the lower one must be displayed first
     void sortobjects ( void );
@@ -188,6 +196,12 @@ class  tfield {
     //! returns the building if there is one with its entrance on this field
     Building* getBuildingEntrance();
     
+    //! if there is a building on the field, the building is deleted (may affect othere fields too, depending on building size)
+    void removeBuilding();
+    
+    //! if there is a unit on the field, the unit will be deleted 
+    void removeUnit();
+    
     //! put a mine of type typ for player owner and a punch of strength on the field. Strength is an absolute value (unlike the basestrength of a mine or the punch of the mine-weapon, which are just factors)
     bool  putmine ( int owner, MineTypes typ, int strength );
 
@@ -223,7 +237,7 @@ class  tfield {
 
     int getMemoryFootprint() const;
 
-    ~tfield();
+    ~MapField();
   private:
     TerrainType::MoveMalus __movemalus;
 };
