@@ -1,6 +1,6 @@
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ const char* letter[] = { "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K",
 char strstring[1000];
 
 
-int firstBit(int zahl)
+int getFirstBit(int zahl)
 {
    if (zahl != 0) {
       int log = 0;
@@ -56,13 +56,6 @@ int firstBit(int zahl)
 }
 
 
-char* strr ( int a ) {
-   char* s;
-   s = new char [33];
-   itoa ( a, s, 10 );
-   return s;
-}
-
 
 char* strrr ( int a ) {
    itoa ( a, strstring, 10 );
@@ -80,12 +73,6 @@ char* strrr ( double f ) {
 }
 
 
-void beep ( void )
-{
-   printf("\a");
-}
-
-
 typedef unsigned int UNS_32_BITS;
 
 
