@@ -8,7 +8,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -104,7 +104,7 @@ void toldfont::read ( tnstream& stream )
    groundline = stream.readChar();
 }
 
-pfont        loadfont( pnstream stream )
+pfont        loadfont( tnstream* stream )
 {
    toldfont     *font1;
    char *p;
