@@ -74,7 +74,7 @@ const ObjectType::FieldModification&  ObjectType::getFieldModification ( int wea
    return fieldModification[getWeather(weather)];
 }
 
-bool  ObjectType :: buildable ( tfield* fld ) const
+bool  ObjectType :: buildable ( MapField* fld ) const
 {
    #ifndef converter
    if ( fld->building && !growOnUnits )
@@ -402,7 +402,7 @@ class Smoothing {
          GameMap* actmap;
        public:
          Smoothing ( GameMap* gamemap ) : actmap ( gamemap ) {};
-         tfield* getfield ( int x, int y )
+         MapField* getfield ( int x, int y )
          {
             return actmap->getField ( x, y );
          }
@@ -446,7 +446,7 @@ class Smoothing {
                int x1 = x;
                int y1 = y;
                getnextfield ( x1, y1, d );
-               tfield* fld = getfield ( x1, y1 );
+               MapField* fld = getfield ( x1, y1 );
                if ( fld ) {
 
                   Object* obj = fld->checkForObject ( o );
@@ -471,7 +471,7 @@ class Smoothing {
                int x1 = x;
                int y1 = y;
                getnextfield ( x1, y1, d );
-               tfield* fld = getfield ( x1, y1 );
+               MapField* fld = getfield ( x1, y1 );
                if ( fld ) {
 
                   if ( IsInSetOfWord ( fld->typ->bi_pict, Arr ))
@@ -550,7 +550,7 @@ class Smoothing {
                           Res = 1;
                     }
                  } else {
-                    tfield* fld = getfield ( X, Y );
+                    MapField* fld = getfield ( X, Y );
                     TerrainType::Weather* old = fld->typ;
                     // int odir = fld->direction;
 
@@ -761,9 +761,9 @@ void calculateforest( GameMap* actmap, ObjectType* woodObj )
 {
    for ( int y = 0; y < actmap->ysize ; y++)
      for ( int x = 0; x < actmap->xsize ; x++) {
-        tfield* fld = actmap->getField(x,y);
+        MapField* fld = actmap->getField(x,y);
 
-        for ( tfield::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); i++ )
+        for ( MapField::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); i++ )
            if ( i->typ == woodObj )
               i->dir = 0;
      }
@@ -778,16 +778,16 @@ void calculateforest( GameMap* actmap, ObjectType* woodObj )
       changed = 0;
       for ( int y = 0; y < actmap->ysize ; y++)
          for ( int x = 0; x < actmap->xsize ; x++) { 
-            tfield* fld = actmap->getField(x,y);
+            MapField* fld = actmap->getField(x,y);
    
-            for ( tfield::ObjectContainer::iterator o = fld->objects.begin(); o != fld->objects.end(); o++ )
+            for ( MapField::ObjectContainer::iterator o = fld->objects.begin(); o != fld->objects.end(); o++ )
                if ( o->typ == woodObj ) {
                   int c = 0;
                   for ( int i = 0; i < sidenum; i++) {
                      int a = x;
                      int b = y;
                      getnextfield( a, b, i );
-                     tfield* fld2 = actmap->getField(a,b);
+                     MapField* fld2 = actmap->getField(a,b);
 
                      if ( fld2 ) {
                         Object* oi = fld2->checkForObject ( o->typ );
@@ -842,7 +842,7 @@ int ObjectType :: getMemoryFootprint() const
 
 
 
-const int object_version = 21;
+const int object_version = 22;
 
 void ObjectType :: read ( tnstream& stream )
 {
@@ -969,6 +969,8 @@ void ObjectType :: read ( tnstream& stream )
                      weatherPicture[ww].flip[n] = 0;
                }
             }
+            if ( version >= 22 )
+               weatherPicture[ww].originalFilename = stream.readString();
          }
 
       if ( version >= 16 )
@@ -1068,6 +1070,7 @@ void ObjectType :: write ( tnstream& stream ) const
              }
              stream.writeInt ( weatherPicture[ww].flip.at(l) );
           }
+          stream.writeString( weatherPicture[ww].originalFilename );
        }
 
     stream.writeInt( namingMethod );
@@ -1218,30 +1221,38 @@ void ObjectType :: runTextIO ( PropertyContainer& pc )
                s = "object";
                s += strrr(id);
             }
-            pc.addImageArray ( "picture",   weatherPicture[i].images, s + weatherAbbrev[i] );
+            ASCString filename = s + weatherAbbrev[i];
+            pc.addImageArray ( "picture",   weatherPicture[i].images, filename );
+            if ( pc.isReading() )
+               weatherPicture[i].originalFilename = filename;
+            else
+               pc.addString( "OriginalImageFilename", weatherPicture[i].originalFilename );
+            
             weatherPicture[i].bi3pic.resize( weatherPicture[i].images.size() );
             weatherPicture[i].flip.resize( weatherPicture[i].images.size() );
 
-            if ( pc.find ( "FlipPictures" ) ) {
+            if ( pc.find ( "FlipPictures" ) || !pc.isReading() ) {
                vector<int>   imgReferences;
                imgReferences.resize ( weatherPicture[i].images.size() );
 
-               for ( int j = 0; j < weatherPicture[i].images.size(); j++ ) {
-                  weatherPicture[i].bi3pic[j] = -1;
-                  weatherPicture[i].flip[j] = 0;
-                  imgReferences[j] = -1;
-               }
+               if ( pc.isReading() )
+                  for ( int j = 0; j < weatherPicture[i].images.size(); j++ ) {
+                     weatherPicture[i].bi3pic[j] = -1;
+                     weatherPicture[i].flip[j] = 0;
+                     imgReferences[j] = -1;
+                  }
 
                pc.addIntegerArray ( "FlipPictures", weatherPicture[i].flip );
                pc.addIntegerArray ( "ImageReference", imgReferences );
 
-               for ( int j = 0; j < weatherPicture[i].images.size(); j++ )
-                  if ( j < imgReferences.size() && imgReferences[j] >= 0 && imgReferences[j] < weatherPicture[i].images.size() )
-                     weatherPicture[i].images[j] = weatherPicture[i].images[imgReferences[j]];
-
-               while ( weatherPicture[i].flip.size() < weatherPicture[i].images.size() )
-                  weatherPicture[i].flip.push_back(0);
-
+               if ( pc.isReading() ) {
+                  for ( int j = 0; j < weatherPicture[i].images.size(); j++ )
+                     if ( j < imgReferences.size() && imgReferences[j] >= 0 && imgReferences[j] < weatherPicture[i].images.size() )
+                        weatherPicture[i].images[j] = weatherPicture[i].images[imgReferences[j]];
+   
+                  while ( weatherPicture[i].flip.size() < weatherPicture[i].images.size() )
+                     weatherPicture[i].flip.push_back(0);
+               }
             } else {
                for ( int u = 0; u < weatherPicture[i].images.size(); u++ ) {
                   weatherPicture[i].bi3pic[u] = -1;
@@ -1272,7 +1283,7 @@ void ObjectType :: runTextIO ( PropertyContainer& pc )
 
          }
          
-         if ( pc.find ( "DisplayMethod" ) ) {
+         if ( pc.find ( "DisplayMethod" ) || !pc.isReading() ) {
             pc.addNamedInteger( "DisplayMethod", displayMethod, objectDisplayingMethodNum, objectDisplayingMethodTags );
             if ( displayMethod == 2 && pc.isReading() && weatherPicture[i].images[0].GetPixelFormat().BitsPerPixel() != 8 )
                pc.error("Error parsing object " + name + " (ID=" + ASCString::toString(id)+"): invalid image; displaymethod=translation is only a available for 8 Bit images");
