@@ -2,7 +2,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ void tsearchreactionfireingunits :: initLimits()
          maxshootdist[i] = 0;
 
       for (int i = 0; i < vehicleTypeRepository.getNum(); i++ ) {
-         Vehicletype* fzt = vehicleTypeRepository.getObject_byPos ( i );
+         VehicleType* fzt = vehicleTypeRepository.getObject_byPos ( i );
          if ( fzt )
             for (int j = 0; j < fzt->weapons.count; j++ )
                if ( fzt->weapons.weapon[j].shootable() )
@@ -165,7 +165,7 @@ void tsearchreactionfireingunits :: init ( Vehicle* vehicle, const AStar3D::Path
       if ( i->y < y1 )
          y1 = i->y ;
    }
-   findOffensiveUnits ( vehicle, log2 ( vehicle->height ), x1,y1,x2,y2);
+   findOffensiveUnits ( vehicle, getFirstBit ( vehicle->height ), x1,y1,x2,y2);
           
 }
 
@@ -201,7 +201,7 @@ void tsearchreactionfireingunits :: removeunit ( Vehicle* vehicle )
 
 int tsearchreactionfireingunits :: attack( Vehicle* attacker, Vehicle* target, const Context& context )
 {
-   tfield* fld = target->getMap()->getField( target->getPosition() );
+   MapField* fld = target->getMap()->getField( target->getPosition() );
    
    
    int result = 0;
@@ -280,7 +280,7 @@ int  tsearchreactionfireingunits :: checkfield ( const MapCoordinate3D& pos, Veh
    int attacks = 0;
    int result = 0;
 
-   tfield* fld = gamemap->getField( pos.x, pos.y );
+   MapField* fld = gamemap->getField( pos.x, pos.y );
 
    for ( int i = 0; i < 8; i++ ) {
       if ( fieldvisiblenow ( fld, i )) {
