@@ -72,6 +72,71 @@ trunreplay runreplay;
 int startreplaylate = 0;
 
 
+enum trpl_actions { rpl_attack,
+   rpl_move, 
+   rpl_changeheight, 
+   rpl_convert, 
+   rpl_remobj, 
+   rpl_buildobj, 
+   rpl_putbuilding,
+   rpl_removebuilding, 
+   rpl_putmine, 
+   rpl_removemine,
+   rpl_produceunit, 
+   rpl_removeunit,
+   rpl_trainunit,
+   rpl_reactionfire, 
+   rpl_finished, 
+   rpl_shareviewchange, 
+   rpl_alliancechange,
+   rpl_move2, 
+   rpl_buildtnk,
+   rpl_refuel, 
+   rpl_bldrefuel, 
+   rpl_move3, 
+   rpl_changeheight2,
+   rpl_buildtnk2,
+   rpl_moveUnitUpDown,
+   rpl_move4,
+   rpl_productionResourceUsage,
+   rpl_buildtnk3,
+   rpl_refuel2,
+   rpl_buildobj2,
+   rpl_remobj2,
+   rpl_repairUnit,
+   rpl_repairUnit2,
+   rpl_refuel3,
+   rpl_produceAmmo,
+   rpl_buildtnk4,
+   rpl_buildProdLine,
+   rpl_removeProdLine,
+   rpl_setResearch,
+   rpl_techResearched,
+   rpl_putbuilding2,
+   rpl_setGeneratorStatus,
+   rpl_cutFromGame,
+   rpl_removebuilding2,
+   rpl_setResourceProcessingAmount,
+   rpl_removebuilding3,
+   rpl_netcontrol,
+   rpl_move5,
+   rpl_alliancechange2,
+   rpl_moveUnitUp,
+   rpl_jump,
+   rpl_repairBuilding,
+   rpl_recycleUnit,
+   rpl_convert2,
+   rpl_putmine2,
+   rpl_repairUnit3,
+   rpl_transferTribute,
+   rpl_reactionFireOn,
+   rpl_reactionFireOff,
+   rpl_selfdestruct,
+   rpl_cancelResearch,
+   rpl_runCommandAction };
+
+
+
 class ReplayRecorder;
 
 class ReplayRecorderWatcherGlobal {
@@ -100,7 +165,7 @@ class ReplayRecorderWatcherGlobal {
          replayRecorderWatcherGlobal.set( this );
       }
       
-      void start( const ASCString& filename, bool append, int framerate, int quality )
+      void start( const ASCString& filename, bool append, int framerate, int ascFramerateLimit, int quality )
       {
          lastFilename = filename;
          movieModeStorage = CGameOptions::Instance()->replayMovieMode;
@@ -108,7 +173,7 @@ class ReplayRecorderWatcherGlobal {
          ASCString newFilename = constructFileName( 0, "", filename );
          if ( !rec || !append || newFilename != rec->getFilename()  ) {
             delete rec;
-            rec = new VideoRecorder( newFilename, PG_Application::GetScreen(), framerate, quality );
+            rec = new VideoRecorder( newFilename, PG_Application::GetScreen(), framerate, ascFramerateLimit, quality );
          }
          
          if ( !connection.connected() )
@@ -423,7 +488,7 @@ class ReplayRecord : public GuiFunction
          
         if ( !replayRecorder )
            replayRecorder = new ReplayRecorder();
-        replayRecorder->start( rrd.getFilename(), rrd.getAppend(), rrd.getFramerate(), rrd.getQuality() );
+        replayRecorder->start( rrd.getFilename(), rrd.getAppend(), rrd.getFramerate(), rrd.getASCFramerateLimit(),  rrd.getQuality() );
         
         runreplay.status = 2;
         updateFieldInfo();
@@ -639,8 +704,8 @@ void initReplayLogging( Player& player )
 
       savereplay ( gamemap, player.getPosition() );
 
-      gamemap->replayinfo->guidata[ player.getPosition() ] = new tmemorystreambuf;
-      gamemap->replayinfo->actmemstream = new tmemorystream ( gamemap->replayinfo->guidata[ player.getPosition() ], tnstream::writing );
+      gamemap->replayinfo->guidata[ player.getPosition() ] = new MemoryStreamStorage;
+      gamemap->replayinfo->actmemstream = new MemoryStream ( gamemap->replayinfo->guidata[ player.getPosition() ], tnstream::writing );
    }
 }
 
@@ -680,9 +745,9 @@ class LogActionIntoReplayInfo  {
          
             stream->writeChar( rpl_runCommandAction );
             
-            tmemorystreambuf buff;
+            MemoryStreamStorage buff;
             {
-               tmemorystream stream2( &buff, tnstream::writing );
+               MemoryStream stream2( &buff, tnstream::writing );
                cmd.write( stream2 );
             }
             
@@ -700,7 +765,7 @@ class LogActionIntoReplayInfo  {
       }
 };
 
-void logActionToReplay( GameMap* map, const Command& command)
+static void logActionToReplay( GameMap* map, Command& command)
 {
    LogActionIntoReplayInfo lairi( map );
    lairi.saveCommand( command );
@@ -858,7 +923,13 @@ void trunreplay :: removeActionCursor ( void )
 
 void trunreplay :: execnextreplaymove ( void )
 {
-   displayLogMessage( 8, "executing replay move %d\n", movenum );
+   
+   static int lastTicker = ticker;
+   
+   if ( lastTicker + 10 < ticker ) {
+      displayLogMessage( 8, "executing replay move %d\n", movenum );
+      lastTicker = ticker;
+   }
 
    if ( !replayRecorder || !replayRecorder->isRunning())
       displaymessage2("executing replay move %d\n", movenum );
@@ -940,7 +1011,7 @@ void trunreplay :: execnextreplaymove ( void )
                            else {
                               if ( CGameOptions::Instance()->replayMovieMode ) {
 
-                                 tfield* fld = eht->getMap()->getField(x1,y1);
+                                 MapField* fld = eht->getMap()->getField(x1,y1);
                                  if ( fld->vehicle == eht ) {
                                     fld->vehicle = NULL;
                                  } else {
@@ -956,7 +1027,7 @@ void trunreplay :: execnextreplaymove ( void )
                                  if ( height >= 0 )
                                     eht->height = 1 << height;
 
-                                 tfield* fld2 = eht->getMap()->getField(x2,y2);
+                                 MapField* fld2 = eht->getMap()->getField(x2,y2);
                                  if ( !fld2->getContainer() ) {
                                     fld2->vehicle = eht;
                                     eht->addview();
@@ -997,8 +1068,8 @@ void trunreplay :: execnextreplaymove ( void )
                            int wpnum = stream->readInt();
                            readnextaction();
 
-                           tfield* fld = getfield ( x1, y1 );
-                           tfield* targ = getfield ( x2, y2 );
+                           MapField* fld = getfield ( x1, y1 );
+                           MapField* targ = getfield ( x2, y2 );
                            int attackvisible = fieldvisiblenow ( fld, actmap->getPlayerView() ) || fieldvisiblenow ( targ, actmap->getPlayerView() );
                            if ( fld && targ && fld->vehicle ) {
                               if ( fieldvisiblenow ( targ, fld->vehicle->getOwner() )) {
@@ -1016,7 +1087,7 @@ void trunreplay :: execnextreplaymove ( void )
                                     }
                                     if ( battle.av.damage < ad2 || battle.dv.damage > dd2 )
                                        error(MapCoordinate(x2,y2), "severe replay inconsistency:\nresult of attack differ !\nexpected target damage: %d ; recorded target damage: %d\nexpected attacker damage: %d ; recorded attacker damage: %d", battle.av.damage,ad2 ,battle.dv.damage, dd2);
-                                    battle.setresult ();
+                                    battle.setresult( createReplayContext() );
 
                                     if ( battle.av.damage >= 100 || battle.dv.damage >= 100 )
                                        computeview( actmap );
@@ -1040,7 +1111,7 @@ void trunreplay :: execnextreplaymove ( void )
                                     }
                                     if ( battle.av.damage != ad2 || battle.dv.damage != dd2 )
                                        error(MapCoordinate(x2,y2), "severe replay inconsistency:\nresult of attack differ !\nexpected target damage: %d ; recorded target damage: %d\nexpected attacker damage: %d ; recorded attacker damage: %d", battle.av.damage,ad2 ,battle.dv.damage, dd2);
-                                    battle.setresult ();
+                                    battle.setresult( createReplayContext() );
 
                                     if ( battle.av.damage >= 100 || battle.dv.damage >= 100 )
                                        computeview( actmap );
@@ -1060,7 +1131,7 @@ void trunreplay :: execnextreplaymove ( void )
                                     }
                                     if ( battle.av.damage != ad2 || battle.dv.damage != dd2 )
                                        error(MapCoordinate(x2,y2), "severe replay inconsistency:\nresult of attack differ !\nexpected target damage: %d ; recorded target damage: %d\nexpected attacker damage: %d ; recorded attacker damage: %d", battle.av.damage,ad2 ,battle.dv.damage, dd2);
-                                    battle.setresult ();
+                                    battle.setresult( createReplayContext() );
 
                                     if ( battle.av.damage >= 100 || battle.dv.damage >= 100 )
                                        computeview( actmap );
@@ -1136,7 +1207,7 @@ void trunreplay :: execnextreplaymove ( void )
                            } else {
                               readnextaction();
 
-                              tfield* fld = getfield ( x, y );
+                              MapField* fld = getfield ( x, y );
                               if ( fld ) {
                                  displayActionCursor ( x, y );
                                  if ( fld->vehicle )
@@ -1170,7 +1241,7 @@ void trunreplay :: execnextreplaymove ( void )
 
                            ObjectType* obj = objectTypeRepository.getObject_byID ( id );
 
-                           tfield* fld = getfield ( x, y );
+                           MapField* fld = getfield ( x, y );
                            if ( obj && fld ) {
                               displayActionCursor ( x, y );
 
@@ -1248,9 +1319,9 @@ void trunreplay :: execnextreplaymove ( void )
 
                            readnextaction();
 
-                           tfield* fld = getfield ( x, y );
+                           MapField* fld = getfield ( x, y );
 
-                           Vehicletype* tnk = vehicleTypeRepository.getObject_byID ( id );
+                           VehicleType* tnk = vehicleTypeRepository.getObject_byID ( id );
 
                            if ( fld && tnk && !fld->vehicle ) {
                               displayActionCursor ( x, y );
@@ -1262,7 +1333,7 @@ void trunreplay :: execnextreplaymove ( void )
                                  v->height = height;
 
                               if ( constx >= 0 && consty >= 0 ) {
-                                 tfield* constructorField = getfield(constx, consty );
+                                 MapField* constructorField = getfield(constx, consty );
                                  if ( constructorField->vehicle ) {
                                     Resources r ( 0, tnk->productionCost.material, tnk->productionCost.energy ); //  = constructorField->vehicle->getProductionCost(tnk );
                                     Resources rr = constructorField->getContainer()->getResource( r, 0 );
@@ -1297,7 +1368,7 @@ void trunreplay :: execnextreplaymove ( void )
 
                                readnextaction();
 
-                               tfield* fld = getfield ( x, y );
+                               MapField* fld = getfield ( x, y );
 
                                BuildingType* bld = buildingTypeRepository.getObject_byID ( id );
 
@@ -1332,7 +1403,7 @@ void trunreplay :: execnextreplaymove ( void )
 
                            readnextaction();
 
-                           tfield* fld = getfield ( x, y );
+                           MapField* fld = getfield ( x, y );
                            if ( fld ) {
                               displayActionCursor ( x, y );
                               fld -> putmine ( col, MineTypes(typ), strength );
@@ -1364,7 +1435,7 @@ void trunreplay :: execnextreplaymove ( void )
                            int y = stream->readInt();
                            readnextaction();
 
-                           tfield* fld = getfield ( x, y );
+                           MapField* fld = getfield ( x, y );
                            if ( fld ) {
                               displayActionCursor ( x, y );
                               fld -> removemine ( -1 );
@@ -1398,7 +1469,7 @@ void trunreplay :: execnextreplaymove ( void )
 
                            readnextaction();
 
-                           tfield* fld = getfield ( x, y );
+                           MapField* fld = getfield ( x, y );
                            if ( fld && fld->building ) {
                               displayActionCursor ( x, y );
                               if ( nwid >= 0 ) {
@@ -1432,9 +1503,9 @@ void trunreplay :: execnextreplaymove ( void )
                                  int nwid = stream->readInt();
                                  readnextaction();
 
-                                 tfield* fld = getfield ( x, y );
+                                 MapField* fld = getfield ( x, y );
 
-                                 Vehicletype* tnk = vehicleTypeRepository.getObject_byID ( id );
+                                 VehicleType* tnk = vehicleTypeRepository.getObject_byID ( id );
                                  if ( tnk && fld) {
                                  
                                     #if 0
@@ -1473,7 +1544,7 @@ void trunreplay :: execnextreplaymove ( void )
                                  int y = stream->readInt();
                                  int nwid = stream->readInt();
                                  readnextaction();
-                                 tfield* fld = getfield(x,y);
+                                 MapField* fld = getfield(x,y);
                                  if ( (!fld->vehicle || fld->vehicle->networkid != nwid) && fld->building ) {
                                     auto_ptr<RecycleUnitCommand> ruc ( new RecycleUnitCommand( fld->building ));
                                     ruc->setUnit( actmap->getUnit( nwid ) );
@@ -1761,7 +1832,7 @@ void trunreplay :: execnextreplaymove ( void )
                                  int vehicleid = stream->readInt();
                                  readnextaction();
                                  Building* bld = dynamic_cast<Building*>( actmap->getContainer(building));
-                                 Vehicletype* veh = actmap->getvehicletype_byid ( vehicleid );
+                                 VehicleType* veh = actmap->getvehicletype_byid ( vehicleid );
                                  if ( bld && veh ) {
                                     if ( veh->techDependency.available( actmap->player[ bld->getOwner()].research )) {
                                        auto_ptr<BuildProductionLineCommand> bplc ( new BuildProductionLineCommand( bld ));
@@ -1785,7 +1856,7 @@ void trunreplay :: execnextreplaymove ( void )
                                  int vehicleid = stream->readInt();
                                  readnextaction();
                                  Building* bld = dynamic_cast<Building*>( actmap->getContainer(building));
-                                 Vehicletype* veh = actmap->getvehicletype_byid ( vehicleid );
+                                 VehicleType* veh = actmap->getvehicletype_byid ( vehicleid );
                                  if ( bld && veh ) {
                                     auto_ptr<RemoveProductionLineCommand> rplc ( new RemoveProductionLineCommand( bld ));
                                     rplc->setRemoval( veh );
@@ -1911,7 +1982,7 @@ void trunreplay :: execnextreplaymove ( void )
 
             Vehicle* veh = actmap->getUnit(nwid);
             if ( veh ) {
-               if ( JumpDriveCommand::avail( veh )) {
+               if ( JumpDriveCommand::available( veh ).ready()) {
                   auto_ptr<JumpDriveCommand> jd( new JumpDriveCommand(veh) );
                   displayActionCursor ( veh->getPosition().x , veh->getPosition().x, x, y, 0 );
                   jd->setDestination( MapCoordinate(x,y));
@@ -2008,10 +2079,10 @@ void trunreplay :: execnextreplaymove ( void )
          {
             stream->readInt();
             int padding = stream->readInt();
-            tmemorystreambuf buffer;
+            MemoryStreamStorage buffer;
             buffer.readfromstream( stream );
             
-            tmemorystream memstream( &buffer, tnstream::reading );
+            MemoryStream memstream( &buffer, tnstream::reading );
             
             auto_ptr<GameAction> readaction ( GameAction::readFromStream( memstream, actmap ));
             
@@ -2095,7 +2166,7 @@ int  trunreplay :: run ( int player, int viewingplayer, bool performEndTurnOpera
    SuppressTechPresentation stp;
    actmap->sigPlayerTurnBegins( actmap->getPlayer( player ));
    
-   tmemorystream guidatastream ( orgmap->replayinfo->guidata [ player ], tnstream::reading );
+   MemoryStream guidatastream ( orgmap->replayinfo->guidata [ player ], tnstream::reading );
    stream = &guidatastream;
 
    if ( stream->dataavail () )
