@@ -95,10 +95,8 @@ bool TechDependency::eventually_available_single( const Research& res, list<cons
    Technology* tech = technologyRepository.getObject_byID( id );
    if ( !tech )
       return false;
-
-
-   
-   return tech->eventually_available( res, dependencies, stack );
+   else
+      return tech->eventually_available( res, dependencies, stack );
 }
 
 bool TechDependency::eventually_available( const Research& res, list<const Technology*>* dependencies, list<int>& stack ) const
@@ -144,7 +142,7 @@ int TechDependency::findInheritanceLevel( int id, vector<int>& stack, const ASCS
                Technology* t = technologyRepository.getObject_byID( k );
                if ( t )
                   s += t->name + "\n";
-               warning ( s );
+               warningMessage ( s );
                return -1;
             }
 
@@ -773,11 +771,19 @@ bool Research::techAdapterAvail( const ASCString& ta ) const
    return triggeredTechAdapter.find ( ta ) != triggeredTechAdapter.end();
 }
 
-void Research::evalTechAdapter()
+vector<ASCString> Research::evalTechAdapter()
 {
+   vector<ASCString> newTechadapters;
    for ( TechAdapterContainer::iterator i = techAdapterContainer.begin(); i != techAdapterContainer.end(); ++i )
-      if ( (*i)->available ( *this ))
-         triggeredTechAdapter[(*i)->getName()] = true;
+      if ( (*i)->available ( *this )) {
+         ASCString techAdap = (*i)->getName();
+         if ( find( triggeredTechAdapter.begin(), triggeredTechAdapter.end(), techAdap ) == triggeredTechAdapter.end() ) {
+            triggeredTechAdapter.insert( techAdap );
+            newTechadapters.push_back ( techAdap );
+         }
+      }
+   
+   return newTechadapters;
 }
 
 
@@ -786,11 +792,11 @@ ASCString Research::listTriggeredTechAdapter() const
    ASCString s;
    for ( TriggeredTechAdapter::const_iterator i = triggeredTechAdapter.begin(); i != triggeredTechAdapter.end(); ++i ) {
       s += "#fontsize=14# ";
-      s += i->first + "\n";
+      s += *i + "\n";
       s += "#fontsize=10#";
       int counter = 0;
       for ( TechAdapterContainer::iterator j = techAdapterContainer.begin(); j != techAdapterContainer.end(); ++j ) {
-         if ( (*j)->getName() == i->first ) {
+         if ( (*j)->getName() == *i ) {
             if ( counter )
                s += " ----\n";
             ++counter;
@@ -840,23 +846,17 @@ ResearchAvailabilityStatus Research::techAvailable ( const Technology* tech ) co
 }
 
 
-void Research :: addanytechnology ( const Technology* tech )
+vector<ASCString> Research :: addanytechnology ( const Technology* tech )
 {
    if ( tech ) {
       developedTechnologies.push_back ( tech->id );
 
       map->player[player].queuedEvents++;
-      evalTechAdapter();
-   }
+      return evalTechAdapter();
+   } else
+      return vector<ASCString>();
 }
 
-void Research :: addtechnology ( void )
-{
-   if ( activetechnology )
-      addanytechnology ( activetechnology );
-
-   activetechnology = 0;
-}
 
 void Research :: settechlevel ( int techlevel )
 {
@@ -876,18 +876,6 @@ void Research :: settechlevel ( int techlevel )
 
 
 
-
-
-
-bool Research :: vehicletypeavailable ( const Vehicletype* fztyp ) const
-{
-   if ( !fztyp )
-      return false;
-   else
-      return fztyp->techDependency.available( *this );
-      // return true; // vehicleclassavailable( fztyp, 0 );
-}
-
 /*
 void Research::initchoosentechnology()
 {
@@ -929,6 +917,18 @@ int Research :: currentTechAvailableIn() const
       return -1;
 }
 
+void Research::setPredefinedTechAdapter( const set<ASCString>& adapter )
+{
+   predefinedTechAdapter.clear();
+   predefinedTechAdapter.insert( predefinedTechAdapter.end(), adapter.begin(), adapter.end());
+}
+
+void Research::addPredefinedTechAdapter( const ASCString& techAdapter )
+{
+   predefinedTechAdapter.push_back( techAdapter );
+}
+
+
 
 Research::~Research () {};
 
@@ -937,7 +937,7 @@ Research::~Research () {};
 Resources returnResourcenUseForResearch ( const ContainerBase* bld, int research )
 {
    Resources res;
-   if ( bld->baseType->nominalresearchpoints == 0 )
+   if ( (bld->baseType->nominalresearchpoints == 0) || !bld->baseType->hasFunction( ContainerBaseType::Research) )
       return res;
 
    int num = 0;
