@@ -2,7 +2,7 @@
                            sg.cpp  -  description
                              -------------------
     begin                : a long time ago...
-    copyright            : (C) 1994-2003 by Martin Bickel
+    copyright            : (C) 1994-2010 by Martin Bickel
     email                : bickel@asc-hq.org
  ***************************************************************************/
 
@@ -124,6 +124,7 @@
 #include "gamedialog.h"
 #include "unitset.h"
 #include "applicationstarter.h"
+#include "replaymapdisplay.h"
 
 #ifdef WEATHERGENERATOR
 # include "weathercast.h"
@@ -169,7 +170,10 @@
 #include "dialogs/actionmanager.h"
 #include "dialogs/gotoposition.h"
 #include "loggingoutput.h"
-
+#include "contextutils.h"
+#include "actions/taskinterface.h"
+#include "tasks/taskcontainer.h"
+#include "dialogs/taskmanager.h"
 #include "autotraining.h"
 #include "spfst-legacy.h"
 
@@ -191,7 +195,7 @@
 # include <stdio.h>
 #endif
 
-tfield*        getSelectedField(void)
+MapField*        getSelectedField(void)
 {
    return actmap->getField( actmap->getCursor() ); 
 } 
@@ -240,6 +244,43 @@ void viewcomp( Player& player )
 }
 
 
+void runOpenTasks()
+{
+   GameMap* map = actmap;
+   
+   if ( map->tasks ) {
+      TaskContainer* tc = dynamic_cast<TaskContainer*>( map->tasks );
+      if ( tc ) {
+         while ( tc->pendingCommands.begin() != tc->pendingCommands.end() ) {
+            Command* c = tc->pendingCommands.front();
+            TaskInterface* ti = dynamic_cast<TaskInterface*>( c );
+            
+            if ( ti->operatable() ) {
+               ActionResult res = c->execute( createFollowerContext( map ));
+               if ( !res.successful() )
+                  dispmessage2(res);
+            }
+            
+            tc->pendingCommands.erase( tc->pendingCommands.begin() );
+         }
+      }
+   }
+}
+
+
+void runPendingTasks( Player& player )
+{
+   GameMap* map = player.getParentMap();
+   if ( map->tasks ) {
+      TaskContainer* tc = dynamic_cast<TaskContainer*>( map->tasks );
+      if ( tc ) 
+         if( tc->pendingCommands.begin() != tc->pendingCommands.end() ) 
+            if (choice_dlg("run pending tasks ?","~y~es","~n~o") == 1)
+               runOpenTasks(); 
+   }
+}
+
+
 
 void hookGuiToMap( GameMap* map )
 {
@@ -256,6 +297,8 @@ void hookGuiToMap( GameMap* map )
       map->sigPlayerUserInteractionBegins.connect( SigC::slot( &checkUsedASCVersions ));
       map->sigPlayerUserInteractionBegins.connect( SigC::hide<Player&>( updateFieldInfo.slot() ));
 
+      map->sigPlayerUserInteractionEnds.connect( SigC::slot( &runPendingTasks ));
+
       map->sigPlayerTurnHasEnded.connect( SigC::slot( viewOwnReplay));
       map->guiHooked();
    }
@@ -276,10 +319,10 @@ bool loadGameFromFile( const ASCString& filename )
          displaymessage2( "actmemstream already open at begin of turn ",2 );
 
       if ( actmap->replayinfo->guidata[actmap->actplayer] )
-         actmap->replayinfo->actmemstream = new tmemorystream ( actmap->replayinfo->guidata[actmap->actplayer], tnstream::appending );
+         actmap->replayinfo->actmemstream = new MemoryStream ( actmap->replayinfo->guidata[actmap->actplayer], tnstream::appending );
       else {
-         actmap->replayinfo->guidata[actmap->actplayer] = new tmemorystreambuf;
-         actmap->replayinfo->actmemstream = new tmemorystream ( actmap->replayinfo->guidata[actmap->actplayer], tnstream::writing );
+         actmap->replayinfo->guidata[actmap->actplayer] = new MemoryStreamStorage;
+         actmap->replayinfo->actmemstream = new MemoryStream ( actmap->replayinfo->guidata[actmap->actplayer], tnstream::writing );
       }
    }
    
@@ -305,7 +348,8 @@ bool loadGame( bool mostRecent )
             s1 = fi.name;
          }
    } else {
-      s1 = selectFile( savegameextension, true );
+     // s1 = selectFile( savegameextension, true );
+	   s1 = selectSavegame( savegameextension, true );
    }
 
    if ( !s1.empty() ) {
@@ -336,7 +380,7 @@ void saveGame( bool as )
       nameavail = 1;
 
    if ( as || !nameavail ) {
-      s1 = selectFile( savegameextension, false);
+      s1 = selectSavegame( savegameextension, false);
    } else
       s1 = actmap->preferredFileNames.savegame[actmap->actplayer];
 
@@ -351,8 +395,6 @@ void saveGame( bool as )
 
 
 
-
-
 void loadmap( const ASCString& name, bool campaign )
 {
    GameMap* m = mapLoadingExceptionChecker( name, MapLoadingFunction( tmaploaders::loadmap ));
@@ -539,18 +581,6 @@ void helpAbout()
 }
 
 
-Context createContext( GameMap* gamemap )
-{
-   Context context;
-   
-   context.gamemap = gamemap;
-   context.actingPlayer = &gamemap->getPlayer( gamemap->actplayer );
-   context.parentAction = NULL;
-   context.display = &getDefaultMapDisplay();
-   context.viewingPlayer = gamemap->getPlayerView(); 
-   context.actionContainer = &gamemap->actions;
-   return context;   
-}
 
 void undo()
 {
@@ -574,8 +604,155 @@ void redo()
    }
 }
 
+
+bool continueAndStartMultiplayerGame( bool mostRecent = false )
+{
+   GameMap* map = continueNetworkGame( mostRecent );
+   if ( map ) {
+      delete actmap;
+      actmap = map;
+      hookGuiToMap(actmap);
+      actmap->sigPlayerUserInteractionBegins( actmap->player[actmap->actplayer] );
+      displaymap();
+      return true;
+   } else
+      return false;
+}
+
+
+
+
+void writeLuaCommands()
+{
+   ASCString filename =  selectFile("*.lua", false );
+   if ( !filename.empty() ) {
+      LuaCommandFileWriter writer ( filename );
+      actmap->actions.getCommands( writer );
+   }
+}
+
+void selectAndRunLuaScript()
+{
+   ASCString file = selectFile( "*.lua", true );
+   if ( file.size() ) {
+      LuaState state;
+      LuaRunner runner( state );
+      runner.runFile( file );
+      if ( !runner.getErrors().empty() )
+         errorMessage( runner.getErrors() );
+      updateFieldInfo();
+   }
+}
+
+
+void showUnitAiProperties()
+{
+   MapField* fld = getSelectedField();
+   if ( fld->vehicle && fieldvisiblenow(fld ) ) {
+      Vehicle* v = fld->vehicle;
+      ASCString s;
+      s += "Unit nwid = " + ASCString::toString( v->networkid ) + "\n";
+
+      AiParameter* a = NULL;
+
+      for ( int i = 0; i < 8; ++i )
+         if ( v->aiparam[i] ) {
+         a = v->aiparam[i];
+         break;
+         }
+
+         s += "Task = " + ASCString(AItasks[(int)a->getTask() ]) + "\n";
+         s += "Job = " + ASCString(AIjobs[(int)a->getJob() ]) + "\n";
+
+
+         s += "Destination: ";
+         if ( a->dest.valid() )
+            s += a->dest.toString();
+         s += "\n";
+
+         ViewFormattedText vat ( "AI properties", s, PG_Rect( 20, -1 , 450, 480 ));
+         vat.Show();
+         vat.RunModal();
+   }
+}
+
+
+void showUsedPackages()
+{
+   PackageManager::storeData( actmap );
+   if ( actmap->packageData ) {
+      ASCString s;
+      for ( PackageData::Packages::const_iterator i  = actmap->packageData->packages.begin(); i != actmap->packageData->packages.end(); ++i ) {
+         s += "#fontsize=14#" + i->second->name + "#fontsize=11#\n";
+         s += i->second->description;
+         s += "\n\n";
+      }
+
+      ViewFormattedText vat ( "Used Packages", s, PG_Rect( 20, -1 , 450, 480 ));
+      vat.Show();
+      vat.RunModal();
+   }
+}
+
+
+class CommandAllianceSetupStrategy : public AllianceSetupWidget::ApplyStrategy {
+   virtual void sneakAttack ( GameMap* map, int actingPlayer, int towardsPlayer )
+   {
+      auto_ptr<DiplomacyCommand> dc ( new DiplomacyCommand( map->player[actingPlayer]));
+      dc->sneakAttack( map->getPlayer( towardsPlayer ));
+      ActionResult res = dc->execute( createContext(actmap) );
+      if ( res.successful() )
+         dc.release();
+      else
+         displayActionError( res );
+   }
+
+   virtual void setState ( GameMap* map, int actingPlayer, int towardsPlayer, DiplomaticStates newState )
+   {
+      auto_ptr<DiplomacyCommand> dc ( new DiplomacyCommand( map->player[actingPlayer]));
+      dc->newstate( newState, map->getPlayer( towardsPlayer ));
+      ActionResult res = dc->execute( createContext(actmap) );
+      if ( res.successful() )
+         dc.release();
+      else
+         displayActionError( res );
+   }
+};
+
+
+void editAlliances()
+{
+   CommandAllianceSetupStrategy cass;
+   if ( setupalliances( actmap, &cass, actmap->getCurrentPlayer().stat == Player::supervisor ) ) {
+      if ( computeview( actmap ))
+         displaymap();
+   }
+}
+
+
+/** this performs some check if a technology may be choosen right now and than
+    either calls chooseTechnology
+    or displays some informational messages
+ */
+void chooseTechnologyIfAvail( Player& player )
+{
+   if ( player.research.activetechnology ) {
+      infoMessage("You are already researching " + player.research.activetechnology->name);
+   } else {
+      if ( !player.research.progress )
+         infoMessage("You don't have any research points to spend");
+      else {
+         checkForNewResearch( player );
+      }
+   }
+}
+
+
+
+
+
 // user actions using the old event system
-void execuseraction ( tuseractions action )
+void executeUserAction ( tuseractions action )
 {
    switch ( action ) {
       case ua_repainthard  :
@@ -757,7 +934,7 @@ void execuseraction ( tuseractions action )
                if ( !actmap->player[ actmap->actplayer ].ai )
                   actmap->player[ actmap->actplayer ].ai = new AI ( actmap, actmap->actplayer );
 
-               savegame ( "aistart.sav", actmap );
+               savegame ( "aistart.sav", actmap);
                actmap->player[ actmap->actplayer ].ai->run( &getDefaultMapDisplay() );
             }
          }
@@ -791,7 +968,7 @@ void execuseraction ( tuseractions action )
                actmap->player[ actmap->actplayer ].ai = new AI ( actmap, actmap->actplayer );
 
             if ( AI* ai = dynamic_cast<AI*>( actmap->player[ actmap->actplayer ].ai )) {
-               savegame ( "ai-bench-start.sav", actmap );
+               savegame ( "ai-bench-start.sav", actmap);
                ai->run( true, &getDefaultMapDisplay() );
             }
          }
@@ -880,158 +1057,6 @@ void execuseraction ( tuseractions action )
          break;
 
          
-      default:;
-      };
-}
-
-bool continueAndStartMultiplayerGame( bool mostRecent = false )
-{
-   GameMap* map = continueNetworkGame( mostRecent );
-   if ( map ) {
-      delete actmap;
-      actmap = map;
-      hookGuiToMap(actmap);
-      actmap->sigPlayerUserInteractionBegins( actmap->player[actmap->actplayer] );
-      displaymap();
-      return true;
-   } else
-      return false;
-}
-
-
- 
-
-void writeLuaCommands() 
-{
-   ASCString filename =  selectFile("*.lua", false );
-   if ( !filename.empty() ) {
-      LuaCommandFileWriter writer ( filename );
-      actmap->actions.getCommands( writer ); 
-   }
-}
-
-void selectAndRunLuaScript()
-{
-   ASCString file = selectFile( "*.lua", true );
-   if ( file.size() ) {
-      LuaState state;
-      LuaRunner runner( state );
-      runner.runFile( file );
-      if ( !runner.getErrors().empty() )
-         errorMessage( runner.getErrors() );
-      updateFieldInfo();
-   }
-}
-
-
-void showUnitAiProperties() 
-{
-   tfield* fld = getSelectedField();
-   if ( fld->vehicle && fieldvisiblenow(fld ) ) {
-      Vehicle* v = fld->vehicle;
-      ASCString s;
-      s += "Unit nwid = " + ASCString::toString( v->networkid ) + "\n";
-   
-      AiParameter* a = NULL;
-      
-      for ( int i = 0; i < 8; ++i )
-         if ( v->aiparam[i] ) {
-         a = v->aiparam[i];
-         break;
-         }
-         
-         s += "Task = " + ASCString(AItasks[(int)a->getTask() ]) + "\n";
-         s += "Job = " + ASCString(AIjobs[(int)a->getJob() ]) + "\n";
-      
-      
-         s += "Destination: ";
-         if ( a->dest.valid() )
-            s += a->dest.toString();
-         s += "\n";
-      
-         ViewFormattedText vat ( "AI properties", s, PG_Rect( 20, -1 , 450, 480 ));
-         vat.Show();
-         vat.RunModal();
-   }
-}
-   
-
-void showUsedPackages()
-{
-   PackageManager::storeData( actmap );
-   if ( actmap->packageData ) {
-      ASCString s;
-      for ( PackageData::Packages::const_iterator i  = actmap->packageData->packages.begin(); i != actmap->packageData->packages.end(); ++i ) {
-         s += "#fontsize=14#" + i->second->name + "#fontsize=11#\n";
-         s += i->second->description;
-         s += "\n\n";
-      }
-      
-      ViewFormattedText vat ( "Used Packages", s, PG_Rect( 20, -1 , 450, 480 ));
-      vat.Show();
-      vat.RunModal();
-   }
-}
-
-
-class CommandAllianceSetupStrategy : public AllianceSetupWidget::ApplyStrategy {
-   virtual void sneakAttack ( GameMap* map, int actingPlayer, int towardsPlayer )
-   {
-      auto_ptr<DiplomacyCommand> dc ( new DiplomacyCommand( map->player[actingPlayer]));  
-      dc->sneakAttack( map->getPlayer( towardsPlayer ));
-      ActionResult res = dc->execute( createContext(actmap) );
-      if ( res.successful() )
-         dc.release();
-      else
-         displayActionError( res );
-   }
-   
-   virtual void setState ( GameMap* map, int actingPlayer, int towardsPlayer, DiplomaticStates newState )
-   {
-      auto_ptr<DiplomacyCommand> dc ( new DiplomacyCommand( map->player[actingPlayer]));  
-      dc->newstate( newState, map->getPlayer( towardsPlayer ));
-      ActionResult res = dc->execute( createContext(actmap) );
-      if ( res.successful() )
-         dc.release();
-      else
-         displayActionError( res );
-   }
-};
-
-
-void editAlliances()
-{
-   CommandAllianceSetupStrategy cass;
-   if ( setupalliances( actmap, &cass, actmap->getCurrentPlayer().stat == Player::supervisor ) ) {
-      if ( computeview( actmap ))
-         displaymap();
-   }
-}
-
-
-/** this performs some check if a technology may be choosen right now and than 
-    either calls chooseTechnology
-    or displays some informational messages
- */
-void chooseTechnologyIfAvail( Player& player )
-{
-   if ( player.research.activetechnology ) {
-      infoMessage("You are already researching " + player.research.activetechnology->name);
-   } else {
-      if ( !player.research.progress )
-         infoMessage("You don't have any research points to spend");
-      else {
-         checkForNewResearch( player );
-      }
-   }
-}
-
-
-// user actions using the new event system
-void execuseraction2 ( tuseractions action )
-{
-   switch ( action ) {
-   
       case ua_unitweightinfo:
          if ( fieldvisiblenow  ( getSelectedField() )) {
             Vehicle* eht = getSelectedField()->vehicle;
@@ -1158,6 +1183,14 @@ void execuseraction2 ( tuseractions action )
          mainScreenWidget->getMapDisplay()->toggleMapLayer("reactionfire");
          repaintMap();
          break;
+      case ua_viewUnitinfoOverlay:
+         mainScreenWidget->getMapDisplay()->toggleMapLayer("unitinfo");
+         repaintMap();
+         break;
+      case ua_viewUnitexperienceOverlay:
+         mainScreenWidget->getMapDisplay()->toggleMapLayer("unittraining");
+         repaintMap();
+         break;
       case ua_showsearchdirs: showSearchPath();
          break;
       case ua_changepassword:
@@ -1232,18 +1265,17 @@ void execuseraction2 ( tuseractions action )
       case ua_showUsedPackages: showUsedPackages();
          break;
          
-      default:
+      case ua_runOpenTasks: runOpenTasks();
          break;
-   }
-
-}
-
-
-
-void execUserAction_ev( tuseractions action )
-{
-   execuseraction( action );
-   execuseraction2( action );
+         
+      case ua_taskManager: taskManager( actmap );
+         break;
+         
+      case ua_createUnitCostList: createUnitCostList();
+         break;
+         
+      default:;
+      };
 }
 
 
@@ -1332,6 +1364,12 @@ void checkGameEvents( GameMap* map,const Command& command )
 
 int gamethread ( void* data )
 {
+   GameMap::sigMapDeletion.connect( SigC::slot( &resetActions ));
+   GameMap::sigMapDeletion.connect( SigC::slot( &resetActmap ));
+   GameMap::sigPlayerTurnEndsStatic.connect( SigC::slot( automaticTrainig ));
+   
+   TaskContainer::registerHooks();
+   
    GameThreadParams* gtp = (GameThreadParams*) data;
 
    std::auto_ptr<StartupScreen> startupScreen;
@@ -1376,9 +1414,7 @@ int gamethread ( void* data )
    }
 #endif
 
-   GameMap::sigMapDeletion.connect( SigC::slot( &resetActions ));
-   GameMap::sigMapDeletion.connect( SigC::slot( &resetActmap ));
-   GameMap::sigPlayerTurnEndsStatic.connect( SigC::slot( automaticTrainig ));
+
 
 //   ActionContainer::postActionExecution.connect( SigC::slot( &checkGameEvents ));
             
@@ -1479,7 +1515,6 @@ int gamethread ( void* data )
 }
 
 
-
 static void __runResearch( Player& player ){
    runResearch( player, NULL, NULL );  
 }
@@ -1523,17 +1558,91 @@ class ResourceLogger: public SigC::Object {
 };
 
 
+class ScreenResolutionSetup {
+      Cmdline& cli;
+      int x,y;
+      bool fullscreen;
+   public:
+      ScreenResolutionSetup( Cmdline& commandLine );
+      
+      int getWidth() { return x; };
+      int getHeight() { return y; };
+      bool isFullscreen() { return fullscreen; };
+   
+};
+
+ScreenResolutionSetup::ScreenResolutionSetup( Cmdline& commandLine ) : cli( commandLine )
+{
+   if ( SDL_Init( SDL_INIT_VIDEO ) ) 
+      fatalError( ASCString("Unable to init SDL: ") +  SDL_GetError());
+  
+   putenv(const_cast<char*>("SDL_VIDEO_CENTERED=1")) ;
+   
+   fullscreen = true;
+   
+   if ( cli.w() )
+      fullscreen = false;
+
+   if ( cli.f() )
+      fullscreen = true;
+   
+   if ( CGameOptions::Instance()->forceWindowedMode && !cli.f() )  // cl->f == force fullscreen command line param
+      fullscreen = false;
+
+   int xr = -1;
+   int yr = -1;
+   // determining the graphics resolution
+   
+   if ( CGameOptions::Instance()->xresolution != -1 )
+      xr = CGameOptions::Instance()->xresolution;
+   if ( cli.x() != -1 )
+      xr = cli.x();
+
+   if ( CGameOptions::Instance()->yresolution != -1 )
+      yr = CGameOptions::Instance()->yresolution;
+   if ( cli.y() != -1 )
+      yr = cli.y();
+
+   
+   GetVideoModes gvm;
+   
+   GetVideoModes::ModeRes best = gvm.getBest();
+   if ( xr == -1 ) {
+      if ( fullscreen )
+         xr = best.first;
+      else
+         xr = best.first - 100;
+   }
+   
+   if ( yr == -1 ) {
+      if ( fullscreen ) 
+         yr = best.second;
+      else
+         yr = best.second - 100;
+   }
+   
+   
+   if ( CGameOptions::Instance()->graphicsDriver.compare_ci("default") != 0 ) {
+      static char buf[100];
+      strcpy(buf, "SDL_VIDEODRIVER=" );
+      strncat( buf, CGameOptions::Instance()->graphicsDriver.c_str(), 100 - strlen(buf));
+      buf[99] = 0;
+      putenv( buf );
+   }
+
+   if ( xr == -1 )
+      xr = 1024;
+   
+   if ( yr == -1 )
+      yr = 768;
+   
+   x = xr;
+   y = yr;
+}
 
 
 int main(int argc, char *argv[] )
 { 
-
-//    LoggingOutputHandler logger2( "c:/users/martin/my documents/");
-
-
-   putenv(const_cast<char*>("SDL_VIDEO_CENTERED=1")) ;
-
-  
    assert ( sizeof(PointerSizedInt) == sizeof(int*));
 
    // we should think about replacing clparser with libpopt
@@ -1552,12 +1661,6 @@ int main(int argc, char *argv[] )
       exit(0);
    }
 
-   if ( cl->w() )
-      fullscreen = SDL_FALSE;
-
-   if ( cl->f() )
-      fullscreen = SDL_TRUE;
-
    MessagingHub::Instance().setVerbosity( cl->r() );
    StdIoErrorHandler stdIoErrorHandler(false);
    MessagingHub::Instance().exitHandler.connect( SigC::bind( SigC::slot( exit_asc ), -1 ));
@@ -1585,30 +1688,6 @@ int main(int argc, char *argv[] )
 
    LoggingOutputHandler logger( getSearchPath( 0 ));
    
-   if ( CGameOptions::Instance()->forceWindowedMode && !cl->f() )  // cl->f == force fullscreen command line param
-      fullscreen = SDL_FALSE;
-
-   int xr = 1024;
-   int yr = 768;
-   // determining the graphics resolution
-   
-   if ( CGameOptions::Instance()->xresolution != 1024 )
-      xr = CGameOptions::Instance()->xresolution;
-   if ( cl->x() != 1024 )
-      xr = cl->x();
-
-   if ( CGameOptions::Instance()->yresolution != 768 )
-      yr = CGameOptions::Instance()->yresolution;
-   if ( cl->y() != 768 )
-      yr = cl->y();
-
-   if ( CGameOptions::Instance()->graphicsDriver.compare_ci("default") != 0 ) {
-      static char buf[100];
-      strcpy(buf, "SDL_VIDEODRIVER=" );
-      strncat( buf, CGameOptions::Instance()->graphicsDriver.c_str(), 100 - strlen(buf));
-      buf[99] = 0;
-      putenv( buf );
-   }
 
    
    SoundSystem soundSystem ( CGameOptions::Instance()->sound.muteEffects, CGameOptions::Instance()->sound.muteMusic, cl->q() || CGameOptions::Instance()->sound.off );
@@ -1626,6 +1705,8 @@ int main(int argc, char *argv[] )
 
    cursorMoved.connect( updateFieldInfo );
 
+   
+   ScreenResolutionSetup screenResolutionSetup ( *cl );
    int flags = 0;
 
    if ( CGameOptions::Instance()->hardwareSurface )
@@ -1633,18 +1714,16 @@ int main(int argc, char *argv[] )
    else
       flags |= SDL_SWSURFACE;
 
-   if ( fullscreen )
+   if ( screenResolutionSetup.isFullscreen() )
       flags |= SDL_FULLSCREEN;
 
    app.setIcon( "program-icon.png" );
    bool initialized = false;
-   if ( !app.InitScreen( xr, yr, 32, flags)) {
+   if ( !app.InitScreen( screenResolutionSetup.getWidth(), screenResolutionSetup.getHeight(), 32, flags)) {
       if ( flags & SDL_FULLSCREEN ) {
          GetVideoModes gvm;
          if ( gvm.getList().size() > 0 ) {
-            xr = gvm.getx(0);
-            yr = gvm.gety(0);
-            if ( app.InitScreen( xr, yr, 32, flags)) 
+            if ( app.InitScreen( gvm.getx(0), gvm.gety(0), 32, flags)) 
                initialized = true;
          }
       }
