@@ -167,7 +167,7 @@ TerrainType::Weather::~Weather()
 }
 
 
-const int terrain_version = 4;
+const int terrain_version = 6;
 
 
 void TerrainType::MoveMalus::read( tnstream& stream, int defaultValue, int moveMalusCount )
@@ -255,6 +255,9 @@ void TerrainType::Weather::read ( tnstream& stream, int version )
 
    move_malus.read( stream, minmalq, move_maluscount );
 
+   if ( version >= 5 )
+      originalImageFilename = stream.readString();
+   
 /*
    for ( j=0; j<8 ;j++ )
       if ( pgbt->picture[j] )
@@ -290,6 +293,8 @@ void TerrainType::Weather::write ( tnstream& stream ) const
 
    move_malus.write ( stream );
 
+   stream.writeString( originalImageFilename );
+   
    if ( bi_pict == -1 )
       image.write ( stream );
 }
@@ -298,38 +303,32 @@ void TerrainType::Weather::write ( tnstream& stream ) const
 void TerrainType::read( tnstream& stream )
 {
    int version = stream.readInt();
-   if ( version == terrain_version || version == 1) {
-
-      stream.readInt(); // name = (char*)
-      id   = stream.readInt();
-
-      bool ___loadWeather[cwettertypennum];
-      for ( int ww = 0; ww < cwettertypennum; ww++ )
-         ___loadWeather[ww] = stream.readInt();
-
-      for ( int nf = 0; nf < 8; nf++ )
-         stream.readInt(); // neighbouringfield[nf]
-
-      name = stream.readString();
-
-      for ( int i=0; i<cwettertypennum ;i++ ) {
-         if ( ___loadWeather[i] ) {
-            weather[i] = new TerrainType::Weather ( this );
-            weather[i]->read( stream, version );
-         } else
-            weather[i] = NULL;
-
-      } /* endfor */
-
-   } else
+   if ( version > terrain_version || (version < 5 && version !=1) ) 
       throw tinvalidversion ( stream.getDeviceName(), terrain_version, version );
+      
+   stream.readInt(); 
+   id   = stream.readInt();
 
-   /*
-   if ( version >= 5 ) {
-      filename = stream.readString();
-      location = stream.readString();
-   }
-   */
+   bool ___loadWeather[cwettertypennum];
+   for ( int ww = 0; ww < cwettertypennum; ww++ )
+      ___loadWeather[ww] = stream.readInt();
+
+   for ( int nf = 0; nf < 8; nf++ )
+      stream.readInt(); // neighbouringfield[nf]
+
+   name = stream.readString();
+
+   for ( int i=0; i<cwettertypennum ;i++ ) {
+      if ( ___loadWeather[i] ) {
+         weather[i] = new TerrainType::Weather ( this );
+         weather[i]->read( stream, version );
+      } else
+         weather[i] = NULL;
+
+   } /* endfor */
+
+   if ( version >= 6 )
+      readClassContainer( secondaryIDs, stream );
 }
 
 
@@ -349,6 +348,8 @@ void TerrainType::write ( tnstream& stream ) const
       if ( weather[i] ) 
          weather[i]->write( stream );
 
+   writeClassContainer( secondaryIDs, stream );
+
    /*
    stream.writeString(filename);
    stream.writeString(location);
@@ -498,6 +499,13 @@ void TerrainType::Weather::runTextIO ( PropertyContainer& pc )
       }
       s += weatherAbbrev[w];
       pc.addImage ( "picture", image, s, true );
+      
+      if ( pc.isReading() ) {
+         originalImageFilename = s;
+      } else {
+         pc.addString( "OriginalImageFilename", originalImageFilename );
+      }
+      
       // applyFieldMask( image );
 
       if ( pc.isReading() ) {
