@@ -1,6 +1,6 @@
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -92,6 +92,22 @@ const int csolarkraftwerkleistung[cwettertypennum] = { 1024, 512, 256, 756, 384,
 
 
 
+int getheightdelta ( int height1, int height2 )
+{
+   int ah = height1;
+   int dh = height2;
+   int hd = dh - ah;
+
+   if ( ah >= 3 && dh <= 2 )
+      hd++;
+   if (dh >= 3 && ah <= 2 )
+      hd--;
+
+   return hd;
+}
+
+
+
 ResourceMatrix :: ResourceMatrix (  )
 {
    for ( int i = 0; i < resourceTypeNum; i++ )
@@ -276,6 +292,13 @@ ASCString Resources::toString() const
 }
 
 
+MapCoordinate& MapCoordinate::operator+=( const MapCoodinateVector& delta )
+{
+   x += delta.dx;
+   y += delta.dy;
+   return *this;
+}
+
 void MapCoordinate::move(int width, int height) {
    x +=width;
    y +=height;
@@ -362,4 +385,15 @@ void Properties::read( tnstream& stream )
    }
 }
 
+ASCString heightToString( int bitmappedHeight )
+{
+   ASCString s;
+   for ( int i = 0; i < 8; ++i )
+      if ( bitmappedHeight & (1 << i )) {
+         if ( !s.empty() )
+            s += " ";
+         s += choehenstufen[i];
+      }
+   return s;
+}
 
