@@ -1,6 +1,6 @@
 /*
      This file is part of Advanced Strategic Command; http://www.asc-hq.de
-     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
+     Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
  
      This program is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -185,6 +185,19 @@ struct GameTime {
 };
 
 
+//! represents a change of a MapCoordinate
+class MapCoodinateVector {
+   int dx;
+   int dy;
+   friend class MapCoordinate;
+   
+   public:
+      MapCoodinateVector( int dx, int dy ) {
+         this->dx = dx;
+         this->dy = dy;
+      }
+};
+
 //! Coordinate on the twodimensional map
 class MapCoordinate {
          public:
@@ -195,6 +208,7 @@ class MapCoordinate {
             bool operator< ( const MapCoordinate& mc ) const { return y < mc.y || ( y == mc.y && x < mc.x );};
             bool operator== ( const MapCoordinate& mc ) const { return y == mc.y && x == mc.x;};
             bool operator!= ( const MapCoordinate& mc ) const { return y != mc.y || x != mc.x;};
+            MapCoordinate& operator+=( const MapCoodinateVector& delta );
             void write( tnstream& stream ) const { stream.writeInt ( 3000 ); stream.writeInt ( x ); stream.writeInt ( y); };
             void read( tnstream& stream ) {
                int vers = stream.readInt ( );
@@ -205,7 +219,7 @@ class MapCoordinate {
                y = stream.readInt ( );
             };
             bool valid() const { return x >= 0 && y >= 0 ; } ;
-	         void move(int width, int height);
+            void move(int width, int height);
             ASCString toString(bool coordinates = false) const;
       };
 
@@ -229,13 +243,13 @@ class MapCoordinate3D : public MapCoordinate {
             void setNumericalHeight ( int nh ) { z = nh; };
             // MapCoordinate3D& operator= ( const MapCoordinate& mc ) { x = mc.x; y = mc.y; z = -1 );
             MapCoordinate3D ( ) : MapCoordinate(), z(-1) {};
-            MapCoordinate3D ( int _x, int _y, int bitmappedz) : MapCoordinate ( _x, _y ), z ( log2(bitmappedz) ) {};
+            MapCoordinate3D ( int _x, int _y, int bitmappedz) : MapCoordinate ( _x, _y ), z ( getFirstBit(bitmappedz) ) {};
             bool operator< ( const MapCoordinate3D& mc ) const { return y < mc.y || ( y == mc.y && x < mc.x ) || (y == mc.y && x == mc.x && z < mc.z);};
             // MapCoordinate3D ( const MapCoordinate& mc ) : MapCoordinate ( mc ), z ( -2 ) {};
-            MapCoordinate3D ( const MapCoordinate& mc, int bitmappedHeight ) : MapCoordinate ( mc ), z ( log2(bitmappedHeight) ) {};
+            MapCoordinate3D ( const MapCoordinate& mc, int bitmappedHeight ) : MapCoordinate ( mc ), z ( getFirstBit(bitmappedHeight) ) {};
             void setnum ( int _x, int _y, int numericalz ) { x = _x; y = _y; z = numericalz; };
             bool operator== ( const MapCoordinate3D& mc ) const { return y == mc.y && x == mc.x && (z == mc.z || z == -2 || mc.z == -2);};
-            bool operator!= ( const MapCoordinate3D& mc ) const { return (mc.x != x) || (mc.y != y) || (mc.z != z); };
+            bool operator!= ( const MapCoordinate3D& mc ) const { return !operator==(mc) ; };
             void write( tnstream& stream ) const { stream.writeInt ( 3500 ); stream.writeInt ( z ); MapCoordinate::write( stream ); };
             void read( tnstream& stream ) {
                stream.readInt ( );
@@ -244,6 +258,15 @@ class MapCoordinate3D : public MapCoordinate {
             };
       };
 
+
+/*!
+  \brief calculate the height difference between two levels of height.
+
+  Since floating and ground based are assumed to be the same effective height, a simple subtraction isn't sufficient.
+  Height is a numeric (and not bitmapped) value
+ */
+extern int getheightdelta ( int height1, int height2 );
+
       
 //! a class for storing general key/values pairs. Intended as a mechanism to persist data from Lua scripts      
 class Properties {      
@@ -392,7 +415,8 @@ extern  const char*  choehenstufen[8] ;
  #define chhochfliegend 64  
  #define chsatellit 128  
 
-
+extern ASCString heightToString( int bitmappedHeight );
+      
 
 
 const int experienceDecreaseDamageBoundaryNum = 4;
@@ -525,7 +549,6 @@ const double productionLineConstructionCostFactor = 0.5;
 const double productionLineRemovalCostFactor = 0.2;
 
 
-
 extern const int csolarkraftwerkleistung[];
 
 //! The number of netcontrol actions ; see #cnetcontrol 
