@@ -58,7 +58,7 @@ Vehicle :: Vehicle ( const Vehicle& v )
 }
 
 
-Vehicle :: Vehicle ( const Vehicletype* t, GameMap* actmap, int player )
+Vehicle :: Vehicle ( const VehicleType* t, GameMap* actmap, int player )
           : ContainerBase ( t, actmap, player ), repairEfficiency ( repairEfficiencyVehicle ), typ ( t ), reactionfire ( this )
 {
    viewOnMap = false;
@@ -74,7 +74,7 @@ Vehicle :: Vehicle ( const Vehicletype* t, GameMap* actmap, int player )
    gamemap->idManager.registerUnitNetworkID( this );
 }
 
-Vehicle :: Vehicle ( const Vehicletype* t, GameMap* actmap, int player, int networkID )
+Vehicle :: Vehicle ( const VehicleType* t, GameMap* actmap, int player, int networkID )
           : ContainerBase ( t, actmap, player ), repairEfficiency ( repairEfficiencyVehicle ), typ ( t ), reactionfire ( this )
 {
    viewOnMap = false;
@@ -121,7 +121,7 @@ Vehicle :: ~Vehicle (  )
       gamemap->idManager.unregisterUnitNetworkID(this);
    }
 
-   tfield* fld = gamemap->getField( xpos, ypos);
+   MapField* fld = gamemap->getField( xpos, ypos);
    if ( fld && fld->vehicle  == this )
        fld->vehicle = NULL;
    
@@ -148,7 +148,7 @@ void Vehicle :: init ( void )
    attacked = false;
 
    if ( typ ) {
-      height = 1 << log2( typ->height );
+      height = 1 << getFirstBit( typ->height );
 
       // These are the preferred levels of height
       if (typ->height & chfahrend )
@@ -160,7 +160,7 @@ void Vehicle :: init ( void )
       for ( int m = 0; m < typ->weapons.count ; m++)
          weapstrength[m] = typ->weapons.weapon[m].maxstrength;
 
-      setMovement ( typ->movement[log2(height)], 0 );
+      setMovement ( typ->movement[getFirstBit(height)], 0 );
    } else {
       height = 0;
 
@@ -238,7 +238,7 @@ int Vehicle :: getResource ( int amount, int resourcetype, bool queryonly, int s
       if ( player < 0 )
          player = getMap()->actplayer;
       
-      if ( player != getOwner() && !getMap()->getPlayer(getOwner()).diplomacy.isAllied(player) && !queryonly)
+      if ( player != getOwner() && (getMap()->getPlayer(getOwner()).diplomacy.getState(player) < PEACE) && !queryonly)
          return 0;
       
       
@@ -302,7 +302,7 @@ int Vehicle::size ( void )
    return typ->weight;
 }
 
-void Vehicle::transform ( const Vehicletype* type )
+void Vehicle::transform ( const VehicleType* type )
 {
    if ( !type )
       return;
@@ -414,7 +414,7 @@ void Vehicle :: endOwnTurn()
 
 void Vehicle :: resetMovement ( void )
 {
-    int move = typ->movement[log2(height)];
+    int move = typ->movement[getFirstBit(height)];
     setMovement ( move, 0 );
 }
 
@@ -431,16 +431,16 @@ void Vehicle :: setMovement ( int newmove, double cargoDivisor )
       newmove = 0;
 
    if ( cargoDivisor > 0 && typ)
-      if ( typ->movement[ log2 ( height ) ] ) {
+      if ( typ->movement[ getFirstBit ( height ) ] ) {
          double diff = _movement - newmove;
-         double perc = diff / typ->movement[ log2 ( height ) ] ;
+         double perc = diff / typ->movement[ getFirstBit ( height ) ] ;
          for ( Cargo::iterator i = cargo.begin(); i != cargo.end(); ++i )
             if ( *i ) {
                double lperc = perc;
                if ( cargoDivisor && cargoNestingDepth() == 0 )
                   lperc /= cargoDivisor;
 
-               (*i)->decreaseMovement ( max( 1, int( ceil( lperc * double( (*i)->typ->movement[ log2 ( (*i)->height)] )))));
+               (*i)->decreaseMovement ( max( 1, int( ceil( lperc * double( (*i)->typ->movement[ getFirstBit ( (*i)->height)] )))));
             }
    }
    _movement = newmove;
@@ -448,7 +448,7 @@ void Vehicle :: setMovement ( int newmove, double cargoDivisor )
 
 bool Vehicle::hasMoved ( void ) const
 {
-   return _movement != typ->movement[ log2 ( height )];
+   return _movement != typ->movement[ getFirstBit ( height )];
 }
 
 
@@ -471,8 +471,8 @@ void Vehicle :: decreaseMovement ( int amount )
   int newMovement = _movement - amount;
   if ( newMovement < 0 )
     newMovement = 0;
-  if ( newMovement > typ->movement[log2(height)] )
-    newMovement = typ->movement[log2(height)];
+  if ( newMovement > typ->movement[getFirstBit(height)] )
+    newMovement = typ->movement[getFirstBit(height)];
   setMovement ( newMovement );
 }
 
@@ -499,7 +499,7 @@ bool Vehicle :: canMove ( void ) const
    //   return false;
 
    if ( movementLeft() && reactionfire.canMove() ) {
-      tfield* fld = gamemap->getField ( getPosition() );
+      MapField* fld = gamemap->getField ( getPosition() );
       if ( fld->unitHere ( this ) ) {
          if ( terrainaccessible ( fld, this ) || getMap()->getgameparameter(cgp_movefrominvalidfields))
             return true;
@@ -525,8 +525,8 @@ bool Vehicle::spawnMoveObjects( const MapCoordinate& start, const MapCoordinate&
    if ( typ->objectLayedByMovement.size() && (height == chfahrend || height == chschwimmend))  {
       int dir = getdirection( start, dest );
 
-      tfield* startField = gamemap->getField(start);
-      tfield* destField = gamemap->getField(dest);
+      MapField* startField = gamemap->getField(start);
+      MapField* destField = gamemap->getField(dest);
 
       for ( int i = 0; i < typ->objectLayedByMovement.size(); i++ ) 
          for ( int id = typ->objectLayedByMovement[i].from; id <= typ->objectLayedByMovement[i].to; ++id ) {
@@ -671,7 +671,7 @@ bool Vehicle::ReactionFire:: canPerformAttack( Vehicle* target )
 
 
 
-const Vehicletype::HeightChangeMethod* Vehicle::getHeightChange( int dir, int height ) const
+const VehicleType::HeightChangeMethod* Vehicle::getHeightChange( int dir, int height ) const
 {
    if ( !reactionfire.canMove() )
       return NULL;
@@ -682,7 +682,7 @@ const Vehicletype::HeightChangeMethod* Vehicle::getHeightChange( int dir, int he
    for ( int i = 0; i < typ->heightChangeMethodNum; i++ )
       if ( typ->heightChangeMethod[i].startHeight & height )
          if ( ( dir > 0 && typ->heightChangeMethod[i].heightDelta > 0) || ( dir < 0 && typ->heightChangeMethod[i].heightDelta < 0))
-            if ( (1 << (log2(height) + typ->heightChangeMethod[i].heightDelta)) & typ->height )
+            if ( (1 << (getFirstBit(height) + typ->heightChangeMethod[i].heightDelta)) & typ->height )
                return &typ->heightChangeMethod[i];
 
    return NULL;
@@ -758,7 +758,7 @@ void Vehicle::registerForNewOwner( int player )
 }
 
 
-bool  Vehicle :: vehicleconstructable ( const Vehicletype* tnk, int x, int y )
+bool  Vehicle :: vehicleconstructable ( const VehicleType* tnk, int x, int y )
 {
    if ( gamemap->getgameparameter(cgp_produceOnlyResearchedStuffExternally) && 
        !tnk->techDependency.available ( gamemap->player[getOwner()].research))
@@ -770,7 +770,7 @@ bool  Vehicle :: vehicleconstructable ( const Vehicletype* tnk, int x, int y )
    if( (tnk->height & height ) || (( tnk->height & (chfahrend | chschwimmend)) && (height & (chfahrend | chschwimmend)))) {
       int hgt = height;
       if ( !(tnk->height & height))
-         hgt = 1 << log2(tnk->height);
+         hgt = 1 << getFirstBit(tnk->height);
       if ( terrainaccessible2( gamemap->getField(x,y), tnk->terrainaccess, hgt ) > 0 )
          if ( getResource( getExternalVehicleConstructionCost( tnk ), true ) == getExternalVehicleConstructionCost( tnk ) )
             if ( beeline (x, y, xpos, ypos) <= maxmalq )
@@ -781,7 +781,7 @@ bool  Vehicle :: vehicleconstructable ( const Vehicletype* tnk, int x, int y )
 }
 
 
-Resources Vehicle::getExternalVehicleConstructionCost( const Vehicletype* tnk ) const
+Resources Vehicle::getExternalVehicleConstructionCost( const VehicleType* tnk ) const
 {
    Resources r;
    r.material = tnk->productionCost.material;
@@ -811,7 +811,7 @@ bool Vehicle :: buildingconstructable ( const BuildingType* building, bool check
    if ( !ff )
       ff = 100;
 
-   int hd = getheightdelta ( log2 ( height ), log2 ( building->height ));
+   int hd = getheightdelta ( getFirstBit ( height ), getFirstBit ( building->height ));
 
    if ( hd != 0 ) // && !(hd ==-1 && (height == chschwimmend || height == chfahrend)) ???  what was that ??
       return 0;
@@ -854,7 +854,7 @@ int Vehicle :: searchstackforfreeweight ( Vehicle* searchedInnerVehicle )
 
 int Vehicle :: freeWeight ()
 {
-   tfield* fld = gamemap->getField ( xpos, ypos );
+   MapField* fld = gamemap->getField ( xpos, ypos );
    if ( fld->vehicle )
       return fld->vehicle->searchstackforfreeweight ( this );
    else
@@ -952,7 +952,7 @@ void Vehicle::setAttacked( bool recursive, const Context& context )
 
 int Vehicle::maxMovement ( void ) const
 {
-   return typ->movement[log2(height)];
+   return typ->movement[getFirstBit(height)];
 }
 
 
@@ -1000,7 +1000,7 @@ void Vehicle :: fillMagically( bool ammunition, bool resources )
 
 
 
-const int vehicleVersion = 7;
+const int vehicleVersion = 8;
 
 void   Vehicle::write ( tnstream& stream, bool includeLoadedUnits ) const
 {
@@ -1039,7 +1039,7 @@ void   Vehicle::write ( tnstream& stream, bool includeLoadedUnits ) const
     if ( height != chfahrend )
        bm |= cem_height;
 
-//    if ( _movement < typ->movement[log2(height)] )
+//    if ( _movement < typ->movement[getFirstBit(height)] )
     bm |= cem_movement;
 
     if ( direction )
@@ -1170,6 +1170,8 @@ void   Vehicle::write ( tnstream& stream, bool includeLoadedUnits ) const
     }
     
     stream.writeInt( view );
+    
+    stream.writeString( privateName );
 }
 
 void   Vehicle::read ( tnstream& stream )
@@ -1271,7 +1273,7 @@ void   Vehicle::readData ( tnstream& stream )
        height = chfahrend;
 
     if ( ! (height & typ->height) )
-       height = 1 << log2 ( typ->height );
+       height = 1 << getFirstBit ( typ->height );
 
     if ( bm & cem_movement ) {
        int m;
@@ -1280,9 +1282,9 @@ void   Vehicle::readData ( tnstream& stream )
        else
           m = stream.readInt();
        
-       setMovement ( min( m,typ->movement [ log2 ( height ) ]), 0 );
+       setMovement ( min( m,typ->movement [ getFirstBit ( height ) ]), 0 );
     } else
-       setMovement ( typ->movement [ log2 ( height ) ], 0 );
+       setMovement ( typ->movement [ getFirstBit ( height ) ], 0 );
 
     if ( bm & cem_direction )
        direction = stream.readChar();
@@ -1330,7 +1332,7 @@ void   Vehicle::readData ( tnstream& stream )
 
     if ( reactionfirestatus >= 8 && reactionfireenemiesAttackable <= 4 ) { // for transition from the old reactionfire system ( < ASC1.2.0 ) to the new one ( >= ASC1.2.0 )
        reactionfire.status = ReactionFire::Status ( reactionfireenemiesAttackable );
-       setMovement ( typ->movement [ log2 ( height ) ], 0 );
+       setMovement ( typ->movement [ getFirstBit ( height ) ], 0 );
     } else
        reactionfire.status = ReactionFire::Status ( reactionfirestatus );
 
@@ -1412,6 +1414,12 @@ void   Vehicle::readData ( tnstream& stream )
        view = stream.readInt();
     else
        view = typ->view;
+    
+    if ( version >= 8 )
+       privateName = stream.readString();
+    else
+       privateName = "";
+
 }
 
 MapCoordinate3D Vehicle :: getPosition ( ) const
@@ -1590,7 +1598,7 @@ Vehicle* Vehicle::newFromStream ( GameMap* gamemap, tnstream& stream, int forceN
       id = stream.readInt();
    }
 
-   Vehicletype* fzt = gamemap->getvehicletype_byid ( id );
+   VehicleType* fzt = gamemap->getvehicletype_byid ( id );
    if ( !fzt )
       throw InvalidID ( "vehicle", id );
 
@@ -1647,7 +1655,7 @@ int UnitHooveringLogic::calcFuelUsage( const Vehicle* veh )
 }
 
 
-int UnitHooveringLogic::getEndurance ( const Vehicletype* veh, int height, int resourceModel )
+int UnitHooveringLogic::getEndurance ( const VehicleType* veh, int height, int resourceModel )
 {
    assert( height < 8 );
    
