@@ -60,7 +60,7 @@ void         tcomputeview::initviewcalculation(  int view, int jamming, int sx,
 void         tcomputeview::testfield( const MapCoordinate& mc )
 {
    int f = beeline(startPos, mc);
-   tfield* efield = gamemap->getField(mc);
+   MapField* efield = gamemap->getField(mc);
 
    if ( viewdist && ( f <= 15 ) && (gamemap->getgameparameter( cgp_disableDirectView) == 0  || f < 10 ) )
       efield->view[player].direct += mode;
@@ -129,7 +129,7 @@ void         tcomputeview::testfield( const MapCoordinate& mc )
           efield->view[player].satellite < 0 ||
           efield->view[player].jamming   < 0 ||
           efield->view[player].mine      < 0 )
-        displaymessage ( "Warning: inconsistency in view calculation !!\n Please report this bug !", 1 );
+        errorMessage( "Warning: inconsistency in view calculation !!\n Please report this bug !" );
    #endif
 }
 
@@ -211,7 +211,7 @@ void         tcomputebuildingview::init( const Building*    bld,  int _mode )
    for ( int a = 0; a < 4; a++)
       for (int b = 0; b < 6; b++)
          if ( building->typ->fieldExists ( BuildingType::LocalCoordinate( a, b ) )) {
-            tfield* efield = building->getField ( BuildingType::LocalCoordinate( a, b ) );
+            MapField* efield = building->getField ( BuildingType::LocalCoordinate( a, b ) );
             if ( minenview )
                efield->view[player].mine += _mode;
             efield->view[player].direct += _mode;
@@ -222,19 +222,22 @@ void         tcomputebuildingview::init( const Building*    bld,  int _mode )
 
 
 
-void         clearvisibility( GameMap* gamemap, int  reset )
+void         clearvisibility( GameMap* gamemap )
 {
    if (!gamemap || (gamemap->xsize <= 0) || (gamemap->ysize <= 0))
      return;
 
-   for ( int p = 0; p < gamemap->getPlayerCount() ; p++ )
+   for ( int p = 0; p < gamemap->getPlayerCount() ; p++ ) {
       for ( Player::VehicleList::iterator i = gamemap->player[p].vehicleList.begin(); i != gamemap->player[p].vehicleList.end(); i++ )
          (*i)->resetview();
+      for ( Player::BuildingList::iterator b = gamemap->player[p].buildingList.begin(); b != gamemap->player[p].buildingList.end(); b++ )
+         (*b)->resetview();
+   }
 
    int l = 0;
    for ( int x = 0; x < gamemap->xsize ; x++)
          for ( int y = 0; y < gamemap->ysize ; y++) {
-            tfield* fld = &gamemap->field[l];
+            MapField* fld = &gamemap->field[l];
             memset ( fld->view, 0, sizeof ( fld->view ));
             l++;
          }
@@ -243,7 +246,7 @@ void         clearvisibility( GameMap* gamemap, int  reset )
 }
 
 
-VisibilityStates calcvisibilityfield ( GameMap* gamemap, tfield* fld, int player, int add, int initial, int additionalEnemyJamming )
+VisibilityStates calcvisibilityfield ( GameMap* gamemap, MapField* fld, int player, int add, int initial, int additionalEnemyJamming )
 {
    if ( player == -1 )
       return visible_all;
@@ -302,7 +305,7 @@ VisibilityStates calcvisibilityfield ( GameMap* gamemap, tfield* fld, int player
       return view;
 }
 
-int  evaluatevisibilityfield ( GameMap* gamemap, tfield* fld, int player, int add, int initial )
+int  evaluatevisibilityfield ( GameMap* gamemap, MapField* fld, int player, int add, int initial )
 {
    if ( player < 0 )
       return 0;
@@ -340,7 +343,7 @@ int  evaluateviewcalculation ( GameMap* gamemap, int player_fieldcount_mask, boo
       
          for ( int y = 0; y < gamemap->ysize; ++y )
             for ( int x = 0; x < gamemap->xsize; ++x ) {
-               tfield* fld = gamemap->getField(x,y);
+               MapField* fld = gamemap->getField(x,y);
                
                if ( firstLoop )
                   // first player in loop, so we save the current state as the 'original' state
@@ -359,7 +362,7 @@ int  evaluateviewcalculation ( GameMap* gamemap, int player_fieldcount_mask, boo
       ChangeView::ViewState viewState;
       for ( int y = 0; y < gamemap->ysize; ++y )
          for ( int x = 0; x < gamemap->xsize; ++x ) {
-            tfield* fld = gamemap->getField(x,y);
+            MapField* fld = gamemap->getField(x,y);
             if ( fld->visible != fld->temp3 ) {
                // we are running under action control, the change shall be done by the action and not here,
                // so we are undoing our change for the moment
@@ -416,7 +419,7 @@ int  evaluateviewcalculation ( GameMap* gamemap, const MapCoordinate& pos, int d
 
    for ( int yy = y1; yy <= y2; yy++ )
       for ( int xx = x1; xx <= x2; xx++ ) {
-         tfield* fld = gamemap->getField ( xx, yy );
+         MapField* fld = gamemap->getField ( xx, yy );
          int oldview = fld->visible;
          for ( int player = 0; player < gamemap->getPlayerCount(); player++ )
             if ( gamemap->player[player].exist() ) {
@@ -449,7 +452,7 @@ int computeview( GameMap* gamemap, int player_fieldcount_mask, bool disableShare
    if ( !gamemap || (gamemap->xsize == 0) || (gamemap->ysize == 0))
       return 0;
 
-   clearvisibility( gamemap, 1 );
+   clearvisibility( gamemap );
 
    for ( int a = 0; a < gamemap->getPlayerCount(); a++)
       if (gamemap->player[a].exist() ) {
@@ -483,7 +486,7 @@ int getPlayersWithSharedViewMask( int player, GameMap* gamemap )
 }
       
 #if 0
-VisibilityStates fieldVisibility( tfield* pe, int player, GameMap* gamemap, int additionalEnemyJamming )
+VisibilityStates fieldVisibility( MapField* pe, int player, GameMap* gamemap, int additionalEnemyJamming )
 {
    evaluatevisibilityfield( gamemap, pe, player, getPlayersWithSharedViewMask(player,gamemap), gamemap->getgameparameter ( cgp_initialMapVisibility ), additionalEnemyJamming );
 #ifdef karteneditor
@@ -522,17 +525,17 @@ void RecalculateAreaView::removeView()
 void RecalculateAreaView::addView()
 {
    circularFieldIterator( gamemap, position, 0, range, FieldIterationFunctor( this, &RecalculateAreaView::addFieldView ));
-   evaluateviewcalculation( gamemap, position, range, 0, false, context );
+   evaluateviewcalculation( gamemap, position, range*maxmalq, 0, false, context );
    active = false;
 }
 
 void RecalculateAreaView::removeFieldView( const MapCoordinate& pos )
 {
-   tfield* fld = gamemap->getField(pos);
+   MapField* fld = gamemap->getField(pos);
    if ( !fld )
       return;
    
-   if ( fld->getContainer() && fld->getContainer()->getOwner() < fld->getContainer()->getMap()->getPlayerCount() ) {
+   if ( (fld->vehicle || fld->getBuildingEntrance()) && fld->getContainer()->getOwner() < fld->getContainer()->getMap()->getPlayerCount() ) {
       if ( context ) 
          (new ViewRegistration( fld->getContainer(), ViewRegistration::RemoveView ))->execute(*context);
       else 
@@ -542,12 +545,12 @@ void RecalculateAreaView::removeFieldView( const MapCoordinate& pos )
 
 void RecalculateAreaView::addFieldView( const MapCoordinate& pos )
 {
-   tfield* fld = gamemap->getField(pos);
+   MapField* fld = gamemap->getField(pos);
    if ( !fld )
       return;
    
    
-   if ( fld->getContainer() && fld->getContainer()->getOwner() < fld->getContainer()->getMap()->getPlayerCount() ) { //excluding neutral buildings here
+   if ( (fld->vehicle || fld->getBuildingEntrance()) && fld->getContainer()->getOwner() < fld->getContainer()->getMap()->getPlayerCount() ) { //excluding neutral buildings here
       if ( context ) 
          (new ViewRegistration( fld->getContainer(), ViewRegistration::AddView ))->execute(*context);
       else
